@@ -4,7 +4,7 @@
  * Author:      Joel Farley, Ove Kven
  * Modified by: Vadim Zeitlin, Robert Roebling, Ron Lee
  * Created:     1998/06/12
- * RCS-ID:      $Id: wxchar.h 47877 2007-08-04 21:58:53Z VZ $
+ * RCS-ID:      $Id: wxchar.h 61872 2009-09-09 22:37:05Z VZ $
  * Copyright:   (c) 1998-2006 wxWidgets dev team
  * Licence:     wxWindows licence
  */
@@ -227,32 +227,47 @@
 #endif /* ASCII/Unicode */
 
 /* ---------------------------------------------------------------------------- */
-/* define _T() and related macros */
+/* define wxT() and related macros */
 /* ---------------------------------------------------------------------------- */
 
-/* BSD systems define _T() to be something different in ctype.h, override it */
-#if defined(__FreeBSD__) || defined(__DARWIN__)
-    #include <ctype.h>
-    #undef _T
+#if wxUSE_UNICODE
+    /* use wxCONCAT_HELPER so that x could be expanded if it's a macro */
+    #define wxT(x) wxCONCAT_HELPER(L, x)
+#else /* !Unicode */
+    #define wxT(x) x
+#endif /* Unicode/!Unicode */
+
+/*
+    We define _T() as a synonym of wxT() for backwards compatibility and also
+    for the benefit of Windows programmers used to it. But this identifier is a
+    reserved one and this does create problems in practice, notably with Sun CC
+    which uses it in the recent versions of its standard headers. So avoid
+    defining it for this compiler at all, unless it was explicitly requested by
+    predefining wxNEEDS__T macro before including this header or if we're
+    building wx itself which does need and compiles fine thanks to the special
+    workarounds for Sun CC in wx/{before,after}std.h.
+ */
+#ifndef wxNEEDS__T
+    #if defined(WXBUILDING) || !(defined (__SUNPRO_C) || defined(__SUNPRO_CC))
+        #define wxNEEDS__T
+    #endif
 #endif
 
-/* could already be defined by tchar.h (it's quasi standard) */
-#ifndef _T
-    #if !wxUSE_UNICODE
-        #define _T(x) x
-    #else /* Unicode */
-        /* use wxCONCAT_HELPER so that x could be expanded if it's a macro */
-        #define _T(x) wxCONCAT_HELPER(L, x)
-    #endif /* ASCII/Unicode */
-#endif /* !defined(_T) */
+#ifdef wxNEEDS__T
+    /* BSDs define _T() to be something different in ctype.h, override it */
+    #if defined(__FreeBSD__) || defined(__DARWIN__)
+        #include <ctype.h>
+    #endif
+    #undef _T
 
-/* although global macros with such names are normally bad, we want to have */
-/* another name for _T() which should be used to avoid confusion between _T() */
-/* and _() in wxWidgets sources */
-#define wxT(x)       _T(x)
+    #define _T(x) wxT(x)
+#endif /* wxNEEDS__T */
+
+/* this macro exists only for forward compatibility with wx 3.0 */
+#define wxS(x)       wxT(x)
 
 /* a helper macro allowing to make another macro Unicode-friendly, see below */
-#define wxAPPLY_T(x) _T(x)
+#define wxAPPLY_T(x) wxT(x)
 
 /* Unicode-friendly __FILE__, __DATE__ and __TIME__ analogs */
 #ifndef __TFILE__
@@ -371,6 +386,14 @@
             /* and there is a bug in D Mars tchar.h prior to 8.39.4n, so define as sprintf */
             #define wxSprintf sprintf
         #endif
+    #elif defined(__MINGW32__) && ( defined(_STLPORT_VERSION) && _STLPORT_VERSION >= 0x510 )
+        #if wxUSE_UNICODE
+            /* MinGW with STLPort 5.1 adds count to swprintf (C99) so prototype conversion see wxchar.cpp */
+            int wxSprintf (wchar_t*, const wchar_t*, ...);
+        #else
+            /* MinGW with STLPort 5.1 has clashing defines for _stprintf so use sprintf */
+            #define wxSprintf sprintf
+        #endif
     #else
         #define  wxSprintf   _stprintf
     #endif
@@ -887,9 +910,10 @@ WXDLLIMPEXP_BASE bool wxOKlibc(); /* for internal use */
 
 /*
    MinGW MSVCRT has non-standard vswprintf() (for MSVC compatibility
-   presumably) and normally _vsnwprintf() is used instead
+   presumably) and normally _vsnwprintf() is used instead (but as
+   STLPort 5.1 defines standard vswprintf(), don't do this for it)
  */
-#if defined(HAVE_VSWPRINTF) && defined(__MINGW32__)
+#if defined(HAVE_VSWPRINTF) && defined(__MINGW32__) && !( defined(_STLPORT_VERSION) && _STLPORT_VERSION >= 0x510 )
     #undef HAVE_VSWPRINTF
 #endif
 
@@ -1102,7 +1126,7 @@ WXDLLIMPEXP_BASE bool wxOKlibc(); /* for internal use */
 
 #ifdef _WIN32_WCE
     #if _WIN32_WCE <= 211
-        #define isspace(c) ((c) == _T(' ') || (c) == _T('\t'))
+        #define isspace(c) ((c) == wxT(' ') || (c) == wxT('\t'))
     #endif
 #endif /* _WIN32_WCE */
 
