@@ -1,10 +1,9 @@
-/////////////////////////////////////////////////////////////////////////////
-// Name:        utilscmn.cpp
+// Name:        src/common/utilscmn.cpp
 // Purpose:     Miscellaneous utility functions and classes
 // Author:      Julian Smart
 // Modified by:
 // Created:     29/01/98
-// RCS-ID:      $Id: utilscmn.cpp,v 1.145.2.4 2006/06/26 00:01:03 VZ Exp $
+// RCS-ID:      $Id: utilscmn.cpp 63295 2010-01-28 10:14:20Z CE $
 // Copyright:   (c) 1998 Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -17,17 +16,6 @@
 // headers
 // ----------------------------------------------------------------------------
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA) && !defined(__EMX__)
-// Some older compilers (such as EMX) cannot handle
-// #pragma interface/implementation correctly, iff
-// #pragma implementation is used in _two_ translation
-// units (as created by e.g. event.cpp compiled for
-// libwx_base and event.cpp compiled for libwx_gui_core).
-// So we must not use those pragmas for those compilers in
-// such files.
-    #pragma implementation "utils.h"
-#endif
-
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
@@ -73,7 +61,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#if !defined(__WATCOMC__)
+#if !wxONLY_WATCOM_EARLIER_THAN(1,4)
     #if !(defined(_MSC_VER) && (_MSC_VER > 800))
         #include <errno.h>
     #endif
@@ -83,7 +71,6 @@
     #include "wx/colordlg.h"
     #include "wx/fontdlg.h"
     #include "wx/notebook.h"
-    #include "wx/frame.h"
     #include "wx/statusbr.h"
 #endif // wxUSE_GUI
 
@@ -117,11 +104,6 @@
 // common data
 // ----------------------------------------------------------------------------
 
-#if WXWIN_COMPATIBILITY_2_2
-    const wxChar *wxInternalErrorStr = wxT("wxWidgets Internal Error");
-    const wxChar *wxFatalErrorStr = wxT("wxWidgets Fatal Error");
-#endif // WXWIN_COMPATIBILITY_2_2
-
 // ============================================================================
 // implementation
 // ============================================================================
@@ -304,20 +286,219 @@ wxString wxGetDataDir()
     return dir;
 }
 
-int wxGetOsVersion(int *verMaj, int *verMin)
+bool wxIsPlatformLittleEndian()
 {
-    // we want this function to work even if there is no wxApp
-    wxConsoleAppTraits traitsConsole;
-    wxAppTraits *traits = wxTheApp ? wxTheApp->GetTraits() : NULL;
-    if ( ! traits )
-        traits = &traitsConsole;
+    // Are we little or big endian? This method is from Harbison & Steele.
+    union
+    {
+        long l;
+        char c[sizeof(long)];
+    } u;
+    u.l = 1;
 
-    wxToolkitInfo& info = traits->GetToolkitInfo();
-    if ( verMaj )
-        *verMaj = info.versionMajor;
-    if ( verMin )
-        *verMin = info.versionMinor;
-    return info.os;
+    return u.c[0] == 1;
+}
+
+
+/*
+ * Class to make it easier to specify platform-dependent values
+ */
+
+wxArrayInt*  wxPlatform::sm_customPlatforms = NULL;
+
+void wxPlatform::Copy(const wxPlatform& platform)
+{
+    m_longValue = platform.m_longValue;
+    m_doubleValue = platform.m_doubleValue;
+    m_stringValue = platform.m_stringValue;
+}
+
+wxPlatform wxPlatform::If(int platform, long value)
+{
+    if (Is(platform))
+        return wxPlatform(value);
+    else
+        return wxPlatform();
+}
+
+wxPlatform wxPlatform::IfNot(int platform, long value)
+{
+    if (!Is(platform))
+        return wxPlatform(value);
+    else
+        return wxPlatform();
+}
+
+wxPlatform& wxPlatform::ElseIf(int platform, long value)
+{
+    if (Is(platform))
+        m_longValue = value;
+    return *this;
+}
+
+wxPlatform& wxPlatform::ElseIfNot(int platform, long value)
+{
+    if (!Is(platform))
+        m_longValue = value;
+    return *this;
+}
+
+wxPlatform wxPlatform::If(int platform, double value)
+{
+    if (Is(platform))
+        return wxPlatform(value);
+    else
+        return wxPlatform();
+}
+
+wxPlatform wxPlatform::IfNot(int platform, double value)
+{
+    if (!Is(platform))
+        return wxPlatform(value);
+    else
+        return wxPlatform();
+}
+
+wxPlatform& wxPlatform::ElseIf(int platform, double value)
+{
+    if (Is(platform))
+        m_doubleValue = value;
+    return *this;
+}
+
+wxPlatform& wxPlatform::ElseIfNot(int platform, double value)
+{
+    if (!Is(platform))
+        m_doubleValue = value;
+    return *this;
+}
+
+wxPlatform wxPlatform::If(int platform, const wxString& value)
+{
+    if (Is(platform))
+        return wxPlatform(value);
+    else
+        return wxPlatform();
+}
+
+wxPlatform wxPlatform::IfNot(int platform, const wxString& value)
+{
+    if (!Is(platform))
+        return wxPlatform(value);
+    else
+        return wxPlatform();
+}
+
+wxPlatform& wxPlatform::ElseIf(int platform, const wxString& value)
+{
+    if (Is(platform))
+        m_stringValue = value;
+    return *this;
+}
+
+wxPlatform& wxPlatform::ElseIfNot(int platform, const wxString& value)
+{
+    if (!Is(platform))
+        m_stringValue = value;
+    return *this;
+}
+
+wxPlatform& wxPlatform::Else(long value)
+{
+    m_longValue = value;
+    return *this;
+}
+
+wxPlatform& wxPlatform::Else(double value)
+{
+    m_doubleValue = value;
+    return *this;
+}
+
+wxPlatform& wxPlatform::Else(const wxString& value)
+{
+    m_stringValue = value;
+    return *this;
+}
+
+void wxPlatform::AddPlatform(int platform)
+{
+    if (!sm_customPlatforms)
+        sm_customPlatforms = new wxArrayInt;
+    sm_customPlatforms->Add(platform);
+}
+
+void wxPlatform::ClearPlatforms()
+{
+    delete sm_customPlatforms;
+    sm_customPlatforms = NULL;
+}
+
+/// Function for testing current platform
+
+bool wxPlatform::Is(int platform)
+{
+#ifdef __WXMSW__
+    if (platform == wxOS_WINDOWS)
+        return true;
+#endif
+#ifdef __WXWINCE__
+    if (platform == wxOS_WINDOWS_CE)
+        return true;
+#endif
+
+#if 0
+
+// FIXME: wxWinPocketPC and wxWinSmartPhone are unknown symbols
+
+#if defined(__WXWINCE__) && defined(__POCKETPC__)
+    if (platform == wxWinPocketPC)
+        return true;
+#endif
+#if defined(__WXWINCE__) && defined(__SMARTPHONE__)
+    if (platform == wxWinSmartPhone)
+        return true;
+#endif
+
+#endif
+
+#ifdef __WXGTK__
+    if (platform == wxPORT_GTK)
+        return true;
+#endif
+#ifdef __WXMAC__
+    if (platform == wxPORT_MAC)
+        return true;
+#endif
+#ifdef __WXX11__
+    if (platform == wxPORT_X11)
+        return true;
+#endif
+#ifdef __UNIX__
+    if (platform == wxOS_UNIX)
+        return true;
+#endif
+#ifdef __WXMGL__
+    if (platform == wxPORT_MGL)
+        return true;
+#endif
+#ifdef __OS2__
+    if (platform == wxOS_OS2)
+        return true;
+#endif
+#ifdef __WXPM__
+    if (platform == wxPORT_PM)
+        return true;
+#endif
+#ifdef __WXCOCOA__
+    if (platform == wxPORT_MAC)
+        return true;
+#endif
+
+    if (sm_customPlatforms && sm_customPlatforms->Index(platform) != wxNOT_FOUND)
+        return true;
+
+    return false;
 }
 
 // ----------------------------------------------------------------------------
@@ -465,24 +646,27 @@ static bool ReadAll(wxInputStream *is, wxArrayString& output)
 
     wxTextInputStream tis(*is);
 
-    bool cont = true;
-    while ( cont )
+    for ( ;; )
     {
         wxString line = tis.ReadLine();
-        if ( is->Eof() )
-            break;
 
+        // check for EOF before other errors as it's not really an error
+        if ( is->Eof() )
+        {
+            // add the last, possibly incomplete, line
+            if ( !line.empty() )
+                output.Add(line);
+            break;
+        }
+
+        // any other error is fatal
         if ( !*is )
-        {
-            cont = false;
-        }
-        else
-        {
-            output.Add(line);
-        }
+            return false;
+
+        output.Add(line);
     }
 
-    return cont;
+    return true;
 }
 #endif // wxUSE_STREAMS
 
@@ -540,30 +724,113 @@ long wxExecute(const wxString& command,
 // Launch default browser
 // ----------------------------------------------------------------------------
 
-bool wxLaunchDefaultBrowser(const wxString& urlOrig)
+#include "wx/private/browserhack28.h"
+
+static bool wxLaunchDefaultBrowserBaseImpl(const wxString& url, int flags);
+
+// Use wxLaunchDefaultBrowserBaseImpl by default
+static wxLaunchDefaultBrowserImpl_t s_launchBrowserImpl = &wxLaunchDefaultBrowserBaseImpl;
+
+// Function the GUI library can call to provide a better implementation
+WXDLLIMPEXP_BASE void wxSetLaunchDefaultBrowserImpl(wxLaunchDefaultBrowserImpl_t newImpl)
 {
-    // set the scheme of url to http if it does not have one
-    wxString url(urlOrig);
-    if ( !wxURI(url).HasScheme() )
-        url.Prepend(wxT("http://"));
+    s_launchBrowserImpl = newImpl!=NULL ? newImpl : &wxLaunchDefaultBrowserBaseImpl;
+}
+
+static bool wxLaunchDefaultBrowserBaseImpl(const wxString& url, int flags)
+{
+    wxUnusedVar(flags);
 
 #if defined(__WXMSW__)
+
+#if wxUSE_IPC
+    if ( flags & wxBROWSER_NEW_WINDOW )
+    {
+        // ShellExecuteEx() opens the URL in an existing window by default so
+        // we can't use it if we need a new window
+        wxURI uri(url);
+        wxRegKey key(wxRegKey::HKCR, uri.GetScheme() + _T("\\shell\\open"));
+        if ( !key.Exists() )
+        {
+            // try default browser, it must be registered at least for http URLs
+            key.SetName(wxRegKey::HKCR, _T("http\\shell\\open"));
+        }
+
+        if ( key.Exists() )
+        {
+            wxRegKey keyDDE(key, wxT("DDEExec"));
+            if ( keyDDE.Exists() )
+            {
+                // we only know the syntax of WWW_OpenURL DDE request for IE,
+                // optimistically assume that all other browsers are compatible
+                // with it
+                static const wxString TOPIC_OPEN_URL = wxT("WWW_OpenURL");
+                wxString ddeCmd;
+                wxRegKey keyTopic(keyDDE, wxT("topic"));
+                bool ok = keyTopic.Exists() && (keyTopic.QueryDefaultValue() = TOPIC_OPEN_URL);
+                if ( ok )
+                {
+                    ddeCmd = keyDDE.QueryDefaultValue();
+                    ok = !ddeCmd.empty();
+                }
+
+                if ( ok )
+                {
+                    // for WWW_OpenURL, the index of the window to open the URL
+                    // in is -1 (meaning "current") by default, replace it with
+                    // 0 which means "new" (see KB article 160957)
+                    ok = ddeCmd.Replace(wxT("-1"), wxT("0"),
+                                        false /* only first occurence */) == 1;
+                }
+
+                if ( ok )
+                {
+                    // and also replace the parameters: the topic should
+                    // contain a placeholder for the URL
+                    ok = ddeCmd.Replace(wxT("%1"), url, false) == 1;
+                }
+
+                if ( ok )
+                {
+                    // try to send it the DDE request now but ignore the errors
+                    wxLogNull noLog;
+
+                    const wxString ddeServer = wxRegKey(keyDDE, wxT("application")).QueryDefaultValue();
+                    if ( wxExecuteDDE(ddeServer, TOPIC_OPEN_URL, ddeCmd) )
+                        return true;
+
+                    // this is not necessarily an error: maybe browser is
+                    // simply not running, but no matter, in any case we're
+                    // going to launch it using ShellExecuteEx() below now and
+                    // we shouldn't try to open a new window if we open a new
+                    // browser anyhow
+                }
+            }
+        }
+    }
+#endif // wxUSE_IPC
+
     WinStruct<SHELLEXECUTEINFO> sei;
     sei.lpFile = url.c_str();
     sei.lpVerb = _T("open");
     sei.nShow = SW_SHOWNORMAL;
+    sei.fMask = SEE_MASK_FLAG_NO_UI; // we give error message ourselves
 
-    ::ShellExecuteEx(&sei);
+    BOOL nExecResult = ::ShellExecuteEx(&sei);
 
+    //From MSDN for wince
+    //hInstApp member is only valid if the function fails, in which case it
+    //receives one of the following error values, which are less than or
+    //equal to 32.
     const int nResult = (int) sei.hInstApp;
 
     // Firefox returns file not found for some reason, so make an exception
     // for it
-    if ( nResult > 32 || nResult == SE_ERR_FNF )
+    if ( nResult > 32 || nResult == SE_ERR_FNF  || nExecResult == TRUE )
     {
 #ifdef __WXDEBUG__
         // Log something if SE_ERR_FNF happens
-        if ( nResult == SE_ERR_FNF )
+        if ( nResult == SE_ERR_FNF || nExecResult == FALSE )
             wxLogDebug(wxT("SE_ERR_FNF from ShellExecute -- maybe FireFox?"));
 #endif // __WXDEBUG__
         return true;
@@ -571,8 +838,8 @@ bool wxLaunchDefaultBrowser(const wxString& urlOrig)
 #elif defined(__WXMAC__)
     OSStatus err;
     ICInstance inst;
-    SInt32 startSel;
-    SInt32 endSel;
+    long int startSel;
+    long int endSel;
 
     err = ICStart(&inst, 'STKA'); // put your app creator code here
     if (err == noErr)
@@ -584,7 +851,7 @@ bool wxLaunchDefaultBrowser(const wxString& urlOrig)
         {
             ConstStr255Param hint = 0;
             startSel = 0;
-            endSel = url.Length();
+            endSel = url.length();
             err = ICLaunchURL(inst, hint, url.fn_str(), endSel, &startSel, &endSel);
             if (err != noErr)
                 wxLogDebug(wxT("ICLaunchURL error %d"), (int) err);
@@ -597,11 +864,57 @@ bool wxLaunchDefaultBrowser(const wxString& urlOrig)
         wxLogDebug(wxT("ICStart error %d"), (int) err);
         return false;
     }
-#elif wxUSE_MIMETYPE
-    // Non-windows way
+#else
+    // (non-Mac, non-MSW)
+
+#ifdef __UNIX__
+
+    // Our best best is to use xdg-open from freedesktop.org cross-desktop
+    // compatibility suite xdg-utils
+    // (see http://portland.freedesktop.org/wiki/) -- this is installed on
+    // most modern distributions and may be tweaked by them to handle
+    // distribution specifics. Only if that fails, try to find the right
+    // browser ourselves.
+    wxString path, xdg_open;
+    if ( wxGetEnv(_T("PATH"), &path) &&
+         wxFindFileInPath(&xdg_open, path, _T("xdg-open")) )
+    {
+        if ( wxExecute(xdg_open + _T(" ") + url) )
+            return true;
+    }
+
+    wxString desktop = wxTheApp->GetTraits()->GetDesktopEnvironment();
+
+    // GNOME and KDE desktops have some applications which should be always installed
+    // together with their main parts, which give us the
+    if (desktop == wxT("GNOME"))
+    {
+        wxArrayString errors;
+        wxArrayString output;
+
+        // gconf will tell us the path of the application to use as browser
+        long res = wxExecute( wxT("gconftool-2 --get /desktop/gnome/applications/browser/exec"),
+                              output, errors, wxEXEC_NODISABLE );
+        if (res >= 0 && errors.GetCount() == 0)
+        {
+            wxString cmd = output[0];
+            cmd << _T(' ') << url;
+            if (wxExecute(cmd))
+                return true;
+        }
+    }
+    else if (desktop == wxT("KDE"))
+    {
+        // kfmclient directly opens the given URL
+        if (wxExecute(wxT("kfmclient openURL ") + url))
+            return true;
+    }
+#endif
+
     bool ok = false;
     wxString cmd;
 
+#if wxUSE_MIMETYPE
     wxFileType *ft = wxTheMimeTypesManager->GetFileTypeFromExtension(_T("html"));
     if ( ft )
     {
@@ -611,6 +924,7 @@ bool wxLaunchDefaultBrowser(const wxString& urlOrig)
         ok = ft->GetOpenCommand(&cmd, wxFileType::MessageParameters(url));
         delete ft;
     }
+#endif // wxUSE_MIMETYPE
 
     if ( !ok || cmd.empty() )
     {
@@ -628,6 +942,25 @@ bool wxLaunchDefaultBrowser(const wxString& urlOrig)
     wxLogError(_T("No default application configured for HTML files."));
 
 #endif // !wxUSE_MIMETYPE && !__WXMSW__
+    return false;
+}
+
+bool wxLaunchDefaultBrowser(const wxString& urlOrig, int flags)
+{
+    // set the scheme of url to http if it does not have one
+    // RR: This doesn't work if the url is just a local path
+    wxString url(urlOrig);
+    wxURI uri(url);
+    if ( !uri.HasScheme() )
+    {
+        if (wxFileExists(urlOrig))
+            url.Prepend( wxT("file://") );
+        else
+            url.Prepend(wxT("http://"));
+    }
+
+    if(s_launchBrowserImpl(url, flags))
+        return true;
 
     wxLogSysError(_T("Failed to open URL \"%s\" in default browser."),
                   url.c_str());
@@ -679,15 +1012,18 @@ wxRegisterId (long id)
     wxCurrentId = id + 1;
 }
 
-#if wxUSE_MENUS
-
 // ----------------------------------------------------------------------------
 // Menu accelerators related functions
 // ----------------------------------------------------------------------------
 
 wxChar *wxStripMenuCodes(const wxChar *in, wxChar *out)
 {
+#if wxUSE_MENUS
     wxString s = wxMenuItem::GetLabelFromText(in);
+#else
+    wxString str(in);
+    wxString s = wxStripMenuCodes(str);
+#endif // wxUSE_MENUS
     if ( out )
     {
         // go smash their buffer if it's not big enough - I love char * params
@@ -703,8 +1039,10 @@ wxChar *wxStripMenuCodes(const wxChar *in, wxChar *out)
     return out;
 }
 
-wxString wxStripMenuCodes(const wxString& in)
+wxString wxStripMenuCodes(const wxString& in, int flags)
 {
+    wxASSERT_MSG( flags, _T("this is useless to call without any flags") );
+
     wxString out;
 
     size_t len = in.length();
@@ -713,7 +1051,7 @@ wxString wxStripMenuCodes(const wxString& in)
     for ( size_t n = 0; n < len; n++ )
     {
         wxChar ch = in[n];
-        if ( ch == _T('&') )
+        if ( (flags & wxStrip_Mnemonics) && ch == _T('&') )
         {
             // skip it, it is used to introduce the accel char (or to quote
             // itself in which case it should still be skipped): note that it
@@ -728,7 +1066,7 @@ wxString wxStripMenuCodes(const wxString& in)
                 ch = in[n];
             }
         }
-        else if ( ch == _T('\t') )
+        else if ( (flags & wxStrip_Accel) && ch == _T('\t') )
         {
             // everything after TAB is accel string, exit the loop
             break;
@@ -740,8 +1078,6 @@ wxString wxStripMenuCodes(const wxString& in)
     return out;
 }
 
-#endif // wxUSE_MENUS
-
 // ----------------------------------------------------------------------------
 // Window search functions
 // ----------------------------------------------------------------------------
@@ -776,12 +1112,12 @@ int
 wxFindMenuItemId (wxFrame * frame, const wxString& menuString, const wxString& itemString)
 {
 #if wxUSE_MENUS
-  wxMenuBar *menuBar = frame->GetMenuBar ();
-  if ( menuBar )
-      return menuBar->FindMenuItem (menuString, itemString);
+    wxMenuBar *menuBar = frame->GetMenuBar ();
+    if ( menuBar )
+        return menuBar->FindMenuItem (menuString, itemString);
 #endif // wxUSE_MENUS
 
-  return wxNOT_FOUND;
+    return wxNOT_FOUND;
 }
 
 // Try to find the deepest child that contains 'pt'.
@@ -823,16 +1159,16 @@ wxWindow* wxFindWindowAtPoint(wxWindow* win, const wxPoint& pt)
 
     wxPoint pos = win->GetPosition();
     wxSize sz = win->GetSize();
-    if (win->GetParent())
+    if ( !win->IsTopLevel() && win->GetParent() )
     {
         pos = win->GetParent()->ClientToScreen(pos);
     }
 
     wxRect rect(pos, sz);
-    if (rect.Inside(pt))
+    if (rect.Contains(pt))
         return win;
-    else
-        return NULL;
+
+    return NULL;
 }
 
 wxWindow* wxGenericFindWindowAtPoint(const wxPoint& pt)
@@ -947,7 +1283,7 @@ wxString wxGetPasswordFromUser(const wxString& message,
 
 #if wxUSE_COLOURDLG
 
-wxColour wxGetColourFromUser(wxWindow *parent, const wxColour& colInit)
+wxColour wxGetColourFromUser(wxWindow *parent, const wxColour& colInit, const wxString& caption)
 {
     wxColourData data;
     data.SetChooseFull(true);
@@ -958,6 +1294,8 @@ wxColour wxGetColourFromUser(wxWindow *parent, const wxColour& colInit)
 
     wxColour colRet;
     wxColourDialog dialog(parent, &data);
+    if (!caption.empty())
+        dialog.SetTitle(caption);
     if ( dialog.ShowModal() == wxID_OK )
     {
         colRet = dialog.GetColourData().GetColour();
@@ -971,7 +1309,7 @@ wxColour wxGetColourFromUser(wxWindow *parent, const wxColour& colInit)
 
 #if wxUSE_FONTDLG
 
-wxFont wxGetFontFromUser(wxWindow *parent, const wxFont& fontInit)
+wxFont wxGetFontFromUser(wxWindow *parent, const wxFont& fontInit, const wxString& caption)
 {
     wxFontData data;
     if ( fontInit.Ok() )
@@ -981,6 +1319,8 @@ wxFont wxGetFontFromUser(wxWindow *parent, const wxFont& fontInit)
 
     wxFont fontRet;
     wxFontDialog dialog(parent, data);
+    if (!caption.empty())
+        dialog.SetTitle(caption);
     if ( dialog.ShowModal() == wxID_OK )
     {
         fontRet = dialog.GetFontData().GetChosenFont();
