@@ -3,7 +3,7 @@
 // Purpose:
 // Author:      Robert Roebling
 // Modified by: Mart Raudsepp (GetMetric)
-// Id:          $Id: settings.cpp 48415 2007-08-27 17:26:54Z PC $
+// Id:          $Id: settings.cpp 57542 2008-12-25 13:03:24Z VZ $
 // Copyright:   (c) 1998 Robert Roebling
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -42,16 +42,36 @@ struct wxSystemObjects
              m_colHighlight,
              m_colHighlightText,
              m_colListBox,
+             m_colWindow,
              m_colBtnText,
              m_colMenuItemHighlight,
              m_colTooltip,
-             m_colTooltipText;
+             m_colTooltipText,
+             m_colMenubarBg,
+             m_colListBoxText;
 
     wxFont m_fontSystem;
 };
 
 static wxSystemObjects gs_objects;
 
+void wxClearGtkSystemObjects()
+{
+    gs_objects.m_colBtnFace = wxColour();
+    gs_objects.m_colBtnShadow = wxColour();
+    gs_objects.m_colBtnHighlight = wxColour();
+    gs_objects.m_colHighlightText = wxColour();
+    gs_objects.m_colListBox = wxColour();
+    gs_objects.m_colWindow = wxColour();
+    gs_objects.m_colBtnText = wxColour();
+    gs_objects.m_colMenuItemHighlight = wxColour();
+    gs_objects.m_colTooltip = wxColour();
+    gs_objects.m_colTooltipText = wxColour();
+    gs_objects.m_colMenubarBg = wxColour();
+    gs_objects.m_fontSystem = wxNullFont;
+    gs_objects.m_colListBoxText = wxColour();
+}
+
 // ----------------------------------------------------------------------------
 // wxSystemSettings implementation
 // ----------------------------------------------------------------------------
@@ -61,7 +81,9 @@ enum wxGtkWidgetType
 {
     wxGTK_BUTTON,
     wxGTK_LIST,
-    wxGTK_MENUITEM
+    wxGTK_MENUITEM,
+    wxGTK_TEXTCTRL,
+    wxGTK_MENUBAR, 
 };
 
 // the colour we need
@@ -69,7 +91,8 @@ enum wxGtkColourType
 {
     wxGTK_FG,
     wxGTK_BG,
-    wxGTK_BASE
+    wxGTK_BASE,
+    wxGTK_TEXT
 };
 
 // wxSystemSettings::GetColour() helper: get the colours from a GTK+
@@ -90,6 +113,10 @@ static bool GetColourFromGTKWidget(GdkColor& gdkColor,
             widget = gtk_button_new();
             break;
 
+        case wxGTK_TEXTCTRL:
+            widget = gtk_text_view_new();
+            break;
+
         case wxGTK_LIST:
             widget = gtk_tree_view_new_with_model(
                 (GtkTreeModel*)gtk_list_store_new(1, G_TYPE_INT));
@@ -97,6 +124,11 @@ static bool GetColourFromGTKWidget(GdkColor& gdkColor,
 
         case wxGTK_MENUITEM:
             widget = gtk_menu_item_new();
+            break;
+
+        case wxGTK_MENUBAR:
+            widget = gtk_menu_bar_new();
+            break;
     }
 
     GtkStyle *def = gtk_rc_get_style( widget );
@@ -123,6 +155,10 @@ static bool GetColourFromGTKWidget(GdkColor& gdkColor,
             case wxGTK_BASE:
                 gdkColor = def->base[state];
                 break;
+
+            case wxGTK_TEXT:
+                gdkColor = def->text[state];
+                break;
         }
     }
 
@@ -162,7 +198,6 @@ wxColour wxSystemSettingsNative::GetColour( wxSystemColour index )
         case wxSYS_COLOUR_ACTIVEBORDER:
         case wxSYS_COLOUR_INACTIVEBORDER:
         case wxSYS_COLOUR_BTNFACE:
-        case wxSYS_COLOUR_MENUBAR:
         case wxSYS_COLOUR_3DLIGHT:
             if (!gs_objects.m_colBtnFace.Ok())
             {
@@ -176,7 +211,28 @@ wxColour wxSystemSettingsNative::GetColour( wxSystemColour index )
             break;
 
         case wxSYS_COLOUR_WINDOW:
-            color = *wxWHITE;
+            if (!gs_objects.m_colWindow.Ok())
+            {
+                gdkColor.red =
+                gdkColor.green =
+                gdkColor.blue = 0xFFFF;
+                GetColourFromGTKWidget(gdkColor, wxGTK_TEXTCTRL, GTK_STATE_NORMAL, wxGTK_BASE);
+                gs_objects.m_colWindow = wxColor(gdkColor);
+            }
+            color = gs_objects.m_colWindow;
+            break;
+
+
+        case wxSYS_COLOUR_MENUBAR:
+            if (!gs_objects.m_colMenubarBg.Ok())
+            {
+                gdkColor.red =
+                gdkColor.green = 0;
+                gdkColor.blue = 0x9c40;
+                GetColourFromGTKWidget(gdkColor,wxGTK_MENUBAR);
+                gs_objects.m_colMenubarBg = wxColor(gdkColor);
+            }
+            color = gs_objects.m_colMenubarBg;
             break;
 
         case wxSYS_COLOUR_3DDKSHADOW:
@@ -233,6 +289,24 @@ wxColour wxSystemSettingsNative::GetColour( wxSystemColour index )
             color = gs_objects.m_colListBox;
             break;
 
+        case wxSYS_COLOUR_LISTBOXTEXT:
+            if (!gs_objects.m_colListBoxText.Ok())
+            {
+                if ( GetColourFromGTKWidget(gdkColor,
+                                            wxGTK_LIST,
+                                            GTK_STATE_NORMAL,
+                                            wxGTK_TEXT) )
+                {
+                    gs_objects.m_colListBoxText = wxColour(gdkColor);
+                }
+                else
+                {
+                    gs_objects.m_colListBoxText = GetColour(wxSYS_COLOUR_WINDOWTEXT);
+                }
+            }
+            color = gs_objects.m_colListBoxText;
+            break;
+
         case wxSYS_COLOUR_MENUTEXT:
         case wxSYS_COLOUR_WINDOWTEXT:
         case wxSYS_COLOUR_CAPTIONTEXT:
@@ -267,11 +341,12 @@ wxColour wxSystemSettingsNative::GetColour( wxSystemColour index )
         case wxSYS_COLOUR_HIGHLIGHTTEXT:
             if (!gs_objects.m_colHighlightText.Ok())
             {
-                wxColour hclr = GetColour(wxSYS_COLOUR_HIGHLIGHT);
-                if (hclr.Red() > 200 && hclr.Green() > 200 && hclr.Blue() > 200)
-                    gs_objects.m_colHighlightText = *wxBLACK;
-                else
-                    gs_objects.m_colHighlightText = *wxWHITE;
+                gdkColor.red =
+                gdkColor.green =
+                gdkColor.blue = 0;
+                GetColourFromGTKWidget(
+                    gdkColor, wxGTK_BUTTON, GTK_STATE_SELECTED, wxGTK_FG);
+                gs_objects.m_colHighlightText = wxColour(gdkColor);
             }
             color = gs_objects.m_colHighlightText;
             break;
