@@ -15,7 +15,7 @@
 # Author:      Robin Dunn
 #
 # Created:     23-March-2004
-# RCS-ID:      $Id: config.py 57929 2009-01-09 07:01:08Z RD $
+# RCS-ID:      $Id: config.py 64284 2010-05-10 23:57:53Z RD $
 # Copyright:   (c) 2004 by Total Control Software
 # Licence:     wxWindows license
 #----------------------------------------------------------------------
@@ -49,8 +49,8 @@ import distutils.command.clean
 
 VER_MAJOR        = 2      # The first three must match wxWidgets
 VER_MINOR        = 8
-VER_RELEASE      = 9
-VER_SUBREL       = 2      # wxPython release num for x.y.z release of wxWidgets
+VER_RELEASE      = 11
+VER_SUBREL       = 0      # wxPython release num for x.y.z release of wxWidgets
 VER_FLAGS        = ""     # release flags, such as prerelease or RC num, etc.
 
 DESCRIPTION      = "Cross platform GUI toolkit for Python"
@@ -78,7 +78,7 @@ Environment :: X11 Applications :: GTK
 Intended Audience :: Developers
 License :: OSI Approved
 Operating System :: MacOS :: MacOS X
-Operating System :: Microsoft :: Windows :: Windows 95/98/2000
+Operating System :: Microsoft :: Windows :: Windows 98/2000/XP/Vista
 Operating System :: POSIX
 Programming Language :: Python
 Topic :: Software Development :: User Interfaces
@@ -476,6 +476,21 @@ class wx_extra_clean(distutils.command.clean.clean):
 
 
 
+# The Ubuntu Python adds a --install-layout option to distutils that
+# is used in our package build.  If we detect that the current
+# distutils does not have it then make sure that it is removed from
+# the command-line options, otherwise the build will fail.
+for item in distutils.command.install.install.user_options:
+    if item[0] == 'install-layout=':
+        break
+else:
+    for arg in sys.argv:
+        if arg.startswith('--install-layout'):
+            sys.argv.remove(arg)
+            break
+
+
+
 class wx_install(distutils.command.install.install):
     """
     Turns off install_path_file
@@ -483,7 +498,7 @@ class wx_install(distutils.command.install.install):
     def initialize_options(self):
         distutils.command.install.install.initialize_options(self)
         self.install_path_file = 0
-        
+
 
 class wx_install_headers(distutils.command.install_headers.install_headers):
     """
@@ -892,6 +907,7 @@ if os.name == 'nt' and  COMPILER == 'msvc':
                 ('SWIG_TYPE_TABLE', WXPYTHON_TYPE_TABLE),
                 ('SWIG_PYTHON_OUTPUT_TUPLE', None),
                 ('WXP_USE_THREAD', '1'),
+                ('ISOLATION_AWARE_ENABLED', None),
                 ]
 
     if UNDEF_NDEBUG:
@@ -906,14 +922,13 @@ if os.name == 'nt' and  COMPILER == 'msvc':
     if UNICODE:
         defines.append( ('wxUSE_UNICODE', 1) )
 
-    #if True:  # Should it be only for 2.6+??
-    #    defines.append( ('ISOLATION_AWARE_ENABLED', None) )
 
+    libs = []
     libdirs = [ opj(WXDIR, 'lib', VCDLL) ]
     if MONOLITHIC:
-        libs = makeLibName('')
+        libs += makeLibName('')
     else:
-        libs = [ 'wxbase' + WXDLLVER + libFlag(), 
+        libs += [ 'wxbase' + WXDLLVER + libFlag(), 
                  'wxbase' + WXDLLVER + libFlag() + '_net',
                  'wxbase' + WXDLLVER + libFlag() + '_xml',
                  makeLibName('core')[0],
@@ -921,16 +936,15 @@ if os.name == 'nt' and  COMPILER == 'msvc':
                  makeLibName('html')[0],
                  ]
 
-    libs = libs + ['kernel32', 'user32', 'gdi32', 'comdlg32',
-            'winspool', 'winmm', 'shell32', 'oldnames', 'comctl32',
-            'odbc32', 'ole32', 'oleaut32', 'uuid', 'rpcrt4',
-            'advapi32', 'wsock32']
-
+    libs += ['kernel32', 'user32', 'gdi32', 'comdlg32',
+             'winspool', 'winmm', 'shell32', 'oldnames', 'comctl32',
+             'odbc32', 'ole32', 'oleaut32', 'uuid', 'rpcrt4',
+             'advapi32', 'wsock32']
 
     cflags = [ '/Gy',
-             # '/GX-'  # workaround for internal compiler error in MSVC on some machines
                '/EHsc',
-             ]
+               # '/GX-'  # workaround for internal compiler error in MSVC on some machines
+               ]
     lflags = None
 
     # Other MSVC flags...
@@ -939,10 +953,6 @@ if os.name == 'nt' and  COMPILER == 'msvc':
     #lflags = ['/DEBUG', ]
 
 
-# export MSSdk=1
-# export DISTUTILS_USE_SDK=1
-
-
 #----------------------------------------------------------------------
 
 elif os.name == 'posix' or COMPILER == 'mingw32':
@@ -1007,6 +1017,10 @@ elif os.name == 'posix' or COMPILER == 'mingw32':
             #    cflags.append("-isysroot")
             #    cflags.append("/Developer/SDKs/MacOSX10.3.9.sdk")
 
+        if not os.environ.get('CC') or not os.environ.get('CXX'):
+            os.environ["CXX"] = "g++-4.0"
+            os.environ["CC"]  = "gcc-4.0"
+            os.environ["CPP"] = "cpp-4.0"
 
     else:
         # Set flags for other Unix type platforms
