@@ -33,9 +33,10 @@ MENU_SHOW_IMAGES = wx.NewId()
 MENU_USE_VC71_STYLE = wx.NewId()
 MENU_USE_DEFAULT_STYLE = wx.NewId()
 MENU_USE_FANCY_STYLE = wx.NewId()
-MENU_SELECT_GRADIENT_COLOR_FROM = wx.NewId()
-MENU_SELECT_GRADIENT_COLOR_TO = wx.NewId()
-MENU_SELECT_GRADIENT_COLOR_BORDER = wx.NewId()
+MENU_USE_RIBBON_STYLE = wx.NewId()
+MENU_SELECT_GRADIENT_COLOUR_FROM = wx.NewId()
+MENU_SELECT_GRADIENT_COLOUR_TO = wx.NewId()
+MENU_SELECT_GRADIENT_COLOUR_BORDER = wx.NewId()
 MENU_SET_PAGE_IMAGE_INDEX = wx.NewId()
 MENU_HIDE_X = wx.NewId()
 MENU_HIDE_NAV_BUTTONS = wx.NewId()
@@ -49,15 +50,16 @@ MENU_DCLICK_CLOSES_TAB = wx.NewId()
 MENU_USE_VC8_STYLE = wx.NewId()
 MENU_USE_FF2_STYLE = wx.NewId()
 MENU_HIDE_ON_SINGLE_TAB = wx.NewId()
+MENU_NO_TABS_FOCUS = wx.NewId()
 
-MENU_SET_ACTIVE_TEXT_COLOR = wx.NewId()
+MENU_SET_ACTIVE_TEXT_COLOUR = wx.NewId()
 MENU_DRAW_TAB_X = wx.NewId()
-MENU_SET_ACTIVE_TAB_COLOR = wx.NewId()
-MENU_SET_TAB_AREA_COLOR = wx.NewId()
-MENU_SELECT_NONACTIVE_TEXT_COLOR = wx.NewId()
+MENU_SET_ACTIVE_TAB_COLOUR = wx.NewId()
+MENU_SET_TAB_AREA_COLOUR = wx.NewId()
+MENU_SELECT_NONACTIVE_TEXT_COLOUR = wx.NewId()
 MENU_GRADIENT_BACKGROUND = wx.NewId()
-MENU_COLORFUL_TABS = wx.NewId()
-MENU_SMART_TABS	= wx.NewId()
+MENU_COLOURFUL_TABS = wx.NewId()
+MENU_SMART_TABS = wx.NewId()
 MENU_USE_DROP_ARROW_BUTTON = wx.NewId()
 MENU_ALLOW_FOREIGN_DND = wx.NewId()
 
@@ -95,7 +97,9 @@ class FlatNotebookDemo(wx.Frame):
         self.Bind(fnb.EVT_FLATNOTEBOOK_PAGE_CHANGING, self.OnPageChanging)
         self.Bind(fnb.EVT_FLATNOTEBOOK_PAGE_CHANGED, self.OnPageChanged)
         self.Bind(fnb.EVT_FLATNOTEBOOK_PAGE_CLOSING, self.OnPageClosing)
-
+        self.Bind(fnb.EVT_FLATNOTEBOOK_PAGE_DROPPED_FOREIGN, self.OnForeignDrop)
+        self.Bind(fnb.EVT_FLATNOTEBOOK_PAGE_DROPPED, self.OnDrop)
+        
         self.Bind(wx.EVT_UPDATE_UI, self.OnDropDownArrowUI, id=MENU_USE_DROP_ARROW_BUTTON)
         self.Bind(wx.EVT_UPDATE_UI, self.OnHideNavigationButtonsUI, id=MENU_HIDE_NAV_BUTTONS)
         self.Bind(wx.EVT_UPDATE_UI, self.OnAllowForeignDndUI, id=MENU_ALLOW_FOREIGN_DND)
@@ -172,31 +176,40 @@ class FlatNotebookDemo(wx.Frame):
         item = wx.MenuItem(styleMenu, MENU_USE_FF2_STYLE, "Use Firefox 2 Style", "Use Firefox 2 Style", wx.ITEM_RADIO)
         self.Bind(wx.EVT_MENU, self.OnFF2Style, item)
         styleMenu.AppendItem(item)
+        
+        item = wx.MenuItem(styleMenu, MENU_USE_RIBBON_STYLE, "Use Ribbon Style", "Use Ribbon Style", wx.ITEM_RADIO)
+        self.Bind(wx.EVT_MENU, self.OnRibbonStyle, item)
+        styleMenu.AppendItem(item)
 
         self._visualMenu.AppendMenu(wx.ID_ANY, "Tabs Style", styleMenu)
 
-        item = wx.MenuItem(self._visualMenu, MENU_SELECT_GRADIENT_COLOR_FROM, "Select fancy tab style 'from' color",
-                           "Select fancy tab style 'from' color")
+        item = wx.MenuItem(self._visualMenu, MENU_SELECT_GRADIENT_COLOUR_FROM, "Select fancy tab style 'from' colour",
+                           "Select fancy tab style 'from' colour")
         self._visualMenu.AppendItem(item)
 
-        item = wx.MenuItem(self._visualMenu, MENU_SELECT_GRADIENT_COLOR_TO, "Select fancy tab style 'to' color",
-                           "Select fancy tab style 'to' color")
+        item = wx.MenuItem(self._visualMenu, MENU_SELECT_GRADIENT_COLOUR_TO, "Select fancy tab style 'to' colour",
+                           "Select fancy tab style 'to' colour")
         self._visualMenu.AppendItem(item)
 
-        item = wx.MenuItem(self._visualMenu, MENU_SELECT_GRADIENT_COLOR_BORDER, "Select fancy tab style 'border' color",
-                           "Select fancy tab style 'border' color")
+        item = wx.MenuItem(self._visualMenu, MENU_SELECT_GRADIENT_COLOUR_BORDER, "Select fancy tab style 'border' colour",
+                           "Select fancy tab style 'border' colour")
         self._visualMenu.AppendItem(item)
 
         self._editMenu.AppendSeparator()        
 
-        self.Bind(wx.EVT_MENU_RANGE, self.OnSelectColor, id=MENU_SELECT_GRADIENT_COLOR_FROM,
-                  id2=MENU_SELECT_GRADIENT_COLOR_BORDER)        
+        self.Bind(wx.EVT_MENU_RANGE, self.OnSelectColour, id=MENU_SELECT_GRADIENT_COLOUR_FROM,
+                  id2=MENU_SELECT_GRADIENT_COLOUR_BORDER)        
 
         item = wx.MenuItem(self._editMenu, MENU_HIDE_ON_SINGLE_TAB, "Hide Page Container when only one Tab",
                            "Hide Page Container when only one Tab", wx.ITEM_CHECK)
         self.Bind(wx.EVT_MENU, self.OnStyle, item)
         self._editMenu.AppendItem(item)
 
+        item = wx.MenuItem(self._editMenu, MENU_NO_TABS_FOCUS, "No focus on notebook tabs",
+                           "No focus on notebook tabs, only pages", wx.ITEM_CHECK)
+        self.Bind(wx.EVT_MENU, self.OnStyle, item)
+        self._editMenu.AppendItem(item)
+
         item = wx.MenuItem(self._editMenu, MENU_HIDE_NAV_BUTTONS, "Hide Navigation Buttons",
                            "Hide Navigation Buttons", wx.ITEM_CHECK)
         self._editMenu.AppendItem(item)
@@ -265,34 +278,34 @@ class FlatNotebookDemo(wx.Frame):
         self.Bind(wx.EVT_MENU, self.OnDrawTabX, item)
         self._visualMenu.AppendItem(item)
 
-        item = wx.MenuItem(self._visualMenu, MENU_SET_ACTIVE_TAB_COLOR, "Select Active Tab Color",
-                           "Select Active Tab Color")
-        self.Bind(wx.EVT_MENU, self.OnSelectColor, item)
+        item = wx.MenuItem(self._visualMenu, MENU_SET_ACTIVE_TAB_COLOUR, "Select Active Tab Colour",
+                           "Select Active Tab Colour")
+        self.Bind(wx.EVT_MENU, self.OnSelectColour, item)
         self._visualMenu.AppendItem(item)
 
-        item = wx.MenuItem(self._visualMenu, MENU_SET_TAB_AREA_COLOR, "Select Tab Area Color",
-                           "Select Tab Area Color")
-        self.Bind(wx.EVT_MENU, self.OnSelectColor, item)
+        item = wx.MenuItem(self._visualMenu, MENU_SET_TAB_AREA_COLOUR, "Select Tab Area Colour",
+                           "Select Tab Area Colour")
+        self.Bind(wx.EVT_MENU, self.OnSelectColour, item)
         self._visualMenu.AppendItem(item)
 
-        item = wx.MenuItem(self._visualMenu, MENU_SET_ACTIVE_TEXT_COLOR, "Select active tab text color",
-                           "Select active tab text color")
-        self.Bind(wx.EVT_MENU, self.OnSelectColor, item)
+        item = wx.MenuItem(self._visualMenu, MENU_SET_ACTIVE_TEXT_COLOUR, "Select active tab text colour",
+                           "Select active tab text colour")
+        self.Bind(wx.EVT_MENU, self.OnSelectColour, item)
         self._visualMenu.AppendItem(item)
 
-        item = wx.MenuItem(self._visualMenu, MENU_SELECT_NONACTIVE_TEXT_COLOR,
-                           "Select NON-active tab text color", "Select NON-active tab text color")
-        self.Bind(wx.EVT_MENU, self.OnSelectColor, item)
+        item = wx.MenuItem(self._visualMenu, MENU_SELECT_NONACTIVE_TEXT_COLOUR,
+                           "Select NON-active tab text colour", "Select NON-active tab text colour")
+        self.Bind(wx.EVT_MENU, self.OnSelectColour, item)
         self._visualMenu.AppendItem(item)
 
-        item = wx.MenuItem(self._visualMenu, MENU_GRADIENT_BACKGROUND, "Use Gradient Coloring for tab area",
-                           "Use Gradient Coloring for tab area", wx.ITEM_CHECK)
+        item = wx.MenuItem(self._visualMenu, MENU_GRADIENT_BACKGROUND, "Use Gradient Colouring for tab area",
+                           "Use Gradient Colouring for tab area", wx.ITEM_CHECK)
         self.Bind(wx.EVT_MENU, self.OnGradientBack, item)
         self._visualMenu.AppendItem(item)
         item.Check(False)
 
-        item = wx.MenuItem(self._visualMenu, MENU_COLORFUL_TABS, "Colorful tabs", "Colorful tabs", wx.ITEM_CHECK)
-        self.Bind(wx.EVT_MENU, self.OnColorfulTabs, item)
+        item = wx.MenuItem(self._visualMenu, MENU_COLOURFUL_TABS, "Colourful tabs", "Colourful tabs", wx.ITEM_CHECK)
+        self.Bind(wx.EVT_MENU, self.OnColourfulTabs, item)
         self._visualMenu.AppendItem(item)
         item.Check(False)
 
@@ -324,11 +337,11 @@ class FlatNotebookDemo(wx.Frame):
 
         bookStyle = fnb.FNB_NODRAG
 
-        self.book = fnb.FlatNotebook(self, wx.ID_ANY, style=bookStyle)
+        self.book = fnb.FlatNotebook(self, wx.ID_ANY, agwStyle=bookStyle)
 
         bookStyle &= ~(fnb.FNB_NODRAG)
         bookStyle |= fnb.FNB_ALLOW_FOREIGN_DND 
-        self.secondBook = fnb.FlatNotebook(self, wx.ID_ANY, style=bookStyle)
+        self.secondBook = fnb.FlatNotebook(self, wx.ID_ANY, agwStyle=bookStyle)
 
         # Set right click menu to the notebook
         self.book.SetRightClickMenu(self._rmenu)
@@ -353,7 +366,7 @@ class FlatNotebookDemo(wx.Frame):
         text = wx.TextCtrl(self.secondBook, -1, "Second Book Page 2\n", style=wx.TE_MULTILINE|wx.TE_READONLY)
         self.secondBook.AddPage(text,  "Second Book Page 2")
 
-        self.Thaw()	
+        self.Thaw() 
 
         mainSizer.Layout()
         self.SendSizeEvent()
@@ -361,7 +374,7 @@ class FlatNotebookDemo(wx.Frame):
 
     def OnStyle(self, event):
 
-        style = self.book.GetWindowStyleFlag()
+        style = self.book.GetAGWWindowStyleFlag()
         eventid = event.GetId()
 
         if eventid == MENU_HIDE_NAV_BUTTONS:
@@ -372,7 +385,7 @@ class FlatNotebookDemo(wx.Frame):
                 style &= ~fnb.FNB_NO_NAV_BUTTONS
                 style &= ~fnb.FNB_DROPDOWN_TABS_LIST
 
-            self.book.SetWindowStyleFlag(style)
+            self.book.SetAGWWindowStyleFlag(style)
 
         elif eventid == MENU_HIDE_ON_SINGLE_TAB:
             if event.IsChecked():
@@ -381,7 +394,7 @@ class FlatNotebookDemo(wx.Frame):
             else:
                 style &= ~(fnb.FNB_HIDE_ON_SINGLE_TAB)
 
-            self.book.SetWindowStyleFlag(style)
+            self.book.SetAGWWindowStyleFlag(style)
 
         elif eventid == MENU_HIDE_X:
             if event.IsChecked():
@@ -391,7 +404,7 @@ class FlatNotebookDemo(wx.Frame):
                 if style & fnb.FNB_NO_X_BUTTON:
                     style ^= fnb.FNB_NO_X_BUTTON
 
-            self.book.SetWindowStyleFlag(style)
+            self.book.SetAGWWindowStyleFlag(style)
 
         elif eventid == MENU_DRAW_BORDER:
             if event.IsChecked():
@@ -400,7 +413,7 @@ class FlatNotebookDemo(wx.Frame):
                 if style & fnb.FNB_TABS_BORDER_SIMPLE:
                     style ^= fnb.FNB_TABS_BORDER_SIMPLE
 
-            self.book.SetWindowStyleFlag(style)
+            self.book.SetAGWWindowStyleFlag(style)
 
         elif eventid == MENU_USE_MOUSE_MIDDLE_BTN:
             if event.IsChecked():
@@ -409,7 +422,7 @@ class FlatNotebookDemo(wx.Frame):
                 if style & fnb.FNB_MOUSE_MIDDLE_CLOSES_TABS:
                     style ^= fnb.FNB_MOUSE_MIDDLE_CLOSES_TABS
 
-            self.book.SetWindowStyleFlag(style)
+            self.book.SetAGWWindowStyleFlag(style)
 
         elif eventid == MENU_USE_BOTTOM_TABS:
             if event.IsChecked():
@@ -418,9 +431,18 @@ class FlatNotebookDemo(wx.Frame):
                 if style & fnb.FNB_BOTTOM:
                     style ^= fnb.FNB_BOTTOM
 
-            self.book.SetWindowStyleFlag(style)
+            self.book.SetAGWWindowStyleFlag(style)
             self.book.Refresh()
 
+        elif eventid == MENU_NO_TABS_FOCUS:
+            if event.IsChecked():
+                # Hide the navigation buttons
+                style |= fnb.FNB_NO_TAB_FOCUS
+            else:
+                style &= ~(fnb.FNB_NO_TAB_FOCUS)
+
+            self.book.SetAGWWindowStyleFlag(style)
+
 
     def OnQuit(self, event):
 
@@ -437,93 +459,119 @@ class FlatNotebookDemo(wx.Frame):
         self._bShowImages = event.IsChecked()
 
 
+    def OnForeignDrop(self, event):
+
+        self.log.write('Foreign drop received\n')
+        self.log.write('new NB: %s  ||  old NB: %s\n' % (event.GetNotebook(), event.GetOldNotebook()))
+        self.log.write('new tab: %s  ||  old tab: %s\n' % (event.GetSelection(), event.GetOldSelection()))
+        
+
+    def OnDrop(self, event):
+
+        self.log.write('Drop received - same notebook\n')
+        self.log.write('new: %s old: %s\n' % (event.GetSelection(), event.GetOldSelection()))
+
+
     def OnFF2Style(self, event):
 
-        style = self.book.GetWindowStyleFlag()
+        style = self.book.GetAGWWindowStyleFlag()
 
         # remove old tabs style
-        mirror = ~(fnb.FNB_VC71 | fnb.FNB_VC8 | fnb.FNB_FANCY_TABS | fnb.FNB_FF2)
+        mirror = ~(fnb.FNB_VC71 | fnb.FNB_VC8 | fnb.FNB_FANCY_TABS | fnb.FNB_FF2 | fnb.FNB_RIBBON_TABS)
         style &= mirror
 
         style |= fnb.FNB_FF2
 
-        self.book.SetWindowStyleFlag(style)
+        self.book.SetAGWWindowStyleFlag(style)
 
 
     def OnVC71Style(self, event):
 
-        style = self.book.GetWindowStyleFlag()
+        style = self.book.GetAGWWindowStyleFlag()
 
         # remove old tabs style
-        mirror = ~(fnb.FNB_VC71 | fnb.FNB_VC8 | fnb.FNB_FANCY_TABS | fnb.FNB_FF2)
+        mirror = ~(fnb.FNB_VC71 | fnb.FNB_VC8 | fnb.FNB_FANCY_TABS | fnb.FNB_FF2 | fnb.FNB_RIBBON_TABS)
         style &= mirror
 
         style |= fnb.FNB_VC71
 
-        self.book.SetWindowStyleFlag(style)
+        self.book.SetAGWWindowStyleFlag(style)
 
 
     def OnVC8Style(self, event):
 
-        style = self.book.GetWindowStyleFlag()
+        style = self.book.GetAGWWindowStyleFlag()
 
         # remove old tabs style
-        mirror = ~(fnb.FNB_VC71 | fnb.FNB_VC8 | fnb.FNB_FANCY_TABS | fnb.FNB_FF2)
+        mirror = ~(fnb.FNB_VC71 | fnb.FNB_VC8 | fnb.FNB_FANCY_TABS | fnb.FNB_FF2 | fnb.FNB_RIBBON_TABS)
         style &= mirror
 
         # set new style
         style |= fnb.FNB_VC8
 
-        self.book.SetWindowStyleFlag(style)
+        self.book.SetAGWWindowStyleFlag(style)
+        
+    def OnRibbonStyle(self, event):
+
+        style = self.book.GetAGWWindowStyleFlag()
+
+        # remove old tabs style
+        mirror = ~(fnb.FNB_VC71 | fnb.FNB_VC8 | fnb.FNB_FANCY_TABS | fnb.FNB_FF2 | fnb.FNB_RIBBON_TABS)
+        style &= mirror
+
+        # set new style
+        style |= fnb.FNB_RIBBON_TABS
+
+        self.book.SetAGWWindowStyleFlag(style)
 
 
     def OnDefaultStyle(self, event):
 
-        style = self.book.GetWindowStyleFlag()
+        style = self.book.GetAGWWindowStyleFlag()
 
         # remove old tabs style
-        mirror = ~(fnb.FNB_VC71 | fnb.FNB_VC8 | fnb.FNB_FANCY_TABS | fnb.FNB_FF2)
+        mirror = ~(fnb.FNB_VC71 | fnb.FNB_VC8 | fnb.FNB_FANCY_TABS | fnb.FNB_FF2 | fnb.FNB_RIBBON_TABS)
         style &= mirror
 
-        self.book.SetWindowStyleFlag(style)
+        self.book.SetAGWWindowStyleFlag(style)
 
 
     def OnFancyStyle(self, event):
 
-        style = self.book.GetWindowStyleFlag()
+        style = self.book.GetAGWWindowStyleFlag()
 
         # remove old tabs style
-        mirror = ~(fnb.FNB_VC71 | fnb.FNB_VC8 | fnb.FNB_FANCY_TABS | fnb.FNB_FF2)
+        mirror = ~(fnb.FNB_VC71 | fnb.FNB_VC8 | fnb.FNB_FANCY_TABS | fnb.FNB_FF2 | fnb.FNB_RIBBON_TABS)
         style &= mirror
 
         style |= fnb.FNB_FANCY_TABS
-        self.book.SetWindowStyleFlag(style)
+        self.book.SetAGWWindowStyleFlag(style)
+        
 
-
-    def OnSelectColor(self, event):
+    def OnSelectColour(self, event):
 
         eventid = event.GetId()
 
-        # Open a color dialog
+        # Open a colour dialog
         data = wx.ColourData()
 
         dlg = wx.ColourDialog(self, data)
 
         if dlg.ShowModal() == wx.ID_OK:
 
-            if eventid == MENU_SELECT_GRADIENT_COLOR_BORDER:
+            if eventid == MENU_SELECT_GRADIENT_COLOUR_BORDER:
                 self.book.SetGradientColourBorder(dlg.GetColourData().GetColour())
-            elif eventid == MENU_SELECT_GRADIENT_COLOR_FROM:
+            elif eventid == MENU_SELECT_GRADIENT_COLOUR_FROM:
                 self.book.SetGradientColourFrom(dlg.GetColourData().GetColour())
-            elif eventid == MENU_SELECT_GRADIENT_COLOR_TO:
+            elif eventid == MENU_SELECT_GRADIENT_COLOUR_TO:
                 self.book.SetGradientColourTo(dlg.GetColourData().GetColour())
-            elif eventid == MENU_SET_ACTIVE_TEXT_COLOR:
+            elif eventid == MENU_SET_ACTIVE_TEXT_COLOUR:
                 self.book.SetActiveTabTextColour(dlg.GetColourData().GetColour())
-            elif eventid == MENU_SELECT_NONACTIVE_TEXT_COLOR:
+            elif eventid == MENU_SELECT_NONACTIVE_TEXT_COLOUR:
                 self.book.SetNonActiveTabTextColour(dlg.GetColourData().GetColour())
-            elif eventid == MENU_SET_ACTIVE_TAB_COLOR:
+            elif eventid == MENU_SET_ACTIVE_TAB_COLOUR:
                 self.book.SetActiveTabColour(dlg.GetColourData().GetColour())
-            elif eventid == MENU_SET_TAB_AREA_COLOR:
+            elif eventid == MENU_SET_TAB_AREA_COLOUR:
                 self.book.SetTabAreaColour(dlg.GetColourData().GetColour())
 
             self.book.Refresh()
@@ -574,7 +622,7 @@ class FlatNotebookDemo(wx.Frame):
         if dlg.ShowModal() == wx.ID_OK:
 
             val = dlg.GetValue()
-            self.book.EnableTab(int(val))	
+            self.book.EnableTab(int(val))   
 
 
     def OnDisableTab(self, event):
@@ -584,13 +632,13 @@ class FlatNotebookDemo(wx.Frame):
         if dlg.ShowModal() == wx.ID_OK:
 
             val = dlg.GetValue()
-            self.book.EnableTab(int(val), False)	
+            self.book.EnableTab(int(val), False)    
 
 
     def OnEnableDrag(self, event):
 
-        style = self.book.GetWindowStyleFlag()
-        style2 = self.secondBook.GetWindowStyleFlag()
+        style = self.book.GetAGWWindowStyleFlag()
+        style2 = self.secondBook.GetAGWWindowStyleFlag()
 
         if event.IsChecked():        
             if style & fnb.FNB_NODRAG:
@@ -601,19 +649,19 @@ class FlatNotebookDemo(wx.Frame):
             style |= fnb.FNB_NODRAG
             style2 |= fnb.FNB_NODRAG
 
-        self.book.SetWindowStyleFlag(style)
-        self.secondBook.SetWindowStyleFlag(style2)
+        self.book.SetAGWWindowStyleFlag(style)
+        self.secondBook.SetAGWWindowStyleFlag(style2)
 
 
     def OnAllowForeignDnd(self, event): 
 
-        style = self.book.GetWindowStyleFlag()
+        style = self.book.GetAGWWindowStyleFlag()
         if event.IsChecked():
             style |= fnb.FNB_ALLOW_FOREIGN_DND 
         else:
             style &= ~(fnb.FNB_ALLOW_FOREIGN_DND)
 
-        self.book.SetWindowStyleFlag(style)
+        self.book.SetAGWWindowStyleFlag(style)
         self.book.Refresh() 
 
 
@@ -665,66 +713,66 @@ class FlatNotebookDemo(wx.Frame):
 
     def OnDrawTabX(self, event):
 
-        style = self.book.GetWindowStyleFlag()
+        style = self.book.GetAGWWindowStyleFlag()
         if event.IsChecked():
             style |= fnb.FNB_X_ON_TAB
         else:
             if style & fnb.FNB_X_ON_TAB:
-                style ^= fnb.FNB_X_ON_TAB		
+                style ^= fnb.FNB_X_ON_TAB       
 
-        self.book.SetWindowStyleFlag(style)
+        self.book.SetAGWWindowStyleFlag(style)
 
 
     def OnDClickCloseTab(self, event):
 
-        style = self.book.GetWindowStyleFlag()
+        style = self.book.GetAGWWindowStyleFlag()
         if event.IsChecked():       
             style |= fnb.FNB_DCLICK_CLOSES_TABS
         else:
-            style &= ~(fnb.FNB_DCLICK_CLOSES_TABS)		
+            style &= ~(fnb.FNB_DCLICK_CLOSES_TABS)      
 
-        self.book.SetWindowStyleFlag(style)
+        self.book.SetAGWWindowStyleFlag(style)
 
 
     def OnGradientBack(self, event):
 
-        style = self.book.GetWindowStyleFlag()
+        style = self.book.GetAGWWindowStyleFlag()
         if event.IsChecked():
             style |= fnb.FNB_BACKGROUND_GRADIENT
         else:
             style &= ~(fnb.FNB_BACKGROUND_GRADIENT)
 
-        self.book.SetWindowStyleFlag(style)
+        self.book.SetAGWWindowStyleFlag(style)
         self.book.Refresh()
 
 
-    def OnColorfulTabs(self, event):
+    def OnColourfulTabs(self, event):
 
-        style = self.book.GetWindowStyleFlag()
+        style = self.book.GetAGWWindowStyleFlag()
         if event.IsChecked():
-            style |= fnb.FNB_COLORFUL_TABS
+            style |= fnb.FNB_COLOURFUL_TABS
         else:
-            style &= ~(fnb.FNB_COLORFUL_TABS)
+            style &= ~(fnb.FNB_COLOURFUL_TABS)
 
-        self.book.SetWindowStyleFlag(style)
+        self.book.SetAGWWindowStyleFlag(style)
         self.book.Refresh()
 
 
     def OnSmartTabs(self, event):
 
-        style = self.book.GetWindowStyleFlag()
+        style = self.book.GetAGWWindowStyleFlag()
         if event.IsChecked():
             style |= fnb.FNB_SMART_TABS
         else:
             style &= ~fnb.FNB_SMART_TABS
 
-        self.book.SetWindowStyleFlag(style)
+        self.book.SetAGWWindowStyleFlag(style)
         self.book.Refresh()
 
 
     def OnDropDownArrow(self, event):
 
-        style = self.book.GetWindowStyleFlag()
+        style = self.book.GetAGWWindowStyleFlag()
 
         if event.IsChecked():
 
@@ -736,25 +784,25 @@ class FlatNotebookDemo(wx.Frame):
             style &= ~fnb.FNB_DROPDOWN_TABS_LIST
             style &= ~fnb.FNB_NO_NAV_BUTTONS
 
-        self.book.SetWindowStyleFlag(style)
+        self.book.SetAGWWindowStyleFlag(style)
         self.book.Refresh()
 
 
     def OnHideNavigationButtonsUI(self, event):
 
-        style = self.book.GetWindowStyleFlag()
+        style = self.book.GetAGWWindowStyleFlag()
         event.Check((style & fnb.FNB_NO_NAV_BUTTONS and [True] or [False])[0])
 
 
     def OnDropDownArrowUI(self, event):
 
-        style = self.book.GetWindowStyleFlag()
+        style = self.book.GetAGWWindowStyleFlag()
         event.Check((style & fnb.FNB_DROPDOWN_TABS_LIST and [True] or [False])[0])
 
 
     def OnAllowForeignDndUI(self, event): 
 
-        style = self.book.GetWindowStyleFlag()
+        style = self.book.GetAGWWindowStyleFlag()
         event.Enable((style & fnb.FNB_NODRAG and [False] or [True])[0])
 
 
