@@ -3,7 +3,7 @@
 # Python Code By:
 #
 # Andrea Gavana, @ 29 May 2005
-# Latest Revision: 15 Oct 2008, 10.00 GMT
+# Latest Revision: 23 Nov 2009, 09.00 GMT
 #
 #
 # TODO List/Caveats
@@ -30,8 +30,8 @@
 # For All Kind Of Problems, Requests Of Enhancements And Bug Reports, Please
 # Write To Me At:
 #
-# andrea.gavana@agip.it
-# andrea_gavan@tin.it
+# andrea.gavana@gmail.com
+# gavana@kpo.kz
 #
 # Or, Obviously, To The wxPython Mailing List!!!
 #
@@ -40,10 +40,15 @@
 # --------------------------------------------------------------------------- #
 
 """
-Description:
+BalloonTip is a class that allows you to display tooltips in a balloon style
+window.
+
+
+Description
+===========
 
 BalloonTip is a class that allows you to display tooltips in a balloon style
-window (actually a frame), similarly to the windows xp balloon help. There is
+window (actually a frame), similarly to the windows XP balloon help. There is
 also an arrow that points to the center of the control designed as a "target"
 for the BalloonTip.
 
@@ -61,51 +66,81 @@ What it can do:
 - Possibility to set the delay after which the BalloonTip is destroyed;
 - Three different behaviors for the BalloonTip window (regardless the delay
   destruction time set):
+  
   a) Destroy by leave: the BalloonTip is destroyed when the mouse leaves the
      target control/window;
   b) Destroy by click: the BalloonTip is destroyed when you click on any area
      of the target control/window;
   c) Destroy by button: the BalloonTip is destroyed when you click on the
      top-right close button;
-- Possibility to enable/disable globally the BalloonTip on you application.
-- Set the BalloonTip also for the taskbaricon (revised 7 september 2005)
+- Possibility to enable/disable globally the BalloonTip on you application;
+- Set the BalloonTip also for the taskbar icon.
 
 
-Usage example:
+Usage
+=====
 
-# let's suppose that in your application you have a wx.TextCtrl defined as:
+Usage example::
 
-mytextctrl = wx.TextCtrl(panel, -1, "i am a textctrl")
+    # let's suppose that in your application you have a wx.TextCtrl defined as:
 
-# you can define your BalloonTip as follows:
+    mytextctrl = wx.TextCtrl(panel, -1, "i am a textctrl")
 
-tipballoon = BalloonTip(topicon=None, toptitle="textctrl",
-                        message="this is a textctrl",
-                        shape=BT_ROUNDED,
-                        tipstyle=BT_LEAVE)
+    # you can define your BalloonTip as follows:
 
-# set the BalloonTip target
-tipballoon.SetTarget(mytextctrl)
-# set the BalloonTip background colour
-tipballoon.SetBalloonColour(wx.white)
-# set the font for the balloon title
-tipballoon.SetTitleFont(wx.Font(9, wx.SWISS, wx.NORMAL, wx.BOLD, False))
-# set the colour for the balloon title
-tipballoon.SetTitleColour(wx.BLACK)
-# leave the message font as default
-tipballoon.SetMessageFont()
-# set the message (tip) foreground colour
-tipballoon.SetMessageColour(wx.LIGHT_GREY)
-# set the start delay for the BalloonTip
-tipballoon.SetStartDelay(1000)
-# set the time after which the BalloonTip is destroyed
-tipballoon.SetEndDelay(3000)
+    tipballoon = BalloonTip(topicon=None, toptitle="textctrl",
+                            message="this is a textctrl",
+                            shape=BT_ROUNDED,
+                            tipstyle=BT_LEAVE)
+
+    # set the BalloonTip target
+    tipballoon.SetTarget(mytextctrl)
+    # set the BalloonTip background colour
+    tipballoon.SetBalloonColour(wx.white)
+    # set the font for the balloon title
+    tipballoon.SetTitleFont(wx.Font(9, wx.SWISS, wx.NORMAL, wx.BOLD, False))
+    # set the colour for the balloon title
+    tipballoon.SetTitleColour(wx.BLACK)
+    # leave the message font as default
+    tipballoon.SetMessageFont()
+    # set the message (tip) foreground colour
+    tipballoon.SetMessageColour(wx.LIGHT_GREY)
+    # set the start delay for the BalloonTip
+    tipballoon.SetStartDelay(1000)
+    # set the time after which the BalloonTip is destroyed
+    tipballoon.SetEndDelay(3000)
 
 
-BalloonTip is freeware and distributed under the wxPython license.
+Window Styles
+=============
 
-Latest revision: Andrea Gavana @ 15 Oct 2008, 10.00 GMT
-Version 0.1
+This class supports the following window styles:
+
+================ =========== ==================================================
+Window Styles    Hex Value   Description
+================ =========== ==================================================
+``BT_ROUNDED``           0x1 `BalloonTip` will have a rounded rectangular shape.
+``BT_RECTANGLE``         0x2 `BalloonTip` will have a rectangular shape.
+``BT_LEAVE``             0x3 `BalloonTip` will be destroyed when the user moves the mouse outside the target window.
+``BT_CLICK``             0x4 `BalloonTip` will be destroyed when the user click on `BalloonTip`.
+``BT_BUTTON``            0x5 `BalloonTip` will be destroyed when the user click on the close button.
+================ =========== ==================================================
+
+
+Events Processing
+=================
+
+`No custom events are available for this class.`
+
+
+License And Version
+===================
+
+BalloonTip is distributed under the wxPython license.
+
+Latest revision: Andrea Gavana @ 23 Nov 2009, 09.00 GMT
+
+Version 0.2
 
 """
 
@@ -116,12 +151,17 @@ from wx.lib.buttons import GenButton
 
 # Define The Values For The BalloonTip Frame Shape
 BT_ROUNDED = 1
+""" `BalloonTip` will have a rounded rectangular shape. """
 BT_RECTANGLE = 2
+""" `BalloonTip` will have a rectangular shape. """
 
 # Define The Value For The BalloonTip Destruction Behavior
 BT_LEAVE = 3
+""" `BalloonTip` will be destroyed when the user moves the mouse outside the target window. """
 BT_CLICK = 4
+""" `BalloonTip` will be destroyed when the user click on `BalloonTip`. """
 BT_BUTTON = 5
+""" `BalloonTip` will be destroyed when the user click on the close button. """
 
 
 # ---------------------------------------------------------------
@@ -137,7 +177,15 @@ BT_BUTTON = 5
 # ---------------------------------------------------------------
 
 class BalloonFrame(wx.Frame):
-
+    """
+    This class is called by the main L{BalloonTip} class, and it is
+    responsible for the frame creation/positioning on screen
+    depending on target control/window, the frame can position
+    itself to NW (default), NE, SW, SE. The switch on positioning
+    is done by calculating the absolute position of the target
+    control/window plus/minus the balloontip size. The pointing
+    arrow is positioned accordingly.
+    """
     def __init__(self, parent, id=wx.ID_ANY, pos=wx.DefaultPosition,
                  size=wx.DefaultSize, classparent=None):
         """
@@ -263,7 +311,11 @@ class BalloonFrame(wx.Frame):
 
 
     def SetBalloonShape(self, event=None):
-        """ Sets the balloon shape."""
+        """
+        Sets the balloon shape.
+
+        :param `event`: on wxGTK, a `wx.WindowCreateEvent` event to process.
+        """
 
         size = self.GetSize()
         pos = self.GetPosition()
@@ -348,10 +400,12 @@ class BalloonFrame(wx.Frame):
 
     def OnEnterButton(self, event):
         """
-        Handles the wx.EVT_ENTER_WINDOW for the BalloonTip button.
+        Handles the ``wx.EVT_ENTER_WINDOW`` for the L{BalloonTip} button.
 
-        When the BalloonTip is created with the tipstyle=BT_BUTTON, this event
-        provide some kind of 3d effect when the mouse enters the button area.
+        When the L{BalloonTip} is created with the `tipstyle` = ``BT_BUTTON``, this event
+        provide some kind of 3D effect when the mouse enters the button area.
+
+        :param `event`: a `wx.MouseEvent` event to be processed.
         """
 
         button = event.GetEventObject()
@@ -376,10 +430,12 @@ class BalloonFrame(wx.Frame):
 
     def OnLeaveButton(self, event):
         """
-        Handles the wx.EVT_LEAVE_WINDOW for the BalloonTip button.
+        Handles the ``wx.EVT_LEAVE_WINDOW`` for the L{BalloonTip} button.
 
-        When the BalloonTip is created with the tipstyle=BT_BUTTON, this event
-        restore the button appearance when the mouse leaves the button area.
+        When the L{BalloonTip} is created with the `tipstyle` = ``BT_BUTTON``, this event
+        provide some kind of 3D effect when the mouse enters the button area.
+
+        :param `event`: a `wx.MouseEvent` event to be processed.        
         """
 
         button = event.GetEventObject()
@@ -391,7 +447,11 @@ class BalloonFrame(wx.Frame):
 
 
     def OnClose(self, event):
-        """ Handles the wx.EVT_CLOSE event."""
+        """
+        Handles the ``wx.EVT_CLOSE`` event for L{BalloonTip}.
+
+        :param `event`: a `wx.CloseEvent` event to be processed.
+        """
 
         if isinstance(self._parent._widget, wx.TaskBarIcon):
             self._parent.taskbarcreation = 0
@@ -409,36 +469,44 @@ class BalloonFrame(wx.Frame):
 # ---------------------------------------------------------------
 
 class BalloonTip(object):
+    """
+    BalloonTip is a class that allows you to display tooltips in a balloon style
+    window.
 
+    This is the main class implementation.
+    """    
     def __init__(self, topicon=None, toptitle="",
                  message="", shape=BT_ROUNDED, tipstyle=BT_LEAVE):
         """
         Default class constructor.
 
-        BalloonTip.__init__(self, topicon=none, toptitle="", message="",
-                            shape=BT_ROUNDED, tipstyle=BT_LEAVE)
+        :param `topicon`: an icon that will be displayed on the top-left part of the
+         L{BalloonTip} frame. If set to ``None``, no icon will be displayed;
+        :param `toptitle`: a title that will be displayed on the top part of the
+         L{BalloonTip} frame. If set to an empty string, no title will be displayed;
+        :param `message`: the tip message that will be displayed. It can not be set to
+         an empty string;
+        :param `shape`: the L{BalloonTip} shape. It can be one of the following:
 
-        Parameters:
+         ======================= ========= ====================================
+         Shape Flag              Hex Value  Description
+         ======================= ========= ====================================
+         ``BT_ROUNDED``           0x1      `BalloonTip` will have a rounded rectangular shape.
+         ``BT_RECTANGLE``         0x2      `BalloonTip` will have a rectangular shape.
+         ======================= ========= ====================================
+         
+        :param `tipstyle`: the L{BalloonTip} destruction behavior. It can be one of:
+
+         ======================= ========= ====================================
+         Tip Flag                Hex Value  Description
+         ======================= ========= ====================================
+         ``BT_LEAVE``                  0x3 `BalloonTip` will be destroyed when the user moves the mouse outside the target window.
+         ``BT_CLICK``                  0x4 `BalloonTip` will be destroyed when the user click on `BalloonTip`.
+         ``BT_BUTTON``                 0x5 `BalloonTip` will be destroyed when the user click on the close button.
+         ======================= ========= ====================================
 
-        - topicon: an icon that will be displayed on the top-left part of the
-          BalloonTip frame. if set to none, no icon will be displayed;
-        - toptile: a title that will be displayed on the top part of the
-          BalloonTip frame. if set to an empty string, no title will be displayed;
-        - message: the tip message that will be displayed. It can not be set to
-          an empty string;
-        - shape: the BalloonTip shape. it can be one of:
-          a) BT_RECTANGLE (a rectangle);
-          b) BT_ROUNDED (rounded rectangle, the default).
-        - tipstyle: the BalloonTip destruction behavior. It can be one of:
-          a) BT_LEAVE: the BalloonTip is destroyed when the mouse leaves the
-             target control/window;
-          b) BT_CLICK: the BalloonTip is destroyed when you click on any area
-             of the target control/window;
-          c) BT_BUTTON: the BalloonTip is destroyed when you click on the
-             top-right close button;
         """
 
-
         self._shape = shape
         self._topicon = topicon
         self._toptitle = toptitle
@@ -475,7 +543,11 @@ class BalloonTip(object):
 
 
     def SetTarget(self, widget):
-        """ Sets the target control/window for the BalloonTip."""
+        """
+        Sets the target control/window for the BalloonTip.
+
+        :param `widget`: an instance of `wx.Window`.
+        """
 
         self._widget = widget
 
@@ -491,16 +563,20 @@ class BalloonTip(object):
 
 
     def GetTarget(self):
-        """ Returns the target window for the BalloonTip."""
+        """ Returns the target window for the L{BalloonTip}."""
 
         if not hasattr(self, "_widget"):
-            raise "\nERROR: BalloonTip Target Has Not Been Set"
+            raise Exception("\nERROR: BalloonTip Target Has Not Been Set")
 
         return self._widget
 
 
     def SetStartDelay(self, delay=1):
-        """ Sets the delay time after which the BalloonTip is created."""
+        """
+        Sets the delay time after which the L{BalloonTip} is created.
+
+        :param `delay`: the number of milliseconds after which L{BalloonTip} is created.
+        """
 
         if delay < 1:
             raise Exception("\nERROR: Delay Time For BalloonTip Creation Should Be Greater Than 1 ms")
@@ -509,13 +585,17 @@ class BalloonTip(object):
 
 
     def GetStartDelay(self):
-        """ Returns the delay time after which the BalloonTip is created."""
+        """ Returns the delay time after which the L{BalloonTip} is created."""
 
         return self._startdelaytime
 
 
     def SetEndDelay(self, delay=1e6):
-        """ Sets the delay time after which the BalloonTip is destroyed."""
+        """
+        Sets the delay time after which the BalloonTip is destroyed.
+
+        :param `delay`: the number of milliseconds after which L{BalloonTip} is destroyed.
+        """
 
         if delay < 1:
             raise Exception("\nERROR: Delay Time For BalloonTip Destruction Should Be Greater Than 1 ms")
@@ -524,13 +604,18 @@ class BalloonTip(object):
 
 
     def GetEndDelay(self):
-        """ Returns the delay time after which the BalloonTip is destroyed."""
+        """ Returns the delay time after which the L{BalloonTip} is destroyed."""
 
         return self._enddelaytime
 
 
     def OnWidgetEnter(self, event):
-        """ Starts the BalloonTip timer for creation."""
+        """
+        Handles the ``wx.EVT_ENTER_WINDOW`` for the target control/window and
+        starts the L{BalloonTip} timer for creation.
+
+        :param `event`: a `wx.MouseEvent` event to be processed.
+        """
 
         if hasattr(self, "BalloonFrame"):
             if self.BalloonFrame:
@@ -547,9 +632,11 @@ class BalloonTip(object):
 
     def OnWidgetLeave(self, event):
         """
-        Handles the wx.EVT_LEAVE_WINDOW for the target control/window.
+        Handles the ``wx.EVT_LEAVE_WINDOW`` for the target control/window.
+        
+        :param `event`: a `wx.MouseEvent` event to be processed.
 
-        If the BalloonTip tipstyle is set to BT_LEAVE, the BalloonTip is destroyed.
+        :note: If the BalloonTip `tipstyle` is set to ``BT_LEAVE``, the L{BalloonTip} is destroyed.
         """
 
         if hasattr(self, "showtime"):
@@ -575,7 +662,11 @@ class BalloonTip(object):
 
 
     def OnTaskBarMove(self, event):
-        """  Handles the mouse motion inside the taskbar icon. """
+        """
+        Handles the mouse motion inside the taskbar icon area.
+
+        :param `event`: a `wx.MouseEvent` event to be processed.
+        """
 
         if not hasattr(self, "BalloonFrame"):
             if self.taskbarcreation == 0:
@@ -598,8 +689,8 @@ class BalloonTip(object):
         """
         Handle the mouse motion inside the target.
 
-        This prevents the annoying behavior of BalloonTip to display when the
-        user does something else inside the window. The BalloonTip window is
+        This prevents the annoying behavior of L{BalloonTip} to display when the
+        user does something else inside the window. The L{BalloonTip} window is
         displayed only when the mouse does *not* move for the start delay time.
         """
 
@@ -615,7 +706,7 @@ class BalloonTip(object):
 
 
     def NotifyTimer(self):
-        """ The creation timer has expired. creates the BalloonTip frame."""
+        """ The creation timer has expired. Creates the L{BalloonTip} frame."""
 
         self.BalloonFrame = BalloonFrame(self._widget, classparent=self)
         self.BalloonFrame.Show(True)
@@ -633,8 +724,8 @@ class BalloonTip(object):
         This timer check periodically the mouse position.
 
         If the current mouse position is sufficiently far from the coordinates
-        it had when entered the taskbar icon and the BalloonTip style is
-        BT_LEAVE, the BalloonTip frame is destroyed.
+        it had when entered the taskbar icon and the L{BalloonTip} style is
+        ``BT_LEAVE``, the L{BalloonTip} frame is destroyed.
         """
 
         self.currentmousepos = wx.GetMousePosition()
@@ -655,7 +746,7 @@ class BalloonTip(object):
 
 
     def DestroyTimer(self):
-        """ The destruction timer has expired. Destroys the BalloonTip frame."""
+        """ The destruction timer has expired. Destroys the L{BalloonTip} frame."""
 
         self.destroytime.Stop()
         del self.destroytime
@@ -667,25 +758,30 @@ class BalloonTip(object):
 
 
     def SetBalloonShape(self, shape=BT_ROUNDED):
-        """ Sets the BalloonTip frame shape.
+        """
+        Sets the L{BalloonTip} frame shape.
 
-        it should be one of bt_rounded, bt_rectangle.
+        :param `shape`: should be one of ``BT_ROUNDED`` or ``BT_RECTANGLE``.
         """
 
         if shape not in [BT_ROUNDED, BT_RECTANGLE]:
-            raise '\nERROR: BalloonTip Shape Should Be One Of "BT_ROUNDED", "BT_RECTANGLE"'
+            raise Exception('\nERROR: BalloonTip Shape Should Be One Of "BT_ROUNDED", "BT_RECTANGLE"')
 
         self._shape = shape
 
 
     def GetBalloonShape(self):
-        """ Returns the BalloonTip frame shape."""
+        """ Returns the L{BalloonTip} frame shape."""
 
         return self._shape
 
 
     def SetBalloonIcon(self, icon):
-        """ Sets the BalloonTip top-left icon."""
+        """
+        Sets the L{BalloonTip} top-left icon.
+
+        :param `icon`: an instance of `wx.Bitmap`.
+        """
 
         if icon.Ok():
             self._topicon = icon
@@ -694,25 +790,35 @@ class BalloonTip(object):
 
 
     def GetBalloonIcon(self):
-        """ Returns the BalloonTip top-left icon."""
+        """ Returns the L{BalloonTip} top-left icon."""
 
         return self._topicon
 
 
     def SetBalloonTitle(self, title=""):
-        """ Sets the BalloonTip top title."""
+        """
+        Sets the L{BalloonTip} top title.
+
+        :param `title`: a string to use as a L{BalloonTip} title.
+        """
 
         self._toptitle = title
 
 
     def GetBalloonTitle(self):
-        """ Returns the BalloonTip top title."""
+        """ Returns the L{BalloonTip} top title."""
 
         return self._toptitle
 
 
     def SetBalloonMessage(self, message):
-        """ Sets the BalloonTip tip message. it should not be empty."""
+        """
+        Sets the L{BalloonTip} tip message. 
+
+        :param `message`: a string identifying the main message body of L{BalloonTip}.
+
+        :note: The L{BalloonTip} message should never be empty.        
+        """
 
         if len(message.strip()) < 1:
             raise Exception("\nERROR: BalloonTip Message Can Not Be Empty")
@@ -721,16 +827,24 @@ class BalloonTip(object):
 
 
     def GetBalloonMessage(self):
-        """ Returns the BalloonTip tip message."""
+        """ Returns the L{BalloonTip} tip message."""
 
         return self._message
 
 
     def SetBalloonTipStyle(self, tipstyle=BT_LEAVE):
         """
-        Sets the BalloonTip tipstyle.
+        Sets the L{BalloonTip} `tipstyle` parameter.
 
-        It should be one of BT_LEAVE, BT_CLICK, BT_BUTTON.
+        :param `tipstyle`: one of the following bit set:
+
+         ============== ========== =====================================
+         Tip Style      Hex Value  Description
+         ============== ========== =====================================
+         ``BT_LEAVE``          0x3 `BalloonTip` will be destroyed when the user moves the mouse outside the target window.
+         ``BT_CLICK``          0x4 `BalloonTip` will be destroyed when the user click on `BalloonTip`.
+         ``BT_BUTTON``         0x5 `BalloonTip` will be destroyed when the user click on the close button.
+         ============== ========== =====================================
         """
 
         if tipstyle not in [BT_LEAVE, BT_CLICK, BT_BUTTON]:
@@ -741,13 +855,21 @@ class BalloonTip(object):
 
 
     def GetBalloonTipStyle(self):
-        """ Returns the BalloonTip tipstyle."""
+        """
+        Returns the L{BalloonTip} `tipstyle` parameter.
+
+        :see: L{SetBalloonTipStyle}
+        """
 
         return self._tipstyle
 
 
     def SetBalloonColour(self, colour=None):
-        """ Sets the BalloonTip background colour."""
+        """
+        Sets the L{BalloonTip} background colour.
+
+        :param `colour`: a valid `wx.Colour` instance.
+        """
 
         if colour is None:
             colour = wx.Colour(255, 250, 205)
@@ -756,13 +878,17 @@ class BalloonTip(object):
 
 
     def GetBalloonColour(self):
-        """ Returns the BalloonTip background colour."""
+        """ Returns the L{BalloonTip} background colour."""
 
         return self._ballooncolour
 
 
     def SetTitleFont(self, font=None):
-        """ Sets the font for the top title."""
+        """
+        Sets the font for the top title.
+
+        :param `font`: a valid `wx.Font` instance.
+        """
 
         if font is None:
             font = wx.Font(9, wx.SWISS, wx.NORMAL, wx.BOLD, False)
@@ -777,7 +903,11 @@ class BalloonTip(object):
 
 
     def SetMessageFont(self, font=None):
-        """ Sets the font for the tip message."""
+        """
+        Sets the font for the tip message.
+
+        :param `font`: a valid `wx.Font` instance.
+        """
 
         if font is None:
             font = wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL, False)
@@ -792,7 +922,11 @@ class BalloonTip(object):
 
 
     def SetTitleColour(self, colour=None):
-        """ Sets the colour for the top title."""
+        """
+        Sets the colour for the top title.
+
+        :param `colour`: a valid `wx.Colour` instance.
+        """
 
         if colour is None:
             colour = wx.BLACK
@@ -807,7 +941,11 @@ class BalloonTip(object):
 
 
     def SetMessageColour(self, colour=None):
-        """ Sets the colour for the tip message."""
+        """
+        Sets the colour for the tip message.
+
+        :param `colour`: a valid `wx.Colour` instance.
+        """
 
         if colour is None:
             colour = wx.BLACK
@@ -822,8 +960,13 @@ class BalloonTip(object):
 
 
     def OnDestroy(self, event):
-        """ Handles the target destruction."""
+        """
+        Handles the target destruction, specifically handling the ``wx.EVT_WINDOW_DESTROY``
+        event.
 
+        :param `event`: a `wx.WindowDestroyEvent` event to be processed.        
+        """
+        
         if hasattr(self, "BalloonFrame"):
             if self.BalloonFrame:
                 try:
@@ -845,6 +988,11 @@ class BalloonTip(object):
 
 
     def EnableTip(self, enable=True):
-        """ Enable/disable globally the BalloonTip."""
+        """
+        Enable/disable globally the L{BalloonTip}.
+
+        :param `enable`: ``True`` to enable L{BalloonTip}, ``False`` otherwise.
+        """
 
         self._runningapp.__tooltipenabled__ = enable
+
