@@ -2,7 +2,7 @@
 # FOURWAYSPLITTER wxPython IMPLEMENTATION
 #
 # Andrea Gavana, @ 03 Nov 2006
-# Latest Revision: 15 Oct 2008, 22.30 GMT
+# Latest Revision: 14 Apr 2010, 12.00 GMT
 #
 #
 # TODO List
@@ -22,33 +22,32 @@
 # --------------------------------------------------------------------------------- #
 
 """
+FourWaySplitter is a layout manager which manages 4 children like 4 panes in a
+window.
+
+
 Description
 ===========
 
 The FourWaySplitter is a layout manager which manages four children like four
 panes in a window. You can use a four-way splitter for example in a CAD program
 where you may want to maintain three orthographic views, and one oblique view of
-a model. The FourWaySplitter allows interactive repartitioning of the panes by
+a model.
+
+The FourWaySplitter allows interactive repartitioning of the panes by
 means of moving the central splitter bars. When the FourWaySplitter is itself
 resized, each child is proportionally resized, maintaining the same split-percentage.
+
 The main characteristics of FourWaySplitter are:
 
-  - Handles horizontal, vertical or four way sizing via the sashes;
-  - Delayed or live update when resizing;
-  - Possibility to swap windows;
-  - Setting the vertical and horizontal split fractions;
-  - Possibility to expand a window by hiding the onther 3.
+- Handles horizontal, vertical or four way sizing via the sashes;
+- Delayed or live update when resizing;
+- Possibility to swap windows;
+- Setting the vertical and horizontal split fractions;
+- Possibility to expand a window by hiding the onther 3.
 
 And a lot more. See the demo for a complete review of the functionalities.
 
-Events
-======
-
-FourWaySplitter implements the default events for wx.SplitterWindow:
-
-  - wx.EVT_SPLITTER_SASH_POS_CHANGING
-  - wx.EVT_SPLITTER_SASH_POS_CHANGED
-
 
 Supported Platforms
 ===================
@@ -58,14 +57,41 @@ FourWaySplitter has been tested on the following platforms:
   * Linux Ubuntu (Dapper 6.06)
 
 
-License And Version:
+Window Styles
+=============
+
+This class supports the following window styles:
+
+================== =========== ==================================================
+Window Styles      Hex Value   Description
+================== =========== ==================================================
+``SP_NOSASH``             0x10 No sash will be drawn on `FourWaySplitter`.
+``SP_LIVE_UPDATE``        0x80 Don't draw XOR line but resize the child windows immediately.
+``SP_3DBORDER``          0x200 Draws a 3D effect border.
+================== =========== ==================================================
+
+
+Events Processing
+=================
+
+This class processes the following events:
+
+================================== ==================================================
+Event Name                         Description
+================================== ==================================================
+``EVT_SPLITTER_SASH_POS_CHANGED``  The sash position was changed. This event is generated after the user releases the mouse after dragging the splitter. Processes a `wx.wxEVT_COMMAND_SPLITTER_SASH_POS_CHANGED` event.
+``EVT_SPLITTER_SASH_POS_CHANGING`` The sash position is in the process of being changed. You may prevent this change from happening by calling `Veto` or you may also modify the position of the tracking bar to properly reflect the position that would be set if the drag were to be completed at this point. Processes a `wx.wxEVT_COMMAND_SPLITTER_SASH_POS_CHANGING` event.
+================================== ==================================================
+
+
+License And Version
 ===================
 
-FourWaySplitter is freeware and distributed under the wxPython license. 
+FourWaySplitter is distributed under the wxPython license. 
 
+Latest Revision: Andrea Gavana @ 14 Apr 2010, 12.00 GMT
 
-Latest Revision: Andrea Gavana @ 15 Oct 2008, 22.30 GMT
-Version 0.1
+Version 0.4
 
 """
 
@@ -84,6 +110,24 @@ NOWHERE = 0
 FLAG_CHANGED = 1
 FLAG_PRESSED = 2
 
+# FourWaySplitter styles
+SP_NOSASH = wx.SP_NOSASH
+""" No sash will be drawn on `FourWaySplitter`. """
+SP_LIVE_UPDATE = wx.SP_LIVE_UPDATE
+""" Don't draw XOR line but resize the child windows immediately. """
+SP_3DBORDER = wx.SP_3DBORDER
+""" Draws a 3D effect border. """
+
+# FourWaySplitter events
+EVT_SPLITTER_SASH_POS_CHANGING = wx.EVT_SPLITTER_SASH_POS_CHANGING
+""" The sash position is in the process of being changed. You may prevent this change""" \
+""" from happening by calling `Veto` or you may also modify the position of the tracking""" \
+""" bar to properly reflect the position that would be set if the drag were to be""" \
+""" completed at this point. Processes a `wx.wxEVT_COMMAND_SPLITTER_SASH_POS_CHANGING` event."""
+EVT_SPLITTER_SASH_POS_CHANGED = wx.EVT_SPLITTER_SASH_POS_CHANGED
+""" The sash position was changed. This event is generated after the user releases the""" \
+""" mouse after dragging the splitter. Processes a `wx.wxEVT_COMMAND_SPLITTER_SASH_POS_CHANGED` event. """
+
 # ---------------------------------------------------------------------------- #
 # Class FourWaySplitterEvent
 # ---------------------------------------------------------------------------- #
@@ -95,9 +139,16 @@ class FourWaySplitterEvent(wx.PyCommandEvent):
     same event type IDs and event binders are used as with
     `wx.SplitterEvent`.
     """
-    def __init__(self, type=wx.wxEVT_NULL, splitter=None):
+    
+    def __init__(self, evtType=wx.wxEVT_NULL, splitter=None):
+        """
+        Default class constructor.
+
+        :param `evtType`: the event type;
+        :param `splitter`: the associated L{FourWaySplitter} window.
+        """
         
-        wx.PyCommandEvent.__init__(self, type)
+        wx.PyCommandEvent.__init__(self, evtType)
 
         if splitter:
             self.SetEventObject(splitter)
@@ -109,37 +160,79 @@ class FourWaySplitterEvent(wx.PyCommandEvent):
 
 
     def SetSashIdx(self, idx):
+        """
+        Sets the index of the sash currently involved in the event.
+
+        :param `idx`: an integer between 0 and 3, representing the index of the
+         sash involved in the event.
+        """
         
         self.sashIdx = idx
 
 
     def SetSashPosition(self, pos):
+        """
+        In the case of ``EVT_SPLITTER_SASH_POS_CHANGED`` events, sets the new sash
+        position. In the case of ``EVT_SPLITTER_SASH_POS_CHANGING`` events, sets
+        the new tracking bar position so visual feedback during dragging will represent
+        that change that will actually take place. Set to -1 from the event handler
+        code to prevent repositioning.
 
+        :param `pos`: the new sash position.        
+
+        :note: May only be called while processing ``EVT_SPLITTER_SASH_POS_CHANGING``
+         and ``EVT_SPLITTER_SASH_POS_CHANGED`` events.
+        """
+        
         self.sashPos = pos
 
 
     def GetSashIdx(self):
+        """ Returns the index of the sash currently involved in the event. """
 
         return self.sashIdx
 
 
     def GetSashPosition(self):
+        """
+        Returns the new sash position.
 
+        :note: May only be called while processing ``EVT_SPLITTER_SASH_POS_CHANGING``
+         and ``EVT_SPLITTER_SASH_POS_CHANGED`` events.
+        """
+        
         return self.sashPos
 
 
     # methods from wx.NotifyEvent
     def Veto(self):
+        """
+        Prevents the change announced by this event from happening.
+
+        :note: It is in general a good idea to notify the user about the reasons
+         for vetoing the change because otherwise the applications behaviour (which
+         just refuses to do what the user wants) might be quite surprising.
+        """
 
         self.isAllowed = False
 
 
     def Allow(self):
+        """
+        This is the opposite of L{Veto}: it explicitly allows the event to be processed.
+        For most events it is not necessary to call this method as the events are
+        allowed anyhow but some are forbidden by default (this will be mentioned
+        in the corresponding event description).
+        """
 
         self.isAllowed = True
 
 
     def IsAllowed(self):
+        """
+        Returns ``True`` if the change is allowed (L{Veto} hasn't been called) or
+        ``False`` otherwise (if it was).
+        """
 
         return self.isAllowed
         
@@ -152,28 +245,47 @@ class FourWaySplitter(wx.PyPanel):
     """
     This class is very similar to `wx.SplitterWindow` except that it
     allows for four windows and two sashes.  Many of the same styles,
-    constants, and methods behave the same as in wx.SplitterWindow.
+    constants, and methods behave the same as in `wx.SplitterWindow`.
     However, in addition of the ability to drag the vertical and the
     horizontal sash, by dragging at the intersection between the two
     sashes, it is possible to resize the four windows at the same time.
 
-    NOTE: These things are not yet supported:
+    :note: These things are not yet supported:
+    
+     * Minimum pane size (minimum of what? Width? Height?);
+     * Using negative sash positions to indicate a position offset from the end;
+     * User controlled unsplitting with double clicks on the sash (but supported via the L{FourWaySplitter.SetExpanded} method);
+     * Sash gravity.
 
-        * Minimum pane size (minimum of what? Width? Height?)
-        
-        * Using negative sash positions to indicate a position offset
-          from the end.
-          
-        * User controlled unsplitting with double clicks on the sash
-          (but supported via SetExpanded method).
-          
-        * Sash gravity
-       
+     
     """
 
     def __init__(self, parent, id=wx.ID_ANY, pos=wx.DefaultPosition,
-                 size=wx.DefaultSize, style=0, name="FourWaySplitter"):
+                 size=wx.DefaultSize, style=0, agwStyle=0, name="FourWaySplitter"):
+        """
+        Default class constructor.
+        
+        :param `parent`: parent window. Must not be ``None``;
+        :param `id`: window identifier. A value of -1 indicates a default value;
+        :param `pos`: the control position. A value of (-1, -1) indicates a default position,
+         chosen by either the windowing system or wxPython, depending on platform;
+        :param `size`: the control size. A value of (-1, -1) indicates a default size,
+         chosen by either the windowing system or wxPython, depending on platform;
+        :param `style`: the underlying `wx.PyPanel` window style;
+        :param `agwStyle`: the AGW-specific window style. It can be a combination of the
+         following bits:
 
+         ================== =========== ==================================================
+         Window Styles      Hex Value   Description
+         ================== =========== ==================================================
+         ``SP_NOSASH``             0x10 No sash will be drawn on `FourWaySplitter`.
+         ``SP_LIVE_UPDATE``        0x80 Don't draw XOR line but resize the child windows immediately.
+         ``SP_3DBORDER``          0x200 Draws a 3D effect border.
+         ================== =========== ==================================================
+
+        :param `name`: the window name.
+        """
+        
         # always turn on tab traversal
         style |= wx.TAB_TRAVERSAL
 
@@ -181,6 +293,8 @@ class FourWaySplitter(wx.PyPanel):
         style &= ~wx.BORDER_MASK
         style |= wx.BORDER_NONE
 
+        self._agwStyle = agwStyle        
+
         # initialize the base class
         wx.PyPanel.__init__(self, parent, id, pos, size, style, name)
         self.SetBackgroundStyle(wx.BG_STYLE_CUSTOM)
@@ -213,20 +327,56 @@ class FourWaySplitter(wx.PyPanel):
         self.Bind(wx.EVT_ENTER_WINDOW, self.OnEnterWindow)
 
 
+    def SetAGWWindowStyleFlag(self, agwStyle):
+        """
+        Sets the L{FourWaySplitter} window style flags.
+
+        :param `agwStyle`: the AGW-specific window style. This can be a combination of the
+         following bits:
+
+         ================== =========== ==================================================
+         Window Styles      Hex Value   Description
+         ================== =========== ==================================================
+         ``SP_NOSASH``             0x10 No sash will be drawn on `FourWaySplitter`.
+         ``SP_LIVE_UPDATE``        0x80 Don't draw XOR line but resize the child windows immediately.
+         ``SP_3DBORDER``          0x200 Draws a 3D effect border.
+         ================== =========== ==================================================         
+        """
+
+        self._agwStyle = agwStyle
+        self.Refresh()
+        
+
+    def GetAGWWindowStyleFlag(self):
+        """
+        Returns the L{FourWaySplitter} window style.
+        """
+
+        return self._agwStyle
+
+
     def AppendWindow(self, window):
         """
         Add a new window to the splitter at the right side or bottom
         of the window stack.
+
+        :param `window`: an instance of `wx.Window`.
         """
+        
         self.InsertWindow(len(self._windows), window)
 
 
     def InsertWindow(self, idx, window, sashPos=-1):
         """
-        Insert a new window into the splitter at the position given in
-        ``idx``.
+        Insert a new window into the splitter at the position given in `idx`.
+
+        :param `idx`: the index at which the window will be inserted;
+        :param `window`: an instance of `wx.Window`;
+        :param `sashPos`: the sash position after the window insertion.
         """
+        
         assert window not in self._windows, "A window can only be in the splitter once!"
+        
         self._windows.insert(idx, window)
         
         self._SizeWindows()
@@ -234,11 +384,14 @@ class FourWaySplitter(wx.PyPanel):
 
     def DetachWindow(self, window):
         """
-        Removes the window from the stack of windows managed by the
-        splitter.  The window will still exist so you should `Hide` or
-        `Destroy` it as needed.
+        Removes the window from the stack of windows managed by the splitter. The
+        window will still exist so you should `Hide` or `Destroy` it as needed.
+
+        :param `window`: an instance of `wx.Window`.        
         """
+        
         assert window in self._windows, "Unknown window!"
+        
         idx = self._windows.index(window)
         del self._windows[idx]
 
@@ -247,11 +400,16 @@ class FourWaySplitter(wx.PyPanel):
 
     def ReplaceWindow(self, oldWindow, newWindow):
         """
-        Replaces oldWindow (which is currently being managed by the
-        splitter) with newWindow.  The oldWindow window will still
+        Replaces `oldWindow` (which is currently being managed by the
+        splitter) with `newWindow`.  The `oldWindow` window will still
         exist so you should `Hide` or `Destroy` it as needed.
+
+        :param `oldWindow`: an instance of `wx.Window`;
+        :param `newWindow`: another instance of `wx.Window`.
         """
+
         assert oldWindow in self._windows, "Unknown window!"
+        
         idx = self._windows.index(oldWindow)
         self._windows[idx] = newWindow
         
@@ -261,9 +419,14 @@ class FourWaySplitter(wx.PyPanel):
     def ExchangeWindows(self, window1, window2):
         """
         Trade the positions in the splitter of the two windows.
+
+        :param `window1`: an instance of `wx.Window`;
+        :param `window2`: another instance of `wx.Window`.        
         """
+        
         assert window1 in self._windows, "Unknown window!"
         assert window2 in self._windows, "Unknown window!"
+        
         idx1 = self._windows.index(window1)
         idx2 = self._windows.index(window2)
         self._windows[idx1] = window2
@@ -279,7 +442,11 @@ class FourWaySplitter(wx.PyPanel):
 
 
     def GetWindow(self, idx):
-        """ Returns the window at the index `idx`. """
+        """
+        Returns the window at the index `idx`.
+
+        :param `idx`: the index at which the window is located.
+        """
 
         if len(self._windows) > idx:
             return self._windows[idx]
@@ -315,7 +482,11 @@ class FourWaySplitter(wx.PyPanel):
 
 
     def DoGetBestSize(self):
-        """ Returns the best size for FourWaySplitter. """
+        """
+        Gets the size which best suits the window: for a control, it would be the
+        minimal size which doesn't truncate the control, for a panel - the same size
+        as it would have after a call to `Fit()`.
+        """
 
         if not self._windows:
             # something is better than nothing...
@@ -347,7 +518,8 @@ class FourWaySplitter(wx.PyPanel):
     def _SizeWindows(self):
         """
         Recalculate the layout based on split positions and split fractions.
-        See SetHSplit and SetVSplit for more information about split fractions.
+
+        :see: L{SetHSplit} and L{SetVSplit} for more information about split fractions.
         """
             
         win0 = self.GetTopLeft()
@@ -393,10 +565,18 @@ class FourWaySplitter(wx.PyPanel):
     # Determine split mode
     def GetMode(self, pt):
         """
-        Determines the split mode for FourWaySplitter. There are 3 possibilities:
-          - wx.HORIZONTAL: the user has clicked on the horizontal sash;
-          - wx.VERTICAL: the user has clicked on the vertical sash;
-          - wx.BOTH: the user has clicked at the intersection between the 2 sashes.
+        Determines the split mode for L{FourWaySplitter}. There are 3 possibilities:
+
+        ================= ==============================
+        Split Mode        Description
+        ================= ==============================
+        ``wx.HORIZONTAL`` the user has clicked on the horizontal sash
+        ``wx.VERTICAL``   The user has clicked on the vertical sash
+        ``wx.BOTH``       The user has clicked at the intersection between the 2 sashes
+        ================= ==============================
+
+        :param `pt`: the point at which the mouse has been clicked, an instance of
+         `wx.Point`.
         """
 
         barSize = self._GetSashSize()        
@@ -419,7 +599,12 @@ class FourWaySplitter(wx.PyPanel):
 
     # Move the split intelligently
     def MoveSplit(self, x, y):
-        """ Moves the split accordingly to user action. """
+        """
+        Moves the split accordingly to user action.
+
+        :param `x`: the new splitter x coordinate;
+        :param `y`: the new splitter y coordinate.
+        """
 
         width, height = self.GetSize()
         barSize = self._GetSashSize()
@@ -436,7 +621,7 @@ class FourWaySplitter(wx.PyPanel):
     # Adjust layout
     def AdjustLayout(self):
         """
-        Adjust layout of FourWaySplitter. Mainly used to recalculate the
+        Adjust layout of L{FourWaySplitter}. Mainly used to recalculate the
         correct values for split fractions.
         """
 
@@ -457,7 +642,11 @@ class FourWaySplitter(wx.PyPanel):
 
     # Button being pressed
     def OnLeftDown(self, event):
-        """ Handles the wx.EVT_LEFT_DOWN event for FourWaySplitter. """
+        """
+        Handles the ``wx.EVT_LEFT_DOWN`` event for L{FourWaySplitter}.
+
+        :param `event`: a `wx.MouseEvent` event to be processed.
+        """
 
         if not self.IsEnabled():
             return
@@ -469,7 +658,7 @@ class FourWaySplitter(wx.PyPanel):
         if self._mode:
             self._offx = pt.x - self._splitx
             self._offy = pt.y - self._splity
-            if not self.GetWindowStyle() & wx.SP_LIVE_UPDATE:
+            if not self.GetAGWWindowStyleFlag() & wx.SP_LIVE_UPDATE:
                 self.DrawSplitter(wx.ClientDC(self))
                 self.DrawTrackSplitter(self._splitx, self._splity)
 
@@ -478,7 +667,11 @@ class FourWaySplitter(wx.PyPanel):
 
     # Button being released
     def OnLeftUp(self, event):
-        """ Handles the wx.EVT_LEFT_UP event for FourWaySplitter. """
+        """
+        Handles the ``wx.EVT_LEFT_UP`` event for L{FourWaySplitter}.
+
+        :param `event`: a `wx.MouseEvent` event to be processed.
+        """
         
         if not self.IsEnabled():
             return
@@ -493,7 +686,7 @@ class FourWaySplitter(wx.PyPanel):
         
         if flgs & FLAG_PRESSED:
             
-            if not self.GetWindowStyle() & wx.SP_LIVE_UPDATE:
+            if not self.GetAGWWindowStyleFlag() & wx.SP_LIVE_UPDATE:
                 self.DrawTrackSplitter(self._splitx, self._splity)
                 self.DrawSplitter(wx.ClientDC(self))
                 self.AdjustLayout()
@@ -508,20 +701,32 @@ class FourWaySplitter(wx.PyPanel):
         
 
     def OnLeaveWindow(self, event):
-        """ Handles the wx.EVT_LEAVE_WINDOW event for FourWaySplitter. """
+        """
+        Handles the ``wx.EVT_LEAVE_WINDOW`` event for L{FourWaySplitter}.
+
+        :param `event`: a `wx.MouseEvent` event to be processed.
+        """
 
         self.SetCursor(wx.STANDARD_CURSOR)
         self._RedrawIfHotSensitive(False)
 
 
     def OnEnterWindow(self, event):
-        """ Handles the wx.EVT_ENTER_WINDOW event for FourWaySplitter. """
+        """
+        Handles the ``wx.EVT_ENTER_WINDOW`` event for L{FourWaySplitter}.
+
+        :param `event`: a `wx.MouseEvent` event to be processed.
+        """
         
         self._RedrawIfHotSensitive(True)
 
 
     def _RedrawIfHotSensitive(self, isHot):
-        """ Used internally. """
+        """
+        Used internally. Redraw the splitter if we are using a hot-sensitive splitter.
+
+        :param `isHot`: ``True`` if the splitter is in a hot state, ``False`` otherwise.
+        """
 
         if not wx.VERSION >= _RENDER_VER:
             return
@@ -533,7 +738,11 @@ class FourWaySplitter(wx.PyPanel):
 
         
     def OnMotion(self, event):
-        """ Handles the wx.EVT_MOTION event for FourWaySplitter. """
+        """
+        Handles the ``wx.EVT_MOTION`` event for L{FourWaySplitter}.
+
+        :param `event`: a `wx.MouseEvent` event to be processed.
+        """
 
         if self.HasFlag(wx.SP_NOSASH):
             return 
@@ -562,7 +771,7 @@ class FourWaySplitter(wx.PyPanel):
                 return              
 
             if oldsplitx != self._splitx or oldsplity != self._splity:
-                if not self.GetWindowStyle() & wx.SP_LIVE_UPDATE:
+                if not self.GetAGWWindowStyleFlag() & wx.SP_LIVE_UPDATE:
                     self.DrawTrackSplitter(oldsplitx, oldsplity)
                     self.DrawTrackSplitter(self._splitx, self._splity)
                 else:
@@ -589,14 +798,22 @@ class FourWaySplitter(wx.PyPanel):
 
 
     def OnPaint(self, event):
-        """ Handles the wx.EVT_PAINT event for FourWaySplitter. """
+        """
+        Handles the ``wx.EVT_PAINT`` event for L{FourWaySplitter}.
+
+        :param `event`: a `wx.PaintEvent` event to be processed.
+        """
 
         dc = wx.PaintDC(self)
         self.DrawSplitter(dc)
 
 
     def OnSize(self, event):
-        """ Handles the wx.EVT_SIZE event for FourWaySplitter. """
+        """
+        Handles the ``wx.EVT_SIZE`` event for L{FourWaySplitter}.
+
+        :param `event`: a `wx.SizeEvent` event to be processed.
+        """
 
         parent = wx.GetTopLevelParent(self)
         if parent.IsIconized():
@@ -607,7 +824,11 @@ class FourWaySplitter(wx.PyPanel):
 
 
     def DoSendChangingEvent(self, pt):
-        """ Sends a wx.EVT_SPLITTER_SASH_POS_CHANGING event. """
+        """
+        Sends a ``EVT_SPLITTER_SASH_POS_CHANGING`` event.
+
+        :param `pt`: the point at which the splitter is being positioned.
+        """
 
         # send the event
         event = FourWaySplitterEvent(wx.wxEVT_COMMAND_SPLITTER_SASH_POS_CHANGING, self)
@@ -645,7 +866,11 @@ class FourWaySplitter(wx.PyPanel):
         
     # Draw the horizontal split
     def DrawSplitter(self, dc):
-        """ Actually draws the sashes. """
+        """
+        Actually draws the sashes.
+
+        :param `dc`: an instance of `wx.DC`.
+        """
 
         backColour = self.GetBackgroundColour()        
         dc.SetBrush(wx.Brush(backColour, wx.SOLID))
@@ -687,7 +912,14 @@ class FourWaySplitter(wx.PyPanel):
 
 
     def DrawTrackSplitter(self, x, y):
-        """ Draws a fake sash in case we don't have wx.SP_LIVE_UPDATE style. """
+        """
+        Draws a fake sash in case we don't have ``wx.SP_LIVE_UPDATE`` style.
+
+        :param `x`: the x position of the sash;
+        :param `y`: the y position of the sash.
+
+        :note: This method relies on `wx.ScreenDC` which is currently unavailable on wxMac.        
+        """
 
         # Draw a line to represent the dragging sash, for when not
         # doing live updates            
@@ -762,37 +994,41 @@ class FourWaySplitter(wx.PyPanel):
     # Change horizontal split [fraction*10000]
     def SetHSplit(self, s):
         """
-        Change horizontal split fraction. The split fraction s is an integer
-        value between 0 and 10000 (inclusive), indicating how much space to
-        allocate to the leftmost panes. For example, to split the panes at
-        35 percent, use:
+        Change horizontal split fraction.
 
-        fourSplitter.SetHSplit(3500)
+        :param `s`: the split fraction, which is an integer value between 0 and
+         10000 (inclusive), indicating how much space to allocate to the leftmost
+         panes. For example, to split the panes at 35 percent, use::
+
+            fourSplitter.SetHSplit(3500)
+          
         """
 
         if s < 0: s = 0
         if s > 10000: s  =10000
         if s != self._fhor:
             self._fhor = s
-            self.AdjustLayout()
+            self._SizeWindows()
 
     
     # Change vertical split [fraction*10000]
     def SetVSplit(self, s):
         """
-        Change vertical split fraction. The split fraction s is an integer
-        value between 0 and 10000 (inclusive), indicating how much space to
-        allocate to the topmost panes. For example, to split the panes at
-        35 percent, use: 
+        Change vertical split fraction.
 
-        fourSplitter.SetVSplit(3500)
+        :param `s`: the split fraction, which is an integer value between 0 and
+         10000 (inclusive), indicating how much space to allocate to the topmost
+         panes. For example, to split the panes at 35 percent, use::
+
+            fourSplitter.SetVSplit(3500)
+          
         """
 
         if s < 0: s = 0
         if s > 10000: s  =10000
         if s != self._fver:
             self._fver = s
-            self.AdjustLayout()
+            self._SizeWindows()
 
 
     # Expand one or all of the four panes
@@ -801,10 +1037,13 @@ class FourWaySplitter(wx.PyPanel):
         This method is used to expand one of the four window to fill the
         whole client size (when expanded >= 0) or to return to the four-window
         view (when expanded < 0).
+
+        :param `expanded`: an integer >= 0 to expand a window to fill the whole
+         client size, or an integer < 0 to return to the four-window view.
         """
         
         if expanded >= 4:
-            raise "ERROR: SetExpanded: index out of range: %d"%expanded
+            raise Exception("ERROR: SetExpanded: index out of range: %d"%expanded)
 
         if self._expanded != expanded:
             self._expanded = expanded
