@@ -3,7 +3,7 @@
 # Python Code By:
 #
 # Andrea Gavana, @ 31 Oct 2005
-# Latest Revision: 15 Oct 2008, 10.00 GMT
+# Latest Revision: 30 Nov 2009, 17.00 GMT
 #
 #
 # TODO List/Caveats
@@ -17,8 +17,8 @@
 # For All Kind Of Problems, Requests Of Enhancements And Bug Reports, Please
 # Write To Me At:
 #
-# andrea.gavana@agip.it
-# andrea_gavan@tin.it
+# andrea.gavana@gmail.com
+# gavana@kpo.kz
 #
 # Or, Obviously, To The wxPython Mailing List!!!
 #
@@ -28,59 +28,65 @@
 
 
 """
-Description:
+PieCtrl/ProgressPie are simple classes that reproduce the behavior of a pie
+chart.
+
+
+Description
+===========
 
 PieCtrl/ProgressPie are simple classes that reproduce the behavior of a pie
 chart. They use only pure wxPython classes/methods, without external dependencies.
 PieCtrl is somewhat a "static" control, that you may create in order to display
-a simple pie chart on a wx.Panel or similar. ProgressPie tries to emulate the
-behavior of wx.ProgressDialog, but using a pie chart instead of a gauge.
+a simple pie chart on a `wx.Panel` or similar. ProgressPie tries to emulate the
+behavior of `wx.ProgressDialog`, but using a pie chart instead of a gauge.
 
 
-Usage:
+Usage
+=====
 
-An example of use of PieCtrl is as follows:
+An example of use of PieCtrl is as follows::
 
-# create a simple PieCtrl with 3 sectors
-mypie = PieCtrl(panel, -1, wx.DefaultPosition, wx.Size(180,270))
+    # create a simple PieCtrl with 3 sectors
+    mypie = PieCtrl(panel, -1, wx.DefaultPosition, wx.Size(180,270))
 
-part = PiePart()
+    part = PiePart()
 
-part.SetLabel("serieslabel_1")
-part.SetValue(300)
-part.SetColour(wx.Colour(200, 50, 50))
-mypie._series.append(part)
+    part.SetLabel("serieslabel_1")
+    part.SetValue(300)
+    part.SetColour(wx.Colour(200, 50, 50))
+    mypie._series.append(part)
 
-part = PiePart()
+    part = PiePart()
 
-part.SetLabel("series label 2")
-part.SetValue(200)
-part.SetColour(wx.Colour(50, 200, 50))
-mypie._series.append(part)
+    part.SetLabel("series label 2")
+    part.SetValue(200)
+    part.SetColour(wx.Colour(50, 200, 50))
+    mypie._series.append(part)
 
-part = PiePart()
+    part = PiePart()
 
-part.SetLabel("helloworld label 3")
-part.SetValue(50)
-part.SetColour(wx.Colour(50, 50, 200))
-mypie._series.append(part)
-
-An example of use of ProgressPie is as follows:
-
-# create a progresspie
-MyProgressPie = ProgressPie(panel, 100, 50, -1, wx.DefaultPosition,
-                            wx.Size(180, 200), wx.SIMPLE_BORDER)
-
-MyProgressPie.SetBackColour(wx.Colour(150, 200, 255))
-myprogresspie.SetFilledcolour(wx.Colour(255, 0, 0))
-MyProgressPie.SetUnfilledColour(wx.WHITE)
-MyProgressPie.SetHeight(20)
-
-For the full listing of the input parameters, see the PieCtrl __init__()
-method.
+    part.SetLabel("helloworld label 3")
+    part.SetValue(50)
+    part.SetColour(wx.Colour(50, 50, 200))
+    mypie._series.append(part)
 
 
-Methods and Settings:
+An example of use of ProgressPie is as follows::
+
+    # create a progresspie
+    MyProgressPie = ProgressPie(panel, 100, 50, -1, wx.DefaultPosition,
+                                wx.Size(180, 200), wx.SIMPLE_BORDER)
+
+    MyProgressPie.SetBackColour(wx.Colour(150, 200, 255))
+    myprogresspie.SetFilledcolour(wx.Colour(255, 0, 0))
+    MyProgressPie.SetUnfilledColour(wx.WHITE)
+    MyProgressPie.SetHeight(20)
+
+
+
+Methods and Settings
+====================
 
 With PieCtrl you can:
 
@@ -91,14 +97,28 @@ With PieCtrl you can:
 - Change the vertical rotation (perspective) of the PieCtrl;
 - Show/hide the segment edges.
 
-For more info on methods and initial styles, please refer to the __init__()
-method for PieCtrl or to the specific functions.
+
+Window Styles
+=============
+
+`No particular window styles are available for this class.`
 
 
-PieCtrl control is freeware and distributed under the wxPython license.
+Events Processing
+=================
+
+`No custom events are available for this class.`
+
+
+License And Version
+===================
+
+PieCtrl is distributed under the wxPython license.
+
+Latest revision: Andrea Gavana @ 30 Nov 2009, 17.00 GMT
+
+Version 0.2
 
-Latest revision: Andrea Gavana @ 15 Oct 2008, 10.00 GMT
-Version 0.1
 """
 
 
@@ -117,13 +137,23 @@ from math import pi, sin, cos
 #----------------------------------------------------------------------
 
 class PieCtrlLegend(wx.Window):
+    """
+    This class displays a legend window for the classic L{PieCtrl}.
+    """
 
     def __init__(self, parent, title, id=wx.ID_ANY, pos=wx.DefaultPosition,
                  size=wx.DefaultSize, style=0):
         """
         Default class constructor.
 
-        No special parameters are required, only the standard wxPython ones.
+        :param `parent`: the L{PieCtrlLegend} parent;
+        :param `title`: the legend title;
+        :param `id`: window identifier. A value of -1 indicates a default value;
+        :param `pos`: the control position. A value of (-1, -1) indicates a default position,
+         chosen by either the windowing system or wxPython, depending on platform;
+        :param `size`: the control size. A value of (-1, -1) indicates a default size,
+         chosen by either the windowing system or wxPython, depending on platform;
+        :param `style`: the window style (unused).
         """
 
         wx.Window.__init__(self, parent, id, pos, size, style)
@@ -143,14 +173,22 @@ class PieCtrlLegend(wx.Window):
 
 
     def SetTransparent(self, value=False):
-        """ Toggles the legend transparency (visibility). """
+        """
+        Toggles the legend transparency (visibility).
+
+        :param `value`: ``True`` to set the legend as transparent, ``False`` otherwise.
+        """
 
         self._istransparent = value
         self.Refresh()
 
 
     def RecreateBackground(self, parentdc):
-        """ Recreates the legend background. """
+        """
+        Recreates the legend background.
+
+        :param `parentdc`: an instance of `wx.DC`.
+        """
 
         w, h = self.GetSize()
         self._background = wx.EmptyBitmap(w, h)
@@ -170,33 +208,45 @@ class PieCtrlLegend(wx.Window):
 
 
     def SetHorizontalBorder(self, value):
-        """ Sets the legend's horizontal border. """
+        """
+        Sets the legend's horizontal border.
+
+        :param `value`: the horizontal border thickness, in pixels.
+        """
 
         self._horborder = value
         self.Refresh()
 
 
     def GetHorizontalBorder(self):
-        """ Returns the legend's horizontal border. """
+        """ Returns the legend's horizontal border, in pixels. """
 
         return self._horborder
 
 
     def SetVerticalBorder(self, value):
-        """ Sets the legend's vertical border. """
+        """
+        Sets the legend's vertical border.
+
+        :param `value`: the horizontal border thickness, in pixels.
+        """
 
         self._verborder = value
         self.Refresh()
 
 
     def GetVerticalBorder(self):
-        """ Returns the legend's vertical border. """
+        """ Returns the legend's vertical border, in pixels. """
 
         return self._verborder
 
 
     def SetLabelColour(self, colour):
-        """ Sets the legend label colour. """
+        """
+        Sets the legend label colour.
+
+        :param `colour`: a valid `wx.Colour` object.
+        """
 
         self._labelcolour = colour
         self.Refresh()
@@ -209,7 +259,11 @@ class PieCtrlLegend(wx.Window):
 
 
     def SetLabelFont(self, font):
-        """ Sets the legend label font. """
+        """
+        Sets the legend label font.
+
+        :param `font`: a valid `wx.Font` object.
+        """
 
         self._labelfont = font
         self.Refresh()
@@ -222,7 +276,11 @@ class PieCtrlLegend(wx.Window):
 
 
     def SetBackColour(self, colour):
-        """ Sets the legend background colour. """
+        """
+        Sets the legend background colour.
+
+        :param `colour`: a valid `wx.Colour` object.
+        """
 
         self._backcolour = colour
         self.Refresh()
@@ -241,7 +299,11 @@ class PieCtrlLegend(wx.Window):
 
 
     def OnPaint(self, event):
-        """ Handles the wx.EVT_PAINT event for the legend. """
+        """
+        Handles the ``wx.EVT_PAINT`` event for L{PieCtrlLegend}.
+
+        :param `event`: a `wx.PaintEvent` event to be processed.
+        """
 
         pdc = wx.PaintDC(self)
 
@@ -288,14 +350,18 @@ class PieCtrlLegend(wx.Window):
 #----------------------------------------------------------------------
 
 class PiePart(object):
+    """
+    This class handles the legend segments properties, such as value,
+    colour and label.
+    """
 
     def __init__(self, value=0, colour=wx.BLACK, label=""):
         """
         Default class constructor.
 
-        @param value: the pie part value;
-        @param colour: the pie part colour;
-        @param label: the pie part text label.
+        :param `value`: the pie part value;
+        :param `colour`: the pie part colour;
+        :param `label`: the pie part text label.
         """
 
         self._value = value
@@ -304,37 +370,49 @@ class PiePart(object):
 
 
     def SetValue(self, value):
-        """ Sets segment absolute value. """
+        """
+        Sets the segment absolute value.
+
+        :param `value`: a floating point number representing the L{PiePart} value.
+        """
 
         self._value = value
 
 
     def GetValue(self):
-        """ Returns segment absolute value. """
+        """ Returns the segment absolute value. """
 
         return self._value
 
 
     def SetColour(self, colour):
-        """ Sets segment colour. """
+        """
+        Sets the segment colour.
+
+        :param `colour`: a valid `wx.Colour` object.
+        """
 
         self._colour = colour
 
 
     def GetColour(self):
-        """ Returns segment colour. """
+        """ Returns the segment colour. """
 
         return self._colour
 
 
     def SetLabel(self, label):
-        """ Sets segment label. """
+        """
+        Sets the segment label.
+
+        :param `label`: the pie part text label.
+        """
 
         self._label = label
 
 
     def GetLabel(self):
-        """ Returns segment label. """
+        """ Returns the segment label. """
 
         return self._label
 
@@ -345,13 +423,24 @@ class PiePart(object):
 #----------------------------------------------------------------------
 
 class PieCtrl(wx.Window):
-
+    """
+    PieCtrl is somewhat a "static" control, that you may create in order to display
+    a simple pie chart on a `wx.Panel` or similar.
+    """
+    
     def __init__(self, parent, id=wx.ID_ANY, pos=wx.DefaultPosition,
                  size=wx.DefaultSize, style=0, name="PieCtrl"):
         """
         Default class constructor.
 
-        No special parameters are required, only the standard wxPython ones.
+        :param `parent`: the L{PieCtrl} parent. Must not be ``None``;
+        :param `id`: window identifier. A value of -1 indicates a default value;
+        :param `pos`: the control position. A value of (-1, -1) indicates a default position,
+         chosen by either the windowing system or wxPython, depending on platform;
+        :param `size`: the control size. A value of (-1, -1) indicates a default size,
+         chosen by either the windowing system or wxPython, depending on platform;
+        :param `style`: the window style (unused);
+        :param `name`: the window name.
         """
 
         wx.Window.__init__(self, parent, id, pos, size, style, name)
@@ -375,20 +464,28 @@ class PieCtrl(wx.Window):
 
 
     def SetBackground(self, bmp):
-        """ Sets the PieCtrl background image. """
+        """
+        Sets the L{PieCtrl} background image.
+
+        :param `bmp`: a valid `wx.Bitmap` object.
+        """
 
         self._background = bmp
         self.Refresh()
 
 
     def GetBackground(self):
-        """ Returns the PieCtrl background image. """
+        """ Returns the L{PieCtrl} background image. """
 
         return self._background
 
 
     def OnSize(self, event):
-        """ Handles the wx.EVT_SIZE event for PieCtrl. """
+        """
+        Handles the ``wx.EVT_SIZE`` event for L{PieCtrl}.
+
+        :param `event`: a `wx.SizeEvent` event to be processed.
+        """
 
         self.RecreateCanvas()
         self.Refresh()
@@ -396,7 +493,7 @@ class PieCtrl(wx.Window):
 
 
     def RecreateCanvas(self):
-        """ Recreates the PieCtrl container (canvas). """
+        """ Recreates the L{PieCtrl} container (canvas). """
 
         self._canvasbitmap = wx.EmptyBitmap(self.GetSize().GetWidth(),
                                             self.GetSize().GetHeight())
@@ -424,7 +521,11 @@ class PieCtrl(wx.Window):
 
 
     def SetAngle(self, angle):
-        """ Sets the orientation angle for PieCtrl. """
+        """
+        Sets the orientation angle for L{PieCtrl}.
+
+        :param `angle`: the orientation angle for L{PieCtrl}, in radians.
+        """
 
         if angle < 0:
             angle = 0
@@ -436,13 +537,17 @@ class PieCtrl(wx.Window):
 
 
     def GetAngle(self):
-        """ Returns the orientation angle for PieCtrl. """
+        """ Returns the orientation angle for L{PieCtrl}, in radians. """
 
         return self._angle
 
 
     def SetRotationAngle(self, angle):
-        """ Sets the angle at which the first sector starts. """
+        """
+        Sets the angle at which the first sector starts.
+
+        :param `angle`: the first sector angle, in radians.
+        """
 
         if angle < 0:
             angle = 0
@@ -454,57 +559,77 @@ class PieCtrl(wx.Window):
 
 
     def GetRotationAngle(self):
-        """ Returns the angle at which the first sector starts. """
+        """ Returns the angle at which the first sector starts, in radians. """
 
         return self._rotationangle
 
 
     def SetShowEdges(self, value=True):
-        """ Sets whether the PieCtrl edges are visible or not. """
+        """
+        Sets whether the L{PieCtrl} edges are visible or not.
+
+        :param `value`: ``True`` to show the edges, ``False`` to hide them.
+        """
 
         self._showedges = value
         self.Refresh()
 
 
     def GetShowEdges(self):
-        """ Returns whether the PieCtrl edges are visible or not. """
+        """ Returns whether the L{PieCtrl} edges are visible or not. """
 
         return self._showedges
 
 
     def SetBackColour(self, colour):
-        """ Sets the PieCtrl background colour. """
+        """
+        Sets the L{PieCtrl} background colour.
+
+        :param `colour`: a valid `wx.Colour` object.
+        """
 
         self._backcolour = colour
         self.Refresh()
 
 
     def GetBackColour(self):
-        """ Returns the PieCtrl background colour. """
+        """ Returns the L{PieCtrl} background colour. """
 
         return self._backcolour
 
 
     def SetHeight(self, value):
-        """ Sets the height (in pixels) of the PieCtrl. """
+        """
+        Sets the height (in pixels) of the L{PieCtrl}.
+
+        :param `value`: the new height of the widget, in pixels.
+        """
 
         self._height = value
 
 
     def GetHeight(self):
-        """ Returns the height (in pixels) of the PieCtrl. """
+        """ Returns the height (in pixels) of the L{PieCtrl}. """
 
         return self._height
 
 
     def GetLegend(self):
-        """ Returns the PieCtrl legend. """
+        """ Returns the L{PieCtrl} legend. """
 
         return self._legend
 
 
     def DrawParts(self, dc, cx, cy, w, h):
-        """ Here we draw the PieCtrl external edges. """
+        """
+        Draws the L{PieCtrl} external edges.
+
+        :param `dc`: an instance of `wx.DC`;
+        :param `cx`: the part x coordinate;
+        :param `cy`: the part y coordinate;
+        :param `w`: the control's width;
+        :param `h`: the control's height.
+        """
 
         angles = self.GetPartAngles()
         oldpen = dc.GetPen()
@@ -538,7 +663,11 @@ class PieCtrl(wx.Window):
 
 
     def Draw(self, pdc):
-        """ Here we draw all the sectors of PieCtrl. """
+        """
+        Draws all the sectors of L{PieCtrl}.
+
+        :param `dc`: an instance of `wx.DC`.        
+        """
 
         w, h = self.GetSize()
 
@@ -700,7 +829,11 @@ class PieCtrl(wx.Window):
 
 
     def OnPaint(self, event):
-        """ Handles the wx.EVT_PAINT event for PieCtrl. """
+        """
+        Handles the ``wx.EVT_PAINT`` event for L{PieCtrl}.
+
+        :param `event`: a `wx.PaintEvent` event to be processed.
+        """
 
         pdc = wx.PaintDC(self)
         self.Draw(pdc)
@@ -713,13 +846,24 @@ class PieCtrl(wx.Window):
 #----------------------------------------------------------------------
 
 class ProgressPie(PieCtrl):
-
+    """
+    ProgressPie tries to emulate the behavior of `wx.ProgressDialog`, but
+    using a pie chart instead of a gauge.
+    """
+    
     def __init__(self, parent, maxvalue, value, id=wx.ID_ANY,
                  pos=wx.DefaultPosition, size=wx.DefaultSize, style=0):
         """
         Default class constructor.
 
-        No special parameters are required, only the standard wxPython ones.
+        :param `parent`: the L{PieCtrl} parent. Must not be ``None``;
+        :param `id`: window identifier. A value of -1 indicates a default value;
+        :param `pos`: the control position. A value of (-1, -1) indicates a default position,
+         chosen by either the windowing system or wxPython, depending on platform;
+        :param `size`: the control size. A value of (-1, -1) indicates a default size,
+         chosen by either the windowing system or wxPython, depending on platform;
+        :param `style`: the window style (unused);
+        :param `name`: the window name.
         """
 
         PieCtrl.__init__(self, parent, id, pos, size, style)
@@ -742,7 +886,11 @@ class ProgressPie(PieCtrl):
 
 
     def SetValue(self, value):
-        """ Sets the ProgressPie value. """
+        """
+        Sets the L{ProgressPie} value.
+
+        :param `value`: a floating point number representing the new value.
+        """
 
         self._value = min(value, self._maxvalue)
         self._series[0].SetValue(max(self._value, 0.0))
@@ -751,13 +899,17 @@ class ProgressPie(PieCtrl):
 
 
     def GetValue(self):
-        """ Returns the ProgressPie value. """
+        """ Returns the L{ProgressPie} value. """
 
         return self._value
 
 
     def SetMaxValue(self, value):
-        """ Sets the progresspie maximum value. """
+        """
+        Sets the L{ProgressPie} maximum value.
+
+        :param `value`: a floating point number representing the maximum value.
+        """
 
         self._maxvalue = value
         self._value = min(self._value, self._maxvalue)
@@ -767,13 +919,17 @@ class ProgressPie(PieCtrl):
 
 
     def GetMaxValue(self):
-        """ Returns the progresspie maximum value. """
+        """ Returns the L{ProgressPie}  maximum value. """
 
         return self._maxvalue
 
 
     def SetFilledColour(self, colour):
-        """ Sets the colour that progressively fills the ProgressPie. """
+        """
+        Sets the colour that progressively fills the L{ProgressPie} .
+
+        :param `colour`: a valid `wx.Colour` object.
+        """
 
         self._filledcolour = colour
         self._series[0].SetColour(self._filledcolour)
@@ -781,7 +937,11 @@ class ProgressPie(PieCtrl):
 
 
     def SetUnfilledColour(self, colour):
-        """ Sets the colour that is filled. """
+        """
+        Sets the colour that is filled.
+
+        :param `colour`: a valid `wx.Colour` object.
+        """
 
         self._unfilledcolour= colour
         self._series[1].SetColour(self._unfilledcolour)
@@ -789,13 +949,13 @@ class ProgressPie(PieCtrl):
 
 
     def GetFilledColour(self):
-        """ Returns the colour that progressively fills the ProgressPie. """
+        """ Returns the colour that progressively fills the L{ProgressPie}. """
 
         return self._filledcolour
 
 
     def GetUnfilledColour(self):
-        """  Sets the colour that is filled. """
+        """ Returns the colour that is filled. """
 
         return self._unfilledcolour
 
