@@ -8,11 +8,11 @@
 ###############################################################################
 # Plugin Metadata
 """Run the script in the current buffer"""
-__version__ = "1.0"
+__version__ = "1.6"
 
-__author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: __init__.py 58364 2009-01-24 22:15:45Z CJP $"
-__revision__ = "$Revision: 58364 $"
+__author__ = "Cody Precord"
+__svnid__ = "$Id: __init__.py 63198 2010-01-20 02:30:54Z CJP $"
+__revision__ = "$Revision: 63198 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -20,6 +20,7 @@ import wx
 
 # Local modules
 import launch
+import cfgdlg
 
 # Editra imports
 import ed_glob
@@ -77,7 +78,7 @@ class Launch(plugin.Plugin):
         return item
 
     def GetMinVersion(self):
-        return "3.15"
+        return "0.4.89"
 
     def GetName(self):
         """The name of this plugin"""
@@ -114,6 +115,32 @@ class Launch(plugin.Plugin):
 
 #-----------------------------------------------------------------------------#
 
+def GetConfigObject():
+    return LaunchConfigObject()
+
+class LaunchConfigObject(plugin.PluginConfigObject):
+    """Plugin configuration object. Plugins that wish to provide a
+    configuration panel should implement a subclass of this object
+    in their __init__ module.
+
+    """
+    def GetConfigPanel(self, parent):
+        """Get the configuration panel for this plugin
+        @param parent: parent window for the panel
+        @return: wxPanel
+
+        """
+        return cfgdlg.ConfigNotebook(parent)
+
+    def GetLabel(self):
+        """Get the label for this config panel
+        @return string
+
+        """
+        return _("Launch")
+
+#-----------------------------------------------------------------------------#
+
 def OnRequestHandler(evt):
     """Handle the Run Script menu event and dispatch it to the currently
     active Launch panel
