@@ -10,8 +10,8 @@
 """Launch Configuration Dialog"""
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: cfgdlg.py 58501 2009-01-29 20:49:41Z CJP $"
-__revision__ = "$Revision: 58501 $"
+__svnid__ = "$Id: cfgdlg.py 62581 2009-11-10 02:52:54Z CJP $"
+__revision__ = "$Revision: 62581 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -25,11 +25,10 @@ import zlib
 import handlers
 
 # Editra Libraries
-import eclib.colorsetter as colorsetter
-import eclib.elistmix as elistmix
-from profiler import Profile_Get, Profile_Set
-import ed_msg
+import eclib
 import util
+import ed_msg
+from profiler import Profile_Get, Profile_Set
 
 #-----------------------------------------------------------------------------#
 # Globals
@@ -43,6 +42,7 @@ ID_EXECUTABLES = wx.NewId()
 
 # Misc Panel
 ID_AUTOCLEAR = wx.NewId()
+ID_ERROR_BEEP = wx.NewId()
 
 # Color Buttons
 ID_DEF_BACK = wx.NewId()
@@ -110,9 +110,6 @@ class ConfigDialog(wx.Frame):
         """
         wx.Frame.__init__(self, parent, title=_("Launch Configuration"))
 
-        # Attributes
-        self.ftype = ftype
-
         # Layout
         util.SetWindowIcon(self)
         self.__DoLayout()
@@ -130,37 +127,60 @@ class ConfigDialog(wx.Frame):
         hsizer = wx.BoxSizer(wx.HORIZONTAL)
         vsizer = wx.BoxSizer(wx.VERTICAL)
         panel = wx.Panel(self)
-        noteb = wx.Notebook(panel)
-        noteb.AddPage(ConfigPanel(noteb), _("General"))
-        noteb.AddPage(MiscPanel(noteb), _("Misc"))
+        noteb = ConfigNotebook(panel)
         hsizer.AddMany([((5, 5), 0), (noteb, 1, wx.EXPAND), ((5, 5), 0)])
         vsizer.AddMany([((5, 5), 0), (hsizer, 1, wx.EXPAND), ((10, 10), 0)])
         panel.SetSizer(vsizer)
-
         sizer.Add(panel, 1, wx.EXPAND)
         self.SetSizer(sizer)
         self.SetAutoLayout(True)
         self.SetInitialSize()
         self.SetMinSize((420, 345))
 
-    def GetLangId(self):
-        return self.ftype
-
     def OnClose(self, evt):
         """Unregister the window when its closed"""
         wx.GetApp().UnRegisterWindow(repr(self))
-        ed_msg.PostMessage(EDMSG_LAUNCH_CFG_EXIT)
         evt.Skip()
 
 #-----------------------------------------------------------------------------#
 
+class ConfigNotebook(wx.Notebook):
+    """Notebook for holding config pages"""
+    def __init__(self, parent):
+        wx.Notebook.__init__(self, parent)
+
+        # Make sure config has been initialized
+        prefs = Profile_Get(LAUNCH_PREFS, default=None)
+        if prefs is None:
+            buff = eclib.OutputBuffer(self)
+            buff.Hide()
+            Profile_Set(LAUNCH_PREFS,
+                        dict(autoclear=False,
+                             errorbeep=False,
+                             defaultf=buff.GetDefaultForeground().Get(),
+                             defaultb=buff.GetDefaultBackground().Get(),
+                             errorf=buff.GetErrorForeground().Get(),
+                             errorb=buff.GetErrorBackground().Get(),
+                             infof=buff.GetInfoForeground().Get(),
+                             infob=buff.GetInfoBackground().Get(),
+                             warnf=buff.GetWarningForeground().Get(),
+                             warnb=buff.GetWarningBackground().Get()))
+            buff.Destroy()
+
+        # Setup
+        self.AddPage(ConfigPanel(self), _("General"))
+        self.AddPage(MiscPanel(self), _("Misc"))
+
+    def __del__(self):
+        ed_msg.PostMessage(EDMSG_LAUNCH_CFG_EXIT)
+
+#-----------------------------------------------------------------------------#
+
 class ConfigPanel(wx.Panel):
     """Configuration panel that holds the controls for configuration"""
     def __init__(self, parent):
         wx.Panel.__init__(self, parent)
 
-        # Attributes
-
         # Layout
         self.__DoLayout()
 
@@ -174,7 +194,7 @@ class ConfigPanel(wx.Panel):
         msizer = wx.BoxSizer(wx.VERTICAL)
 
         lsizer = wx.BoxSizer(wx.HORIZONTAL)
-        ftype = self.GetTopLevelParent().GetLangId()
+        ftype = wx.GetApp().GetCurrentBuffer().GetLangId()
         ftype = handlers.GetHandlerById(ftype).GetName()
         htypes = GetHandlerTypes()
         lang_ch = wx.Choice(self, ID_LANGUAGE, choices=htypes)
@@ -375,7 +395,7 @@ class MiscPanel(wx.Panel):
 
         # Event Handlers
         self.Bind(wx.EVT_CHECKBOX, self.OnCheck)
-        self.Bind(colorsetter.EVT_COLORSETTER, self.OnColor)
+        self.Bind(eclib.EVT_COLORSETTER, self.OnColor)
 
     def __DoLayout(self):
         """Layout the controls"""
@@ -390,11 +410,14 @@ class MiscPanel(wx.Panel):
         clear_cb = wx.CheckBox(self, ID_AUTOCLEAR,
                                _("Automatically clear buffer between runs"))
         clear_cb.SetValue(cfg.get('autoclear', False))
+        error_cb = wx.CheckBox(self, ID_ERROR_BEEP,
+                               _("Audible feedback when errors are detected"))
+        error_cb.SetValue(cfg.get('errorbeep', False))
 
         # Colors
         colors = dict()
         for btn in COLOR_MAP.iteritems():
-            cbtn = colorsetter.ColorSetter(self, btn[0], color=cfg.get(btn[1]))
+            cbtn = eclib.ColorSetter(self, btn[0], color=cfg.get(btn[1]))
             colors[btn[0]] = cbtn
 
         flexg = wx.FlexGridSizer(5, 5, 5, 5)
@@ -441,6 +464,7 @@ class MiscPanel(wx.Panel):
         msizer.AddMany([((5, 5), 0),
                         (wx.StaticText(self, label=("Actions") + u":"), 0),
                         ((5, 5), 0), (clear_cb, 0),
+                        ((5, 5), 0), (error_cb, 0),
                         ((10, 10), 0), (wx.StaticLine(self), 0, wx.EXPAND),
                         ((10, 10), 0),
                         (boxsz, 1, wx.EXPAND)])
@@ -455,6 +479,8 @@ class MiscPanel(wx.Panel):
         cfg = Profile_Get(LAUNCH_PREFS, default=dict())
         if e_id == ID_AUTOCLEAR:
             cfg['autoclear'] = e_val
+        elif e_id == ID_ERROR_BEEP:
+            cfg['errorbeep'] = e_val
         else:
             evt.Skip()
 
@@ -472,7 +498,7 @@ ID_BROWSE = wx.NewId()
 
 class CommandListCtrl(listmix.ListCtrlAutoWidthMixin,
                       listmix.TextEditMixin,
-                      elistmix.ListRowHighlighter,
+                      eclib.ListRowHighlighter,
 #                      listmix.CheckListCtrlMixin,
                       wx.ListCtrl):
     """Auto-width adjusting list for showing editing the commands"""
@@ -480,7 +506,7 @@ class CommandListCtrl(listmix.ListCtrlAutoWidthMixin,
         wx.ListCtrl.__init__(self, *args, **kwargs)
         listmix.ListCtrlAutoWidthMixin.__init__(self)
 #        listmix.CheckListCtrlMixin.__init__(self)
-        elistmix.ListRowHighlighter.__init__(self)
+        eclib.ListRowHighlighter.__init__(self)
 
         # Attributes
         self._menu = None
