@@ -14,8 +14,8 @@ FileBrowser Plugin.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: browser.py 57481 2008-12-21 21:58:48Z CJP $"
-__revision__ = "$Revision: 57481 $"
+__svnid__ = "$Id: browser.py 62766 2009-12-03 04:50:13Z CJP $"
+__revision__ = "$Revision: 62766 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -35,8 +35,8 @@ import ed_menu
 import ed_mdlg
 import syntax.syntax
 import util
-from eclib import platebtn
-from eclib import ctrlbox
+import eclib
+import ebmlib
 
 # Local Imports
 import Trash
@@ -70,15 +70,15 @@ ID_MARK_PATH = wx.NewId()
 ID_OPEN_MARK = wx.NewId()
 ID_REMOVE_MARK = wx.NewId()
 
-class BrowserMenuBar(ctrlbox.ControlBar):
+class BrowserMenuBar(eclib.ControlBar):
     """Creates a menubar with """
 
     def __init__(self, parent):
-        ctrlbox.ControlBar.__init__(self, parent,
-                                    style=ctrlbox.CTRLBAR_STYLE_GRADIENT)
+        eclib.ControlBar.__init__(self, parent,
+                                  style=eclib.CTRLBAR_STYLE_GRADIENT)
 
         if wx.Platform == '__WXGTK__':
-            self.SetWindowStyle(ctrlbox.CTRLBAR_STYLE_DEFAULT)
+            self.SetWindowStyle(eclib.CTRLBAR_STYLE_DEFAULT)
 
         # Attributes
         self._saved = ed_menu.EdMenu()
@@ -104,8 +104,8 @@ class BrowserMenuBar(ctrlbox.ControlBar):
 
         # Button
         bmp = wx.ArtProvider.GetBitmap(str(ed_glob.ID_ADD_BM), wx.ART_MENU)
-        self.menub = platebtn.PlateButton(self, bmp=bmp,
-                                          style=platebtn.PB_STYLE_NOBG)
+        self.menub = eclib.PlateButton(self, bmp=bmp,
+                                       style=eclib.PB_STYLE_NOBG)
         self.menub.SetToolTipString(_("Pathmarks"))
         self.menub.SetMenu(menu)
 
@@ -186,13 +186,13 @@ class BrowserMenuBar(ctrlbox.ControlBar):
 
 #-----------------------------------------------------------------------------#
 
-class BrowserPane(ctrlbox.ControlBox):
+class BrowserPane(eclib.ControlBox):
     """Creates a filebrowser Pane"""
     ID_SHOW_HIDDEN = wx.NewId()
 
     def __init__(self, parent, id, pos=wx.DefaultPosition,
                  size=wx.DefaultSize, style=wx.NO_BORDER|wx.TAB_TRAVERSAL):
-        ctrlbox.ControlBox.__init__(self, parent, id, pos, size, style)
+        eclib.ControlBox.__init__(self, parent, id, pos, size, style)
         
         # Attributes
         self._mw = parent
@@ -204,14 +204,15 @@ class BrowserPane(ctrlbox.ControlBox):
                                           wx.DIRCTRL_EDIT_LABELS | 
                                           wx.BORDER_SUNKEN,
                                     filter=filters)
+        self._browser.SetMainWindow(self._mw)
         self._config = PathMarkConfig(ed_glob.CONFIG['CACHE_DIR'])
         for item in self._config.GetItemLabels():
             self._menbar.AddItem(item)
 
         # Setup hidden files checkbox
-        bbar = ctrlbox.ControlBar(self, style=ctrlbox.CTRLBAR_STYLE_GRADIENT)
+        bbar = eclib.ControlBar(self, style=eclib.CTRLBAR_STYLE_GRADIENT)
         if wx.Platform == '__WXGTK__':
-            bbar.SetWindowStyle(ctrlbox.CTRLBAR_STYLE_DEFAULT)
+            bbar.SetWindowStyle(eclib.CTRLBAR_STYLE_DEFAULT)
 
         self._showh_cb = wx.CheckBox(bbar, self.ID_SHOW_HIDDEN, 
                                      _("Show Hidden Files"))
@@ -333,6 +334,7 @@ class BrowserPane(ctrlbox.ControlBox):
 # Menu Id's
 ID_EDIT = wx.NewId()
 ID_OPEN = wx.NewId()
+ID_SEARCH_DIR = wx.NewId()
 ID_REVEAL = wx.NewId()
 ID_GETINFO = wx.NewId()
 ID_RENAME = wx.NewId()
@@ -352,6 +354,7 @@ class FileBrowser(wx.GenericDirCtrl):
                                    size, style, filter, defaultFilter)
 
         # Attributes
+        self._mw = None
         self._tree = self.GetTreeCtrl()
         self._treeId = 0                # id of TreeItem that was last rclicked
         self._fmenu = self._MakeMenu()
@@ -372,6 +375,8 @@ class FileBrowser(wx.GenericDirCtrl):
         self.Bind(wx.EVT_TREE_ITEM_ACTIVATED, self.OnOpen)
         self.Bind(wx.EVT_TREE_ITEM_RIGHT_CLICK, self.OnContext)
         self.Bind(wx.EVT_MENU, self.OnMenu)
+
+        # Editra Message Handlers
         ed_msg.Subscribe(self.OnThemeChanged, ed_msg.EDMSG_THEME_CHANGED)
         ed_msg.Subscribe(self.OnPageChange, ed_msg.EDMSG_UI_NB_CHANGED)
 #        self.Bind(wx.EVT_TREE_BEGIN_DRAG, self.OnDragStart)
@@ -412,6 +417,8 @@ class FileBrowser(wx.GenericDirCtrl):
                  (ID_MARK_PATH, _("Bookmark Selected Path(s)"),
                   ed_glob.ID_ADD_BM),
                  (wx.ID_SEPARATOR, '', None),
+                 (ID_SEARCH_DIR, _("Search in directory"), ed_glob.ID_FIND),
+                 (wx.ID_SEPARATOR, '', None),
                  (ID_GETINFO, _("Get Info"), None),
                  (ID_RENAME, _("Rename"), None),
                  (wx.ID_SEPARATOR, '', None),
@@ -499,6 +506,10 @@ class FileBrowser(wx.GenericDirCtrl):
 
         return r_txt + os.sep.join(path)
 
+    def GetMainWindow(self):
+        """Get the main window, needed by L{ed_msg.mwcontext}"""
+        return self._mw
+
     def GetPaths(self):
         """Gets a list of abs paths of the selected items"""
         ret_val = list()
@@ -558,6 +569,14 @@ class FileBrowser(wx.GenericDirCtrl):
         elif e_id == ID_REVEAL:
             worker = OpenerThread([os.path.dirname(fname) for fname in paths])
             worker.start()
+        elif e_id == ID_SEARCH_DIR:
+            paths = self.GetPaths()
+            if len(paths):
+                path = paths[0] # Go off of the first selected item
+                if not os.path.isdir(path):
+                    path = os.path.dirname(path)
+                mdata = dict(mainw=self._mw, lookin=path)
+                ed_msg.PostMessage(ed_msg.EDMSG_FIND_SHOW_DLG, mdata) 
         elif e_id == ID_GETINFO:
             last = None
             for fname in paths:
@@ -572,9 +591,9 @@ class FileBrowser(wx.GenericDirCtrl):
         elif e_id == ID_RENAME:
             self._tree.EditLabel(self._treeId)
         elif e_id == ID_NEW_FOLDER:
-            ok = util.MakeNewFolder(path, _("Untitled_Folder"))
+            ok = ebmlib.MakeNewFolder(path, _("Untitled_Folder"))
         elif e_id == ID_NEW_FILE:
-            ok = util.MakeNewFile(path, _("Untitled_File") + ".txt")
+            ok = ebmlib.MakeNewFile(path, _("Untitled_File") + ".txt")
         elif e_id == ID_DUPLICATE:
             for fname in paths:
                 ok = DuplicatePath(fname)
@@ -613,14 +632,20 @@ class FileBrowser(wx.GenericDirCtrl):
         self.OpenFiles(files)
         ed_msg.Subscribe(self.OnPageChange, ed_msg.EDMSG_UI_NB_CHANGED)
 
+    @ed_msg.mwcontext
     def OnPageChange(self, msg):
         """Syncronize selection with the notebook page changes
         @param msg: MessageObject
         @todo: check if message is from a page closing and avoid updates
 
         """
-        
         nbdata = msg.GetData()
+        pg_count = nbdata[0].GetPageCount()
+        if nbdata[1] > pg_count  or nbdata[1] < 0:
+            # Page is out of range, something has changed since the message was
+            # sent.
+            return
+
         page = nbdata[0].GetPage(nbdata[1])
         path = page.GetFileName()
         if len(path) and os.path.exists(path):
@@ -720,6 +745,13 @@ class FileBrowser(wx.GenericDirCtrl):
 #                 print i_txt
 #             item, cookie = self._tree.GetNextChild(item, cookie)
 
+    def SetMainWindow(self, mainw):
+        """Set the main window this browser belongs to.
+        @param mainw: MainWindow or None
+
+        """
+        self._mw = mainw
+
     def SetTreeStyle(self, style):
         """Sets the style of directory controls tree"""
         self._tree.SetWindowStyle(style)
@@ -805,7 +837,7 @@ def DuplicatePath(path):
     """
     head, tail = os.path.split(path)
     if os.path.isdir(path):
-        name = util.GetUniqueName(head, tail + "_Copy")
+        name = ebmlib.GetUniqueName(head, tail + "_Copy")
         copy = shutil.copytree
     else:
         tmp = [ part for part in tail.split('.') if len(part) ]
@@ -821,7 +853,7 @@ def DuplicatePath(path):
             tmp = '.'.join(tmp[:-1]) + "_Copy." + tmp[-1]
 
         if len(tmp) > 1:
-            name = util.GetUniqueName(head, tmp)
+            name = ebmlib.GetUniqueName(head, tmp)
         copy = shutil.copy2
 
     try:
@@ -843,7 +875,7 @@ def MakeArchive(path):
     ok = True
     name = ''
     if dname and fname:
-        name = util.GetUniqueName(dname, fname + ".zip")
+        name = ebmlib.GetUniqueName(dname, fname + ".zip")
         files = list()
         cwd = os.getcwd()
         head = dname
