@@ -16,13 +16,21 @@ running Editra.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: Editra.py 58902 2009-02-14 18:10:37Z CJP $"
-__revision__ = "$Revision: 58902 $"
+__svnid__ = "$Id: Editra.py 64249 2010-05-08 15:40:56Z CJP $"
+__revision__ = "$Revision: 64249 $"
 
 #--------------------------------------------------------------------------#
-# Dependancies
+# Dependencies
 import os
 import sys
+
+# Due to some methods that were added in 2.8.3 being used in a large number
+# of places Editra has become incompatible with wxPython 2.8.1.1 and earlier.
+# So ensure correct version of wxPython can be loaded
+if not hasattr(sys, 'frozen') and 'wx' not in sys.modules:
+    import wxversion
+    wxversion.ensureMinimal('2.8')
+
 import base64
 import locale
 import time
@@ -38,14 +46,6 @@ try:
 except:
     import extern.events as events
 
-# Due to some methods that were added in 2.8.3 being used in a large number
-# of places Editra has become incompatable with wxPython 2.8.1.1 and earlier.
-# TODO: add a message dialog to display this, or look into the cause of the
-#       issues of using wxversion on windows.
-if not hasattr(sys, 'frozen') and wx.VERSION < (2, 8, 3, ''):
-    print "VersionError: Editra requires wxPython 2.8.3 or higher"
-    print "              Your version is %s" % wx.VERSION_STRING
-
 # Try and import a system installed version of pkg_resources else fallback to
 # the one bundled with Editra's source.
 try:
@@ -67,14 +67,13 @@ import updater
 import plugin
 import ed_ipc
 import ed_msg
+import ebmlib
+from syntax import synglob
 
 #--------------------------------------------------------------------------#
 # Global Variables
 ID_UPDATE_CHECK = wx.NewId()
 
-# Commands (here temporarly)
-APP_CMD_OPEN_WINDOW = u"Editra.OpenWindow"
-
 _ = wx.GetTranslation
 #--------------------------------------------------------------------------#
 
@@ -96,22 +95,36 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         self._lock = False
         self._windows = dict()
 
+        # Disable debug popups
+        wx.Log.EnableLogging(False)
+
         if ed_glob.SINGLE:
             # Setup the instance checker
             instance_name = u"%s-%s" % (self.GetAppName(), wx.GetUserId())
             self._instance = wx.SingleInstanceChecker(instance_name)
             if self._instance.IsAnotherRunning():
                 try:
-                    opts, args = getopt.getopt(sys.argv[1:], "dhv",
-                                               ['debug', 'help', 'version'])
+                    opts, args = ProcessCommandLine()
                 except getopt.GetoptError, msg:
                     self._log("[app][err] %s" % str(msg))
                     args = list()
+                    opts = dict()
 
-                if not len(args):
-                    args.append(APP_CMD_OPEN_WINDOW)
+                exml = ed_ipc.IPCCommand()
+                if len(args):
+                    nargs = list()
+                    for p in args:
+                        try:
+                            p = ebmlib.GetAbsPath(p)
+                        except:
+                            pass
+                        nargs.append(p)
+                    exml.SetFiles(nargs)
+                exml.SetArgs(opts.items())
 
-                rval = ed_ipc.SendCommands(args, profiler.Profile_Get('SESSION_KEY'))
+                # TODO: need to process other command line options as well i.e) -g
+                self._log("[app][info] Sending: %s" % exml.GetXml())
+                rval = ed_ipc.SendCommands(exml, profiler.Profile_Get('SESSION_KEY'))
                 # If sending the command failed then let the editor startup
                 # a new instance
                 if not rval:
@@ -125,7 +138,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
                 profiler.Profile_Set('SESSION_KEY', key)
                 profiler.Profile_Set('ISBINARY', hasattr(sys, 'frozen'))
                 path = profiler.Profile_Get('MYPROFILE')
-                profiler.Profile().Write(path)
+                profiler.TheProfile.Write(path)
                 try:
                     self._server = ed_ipc.EdIpcServer(self, profiler.Profile_Get('SESSION_KEY'))
                     self._server.start()
@@ -139,10 +152,20 @@ class Editra(wx.App, events.AppEventHandlerMixin):
 
         # Setup Plugins after locale as they may have resource that need to
         # be loaded.
-        self._pluginmgr = plugin.PluginManager()
+        if self._isfirst:
+            self._pluginmgr = plugin.PluginManager()
 
-        self._log("[app][info] Registering Editra's ArtProvider")
-        wx.ArtProvider.PushProvider(ed_art.EditraArt())
+            self._log("[app][info] Registering Editra's ArtProvider")
+            wx.ArtProvider.PushProvider(ed_art.EditraArt())
+
+        # Check if libenchant has been loaded or need to be
+        import extern.stcspellcheck as stcspellcheck
+        checker = stcspellcheck.STCSpellCheck
+        if not checker.isEnchantOk():
+            spref = profiler.Profile_Get('SPELLCHECK', default=dict())
+            libpath = spref.get('epath', u'')
+            checker.reloadEnchant(libpath)
+            # TODO: log if load fails here
 
     def AddMessageCatalog(self, name, path):
         """Add a catalog lookup path to the app
@@ -194,7 +217,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         self.Bind(wx.EVT_MENU, self.OnNewWindow, id=ed_glob.ID_NEW_WINDOW)
         self.Bind(wx.EVT_MENU, self.OnCloseWindow)
         self.Bind(ed_event.EVT_NOTIFY, self.OnNotify)
-        self.Bind(ed_ipc.EVT_COMMAND_RECV, self.OnCommandRecieved)
+        self.Bind(ed_ipc.EVT_COMMAND_RECV, self.OnCommandReceived)
 
         # Splash a warning if version is not a final version
         if profiler.Profile_Get('APPSPLASH'):
@@ -230,10 +253,10 @@ class Editra(wx.App, events.AppEventHandlerMixin):
 
         """
         self._pluginmgr.WritePluginConfig()
-        profiler.Profile().Write(profiler.Profile_Get('MYPROFILE'))
+        profiler.TheProfile.Write(profiler.Profile_Get('MYPROFILE'))
         if not self._lock or force:
-            if hasattr(self, 'server'):
-                self.server.ShutDown()
+            if hasattr(self, '_server'):
+                self._server.Shutdown()
 
             try:
                 # Cleanup the instance checker
@@ -376,6 +399,28 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         """
         self._lock = True
 
+    def OpenFile(self, filename, line=-1):
+        """Open a file in the currently active window
+        @param filename: file path
+        @keyword line: int
+
+        """
+        window = self.GetTopWindow()
+        if isinstance(window, ed_main.MainWindow):
+            try:
+                encoding = sys.getfilesystemencoding()
+                window.DoOpen(ed_glob.ID_COMMAND_LINE_OPEN,
+                              ed_txt.DecodeString(filename, encoding),
+                              line)
+
+                # Make sure the window is brought to the front
+                if window.IsIconized():
+                    window.Iconize(False)
+                window.Raise()
+            except Exception, msg:
+                self._log("[app][err] Failed to open drop file: %s" % str(msg))
+                pass
+
     def MacNewFile(self):
         """Stub for future use"""
         pass
@@ -388,24 +433,8 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         @postcondition: if L{MainWindow} is open file will be opened in notebook
 
         """
-        window = self.GetTopWindow()
-        if getattr(window, '__name__', '') == "MainWindow":
-            try:
-                self._log("[app][info] MacOpenFile Fired")
-                encoding = sys.getfilesystemencoding()
-                window.DoOpen(ed_glob.ID_COMMAND_LINE_OPEN,
-                              ed_txt.DecodeString(filename, encoding))
-
-                # Make sure the window is brought to the front
-                if window.IsIconized():
-                    window.Iconize(False)
-                window.Raise()
-
-            except Exception, msg:
-                self._log("[app][err] Failed to open drop file: %s" % str(msg))
-                pass
-        else:
-            pass
+        self._log("[app][info] MacOpenFile Fired")
+        self.OpenFile(filename, line=-1)
 
     def MacPrintFile(self, filename):
         """Stub for future use
@@ -430,11 +459,14 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         """
         if evt.GetActive():
             self._log("[app][info] I'm Awake!!")
-            frame = self.GetTopWindow()
-            if frame is not None:
-                if frame.IsIconized():
-                    frame.Iconize(False)
-                frame.Raise()
+            # Refresh Clipboard Ring
+            ed_main.MainWindow.UpdateClipboardRing()
+
+#            frame = self.GetTopWindow()
+#            if frame is not None:
+#                if frame.IsIconized():
+#                    frame.Iconize(False)
+#                frame.Raise()
         else:
             self._log("[app][info] Going to sleep")
         evt.Skip()
@@ -478,29 +510,31 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         else:
             evt.Skip()
 
-    def OnCommandRecieved(self, evt):
-        """Recieve commands from the IPC server
+    def OnCommandReceived(self, evt):
+        """Receive commands from the IPC server
         @todo: move command processing into own module
 
         """
+        self._log("[app][info] IN OnCommandReceived")
         cmds = evt.GetCommands()
-        for cmdstr in cmds:
-            if u"::" in cmdstr:
-                target, cmd = cmdstr.split(u"::")
-                if target == u"Cmd.EditraStc":
-                    cbuf = self.GetCurrentBuffer()
-                    if cbuf is not None and hasattr(cbuf, cmd):
-                        try:
-                            getattr(cbuf, cmd)()
-                        except:
-                            self._log("[app][err] Invalid Command %s" % cmdstr)
+        if isinstance(cmds, ed_ipc.IPCCommand):
+            self._log("[app][info] OnCommandReceived %s" % cmds.GetXml())
+            if not len(cmds.GetFiles()):
+                self.OpenNewWindow()
             else:
-                if cmdstr == APP_CMD_OPEN_WINDOW:
-                    self.OpenNewWindow()
-                elif len(cmdstr):
-                    self.MacOpenFile(cmdstr)
-                else:
-                    self._log("[app][warn] Unknown Command %s" % cmdstr)
+                # TODO: change goto line handling to require one
+                #       arg per file specified on the command line
+                #       i.e) -g 23,44,100
+                line = -1
+                for arg, val in cmds.GetArgs():
+                    if arg == '-g':
+                        line = val
+                        if line > 0:
+                            line -= 1
+                        break
+
+                for fname in cmds.GetFiles():
+                    self.OpenFile(fname, line)
 
     def OnCloseWindow(self, evt):
         """Close the currently active window
@@ -605,12 +639,16 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         """
         if name in self._windows:
             self._windows.pop(name)
-            cur_top = self.GetTopWindow()
+            
             if not len(self._windows):
                 self._log("[app][info] No more open windows shutting down")
                 self.Exit()
                 return
 
+            # TODO: WXBUG? calling GetTopWindow when there are no more top
+            #       level windows causes a crash under MSW. Moving this line
+            #       above the previous check can reproduce the error.
+            cur_top = self.GetTopWindow()
             if name == repr(cur_top):
                 found = False
                 for key in self._windows:
@@ -654,15 +692,23 @@ def InitConfig():
     @postcondition: all configuration data is set
 
     """
-    # Look for a profile directory on the system level. If this directory exists
-    # Use it instead of the user one. This will allow for running Editra from
-    # a portable drive or for system administrators to enforce settings on a
-    # system installed version.
-    config_base = util.ResolvConfigDir(u'.Editra', True)
+    # Check if a custom config directory was specified on the commandline
+    if ed_glob.CONFIG['CONFIG_BASE'] is not None:
+        # TODO: there is a bug when the first time the config is created
+        #       where the settings will not be saved until second launching.
+        config_base = os.path.abspath(ed_glob.CONFIG['CONFIG_BASE'])
+    else:
+        # Look for a profile directory on the system level. If this directory
+        # exists Use it instead of the user one. This will allow for running
+        # Editra from a portable drive or for system administrators to enforce
+        # settings on a system installed version.
+        config_base = util.ResolvConfigDir(u'.Editra', True) 
+
     if os.path.exists(config_base):
         ed_glob.CONFIG['CONFIG_BASE'] = config_base
         ed_glob.CONFIG['PROFILE_DIR'] = os.path.join(config_base, u"profiles")
         ed_glob.CONFIG['PROFILE_DIR'] += os.sep
+        ed_glob.CONFIG['ISLOCAL'] = True
     else:
         config_base = wx.StandardPaths.Get().GetUserDataDir()
         ed_glob.CONFIG['PROFILE_DIR'] = util.ResolvConfigDir(u"profiles")
@@ -672,17 +718,37 @@ def InitConfig():
     profile_updated = False
     if util.HasConfigDir() and os.path.exists(ed_glob.CONFIG['PROFILE_DIR']):
         if profiler.ProfileIsCurrent():
-            profiler.Profile().Load(profiler.GetProfileStr())
+            pstr = profiler.GetProfileStr()
+            # If using local(portable) config the profile string is stored
+            # as a relative path that just names the config file.
+            if ed_glob.CONFIG['ISLOCAL']:
+                pstr = os.path.join(ed_glob.CONFIG['PROFILE_DIR'], pstr)
+            pstr = util.RepairConfigState(pstr)
+            profiler.TheProfile.Load(pstr)
         else:
             dev_tool.DEBUGP("[InitConfig][info] Updating Profile to current version")
 
             # Load and update profile
             pstr = profiler.GetProfileStr()
-            profiler.Profile().Load(pstr)
-            profiler.Profile().Update()
+            pstr = util.RepairConfigState(pstr)
+            profiler.TheProfile.Load(pstr)
+            profiler.TheProfile.Update()
 
             #---- Temporary Profile Adaptions ----#
 
+            # Added after 0.5.32
+            mconfig = profiler.Profile_Get('LEXERMENU', default=None)
+            if mconfig is None:
+                mconfig = [ synglob.LANG_C, synglob.LANG_CPP,
+                            synglob.LANG_BASH, synglob.LANG_CSS,
+                            synglob.LANG_HTML, synglob.LANG_JAVA,
+                            synglob.LANG_LISP, synglob.LANG_PERL,
+                            synglob.LANG_PHP, synglob.LANG_PYTHON,
+                            synglob.LANG_RUBY, synglob.LANG_SQL,
+                            synglob.LANG_XML]
+                mconfig.sort()
+                profiler.Profile_Set('LEXERMENU', mconfig)
+
             # GUI_DEBUG mode removed in 0.2.5
             mode = profiler.Profile_Get('MODE')
             if mode == 'GUI_DEBUG':
@@ -695,18 +761,24 @@ def InitConfig():
             if isinstance(profiler.Profile_Get('PRINT_MODE'), basestring):
                 profiler.Profile_Set('PRINT_MODE', ed_glob.PRINT_BLACK_WHITE)
 
-            # Simplifications to eol mode persistance (0.4.28)
+            # Simplifications to eol mode persistence (0.4.28)
             # Keep for now till plugins are updated
             #profiler.Profile_Del('EOL') # changed to EOL_MODE
 
+            # After 0.4.65 LAST_SESSION now points a session file and not
+            # to a list of files to open.
+            sess = profiler.Profile_Get('LAST_SESSION')
+            if isinstance(sess, list):
+                profiler.Profile_Set('LAST_SESSION', u'')
+
             #---- End Temporary Profile Adaptions ----#
 
             # Write out updated profile
-            profiler.Profile().Write(pstr)
+            profiler.TheProfile.Write(pstr)
 
             # When upgrading from an older version make sure all
             # config directories are available.
-            for cfg in ["cache", "styles", "plugins", "profiles"]:
+            for cfg in ("cache", "styles", "plugins", "profiles", "sessions"):
                 if not util.HasConfigDir(cfg):
                     util.MakeConfigDir(cfg)
 
@@ -746,7 +818,9 @@ def InitConfig():
             ed_glob.VDEBUG = True
 
     # Resolve resource locations
-    ed_glob.CONFIG['CONFIG_DIR'] = util.ResolvConfigDir("")
+    ed_glob.CONFIG['CONFIG_DIR'] = util.ResolvConfigDir(u"")
+    ed_glob.CONFIG['INSTALL_DIR'] = util.ResolvConfigDir(u"", True)
+    ed_glob.CONFIG['KEYPROF_DIR'] = util.ResolvConfigDir(u"ekeys", True)
     ed_glob.CONFIG['SYSPIX_DIR'] = util.ResolvConfigDir(u"pixmaps", True)
     ed_glob.CONFIG['PLUGIN_DIR'] = util.ResolvConfigDir(u"plugins")
     ed_glob.CONFIG['THEME_DIR'] = util.ResolvConfigDir(os.path.join(u"pixmaps", u"theme"))
@@ -757,10 +831,11 @@ def InitConfig():
     ed_glob.CONFIG['TEST_DIR'] = util.ResolvConfigDir(os.path.join(u"tests", u"syntax"), True)
 
     # Make sure all standard config directories are there
-    for cfg in ["cache", "styles", "plugins", "profiles"]:
+    for cfg in ("cache", "styles", "plugins", "profiles", "sessions"):
         if not util.HasConfigDir(cfg):
             util.MakeConfigDir(cfg)
     ed_glob.CONFIG['CACHE_DIR'] = util.ResolvConfigDir(u"cache")
+    ed_glob.CONFIG['SESSION_DIR'] = util.ResolvConfigDir(u"sessions")
 
     return profile_updated
 
@@ -782,7 +857,6 @@ def UpgradeOldInstall():
     if os.path.exists(old_cdir) and \
        base.lower().rstrip(os.sep) != old_cdir.lower().rstrip(os.sep):
         for item in os.listdir(old_cdir):
-            print item
             try:
                 dest = os.path.join(base, item)
                 item = os.path.join(old_cdir, item)
@@ -805,8 +879,8 @@ def UpgradeOldInstall():
         prof = os.path.basename(pstr)
         pstr = os.path.join(base, u"profiles", prof)
         if os.path.exists(pstr):
-            profiler.Profile().Load(pstr)
-            profiler.Profile().Update()
+            profiler.TheProfile.Load(pstr)
+            profiler.TheProfile.Update()
             profiler.UpdateProfileLoader()
 
         if not err:
@@ -820,63 +894,87 @@ def UpgradeOldInstall():
 
 #--------------------------------------------------------------------------#
 
-def PrintHelp():
+def PrintHelp(err=None):
     """Print command line help
     @postcondition: Help is printed and program exits
 
     """
-    print ("Editra - %s - Developers Text Editor\n"
-       "Cody Precord (2005-2008)\n\n"
+    if err is not None:
+        sys.stderr.write(err + os.linesep)
+
+    print(("Editra - %s - Developers Text Editor\n"
+       "Cody Precord (2005-2009)\n\n"
        "usage: Editra [arguments] [files... ]\n\n"
        "Short Arguments:\n"
-       "  -d         Turn on console debugging (-dd for verbose debug)\n"
-       "  -D         Turn off console debugging (overrides preferences)\n"
-       "  -h         Show this help message\n"
-       "  -p         Run Editra in the profiler\n"
-       "  -v         Print version number and exit\n"
-       "  -S         Disable single instance checker\n"
+       "  -c    Set custom configuration directory at runtime\n"
+       "  -d    Turn on console debugging (-dd for verbose debug)\n"
+       "  -D    Turn off console debugging (overrides preferences)\n"
+       "  -g    Open file to line (i.e Editra -g 10 file.txt)\n"
+       "  -h    Show this help message\n"
+       "  -p    Run Editra in the profiler (outputs to editra.prof).\n"
+       "  -v    Print version number and exit\n"
+       "  -S    Disable single instance checker\n"
        "\nLong Arguments:\n"
-       "  --debug    Turn on console debugging\n"
-       "  --help     Show this help message\n"
-       "  --auth     Print the ipc server info\n"
-       "  --version  Print version number and exit\n"
-      ) % ed_glob.VERSION
-    os._exit(0)
+       "  --confdir arg     Set custom configuration directory at runtime\n"
+       "  --debug           Turn on console debugging\n"
+       "  --help            Show this help message\n"
+       "  --auth            Print the ipc server info\n"
+       "  --version         Print version number and exit\n"
+       "  --profileOut arg  Run Editra in the profier (arg is output file)\n"
+      ) % ed_glob.VERSION)
+
+    if err is None:
+        os._exit(0)
+    else:
+        os._exit(1)
 
 #--------------------------------------------------------------------------#
 
 def ProcessCommandLine():
     """Process the command line switches
-    @return: tuple ([switches,], [args,])
+    @return: tuple ({switches,}, [args,])
 
     """
     try:
-        opts, args = getopt.getopt(sys.argv[1:], "dhpvDS",
-                                   ['debug', 'help', 'version', 'auth'])
+        items, args = getopt.getopt(sys.argv[1:], "dg:hp:vDSc:",
+                                   ['debug', 'help', 'version', 'auth',
+                                    'confdir=', 'profileOut='])
     except getopt.GetoptError, msg:
-        return list(), list()
-
+        # Raise error to console and exit
+        PrintHelp(str(msg))
+    
     # Process command line options
-    opts = [opt[0] for opt in opts if len(opt) == 2]
-    for opt in list(opts):
+    opts = dict(items)
+    for opt, value in dict(opts).items():
         if opt in ['-h', '--help']:
             PrintHelp()
         elif opt in ['-v', '--version']:
-            print ed_glob.VERSION
+            print(ed_glob.VERSION)
             os._exit(0)
-        elif opt in ['-d', '--debug'] and '-D' not in opts:
+        elif opt in ['-d', '--debug'] and '-D' not in opts.keys():
             # If the debug flag is set more than once go into verbose mode
             if ed_glob.DEBUG:
                 ed_glob.VDEBUG = True
             ed_glob.DEBUG = True
-            opts.remove(opt)
+            opts.pop(opt)
         elif opt == '-D':
             ed_glob.DEBUG = False
             ed_glob.VDEBUG = False
-            opts.remove('-D')
+            opts.pop('-D')
         elif opt == '-S':
-            ed_glob.SINGLE = False # Disable single instance checker
-            opts.remove(opt)
+            # Disable single instance checker
+            ed_glob.SINGLE = False
+            opts.pop(opt)
+        elif opt in ['-c', '--confdir']:
+            ed_glob.CONFIG['CONFIG_BASE'] = value
+            opts.pop(opt)
+        elif opt == '--profileOut':
+            opts['-p'] = value
+            opts.pop('--profileOut')
+        elif opt == '-g':
+            # Validate argument passed to -g
+            if not value.isdigit():
+                PrintHelp("error: -g requires a number as an argument!")
         else:
             pass
 
@@ -894,10 +992,15 @@ def Main():
     opts, args = ProcessCommandLine()
 
     if '-p' in opts:
-        opts.remove('-p')
+        p_file = opts['-p']
+        opts.pop('-p')
+
+        if not len(p_file):
+            # Fall back to default output file
+            p_file = "editra.prof"
+            
         import hotshot
-        # TODO: make output file configurable via commandline
-        prof = hotshot.Profile("editra.prof")
+        prof = hotshot.Profile(p_file)
         prof.runcall(_Main, opts, args)
         prof.close()
     else:
@@ -909,7 +1012,7 @@ def _Main(opts, args):
     @param args: Commandline arguments
 
     """
-    # Put extern subpackage on path so that bundled external dependancies
+    # Put extern subpackage on path so that bundled external dependencies
     # can be found if needed.
     if not hasattr(sys, 'frozen'):
         epath = os.path.join(os.path.dirname(__file__), 'extern')
@@ -922,7 +1025,7 @@ def _Main(opts, args):
 
     # Print ipc server authentication info
     if '--auth' in opts:
-        opts.remove('--auth')
+        opts.pop('--auth')
         print "port=%d,key=%s" % (ed_ipc.EDPORT,
                                   profiler.Profile_Get('SESSION_KEY'))
 
@@ -950,7 +1053,13 @@ def _Main(opts, args):
     # Load Session Data
     # But not if there are command line args for files to open
     if profiler.Profile_Get('SAVE_SESSION', 'bool', False) and not len(args):
-        frame.GetNotebook().LoadSessionFiles()
+        session = profiler.Profile_Get('LAST_SESSION', default=u'')
+        if isinstance(session, list):
+            # Check for format conversion from previous versions
+            profiler.Profile_Set('LAST_SESSION', u'')
+        else:
+            frame.GetNotebook().LoadSessionFile(session)
+        del session
 
     # Unlike wxMac/wxGTK Windows doesn't post an activate event when a window
     # is first shown, so do it manually to make sure all event handlers get
@@ -958,19 +1067,26 @@ def _Main(opts, args):
     if wx.Platform == '__WXMSW__':
         wx.PostEvent(frame, wx.ActivateEvent(wx.wxEVT_ACTIVATE, True))
 
-    # Do update check, only check if its been more than a day since the last
-    # check
-    if profiler.Profile_Get('CHECKUPDATE', default=True):
+    # Do update check if preferences say its ok to do so
+    isadmin = os.access(ed_glob.CONFIG['INSTALL_DIR'], os.R_OK|os.W_OK)
+    if isadmin and profiler.Profile_Get('CHECKUPDATE', default=True):
         uthread = updater.UpdateThread(editra_app, ID_UPDATE_CHECK)
         uthread.start()
 
-    for arg in args:
-        try:
-            arg = os.path.abspath(arg)
-            fname = ed_txt.DecodeString(arg, sys.getfilesystemencoding())
-            frame.DoOpen(ed_glob.ID_COMMAND_LINE_OPEN, fname)
-        except IndexError:
-            dev_tool.DEBUGP("[main][err] IndexError on commandline args")
+    if len(args):
+        line = -1
+        if '-g' in opts:
+            line = max(0, int(opts.pop('-g')) - 1)
+
+        # TODO: should line arg only be applied to the first file name or all?
+        #       currently apply to all.
+        for arg in args:
+            try:
+                fname = ed_txt.DecodeString(arg, sys.getfilesystemencoding())
+                fname = ebmlib.GetAbsPath(fname)
+                frame.DoOpen(ed_glob.ID_COMMAND_LINE_OPEN, fname, line)
+            except IndexError:
+                dev_tool.DEBUGP("[main][err] IndexError on commandline args")
 
     # Notify that profile was updated
     if editra_app.GetProfileUpdated():
@@ -979,7 +1095,7 @@ def _Main(opts, args):
         profiler.Profile_Del('WPOS')
         wx.MessageBox(_("Your profile has been updated to the latest "
                         "version") + u"\n" + \
-                      _("Please check the preferences dialog to check "
+                      _("Please check the preferences dialog to verify "
                         "your preferences"),
                       _("Profile Updated"))
 
