@@ -16,8 +16,8 @@ deduct the requested information.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: pycomp.py 58932 2009-02-16 03:23:34Z CJP $"
-__revision__ = "$Revision: 58932 $"
+__cvsid__ = "$Id: pycomp.py 63256 2010-01-25 02:34:08Z CJP $"
+__revision__ = "$Revision: 63256 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -43,12 +43,6 @@ import completer
 
 class Completer(completer.BaseCompleter):
     """Code completer provider"""
-    _autocomp_keys = [ord('.'), ]
-    _autocomp_stop = ' \'"\\`):'
-    _autocomp_fillup = '.,;([]}<>%^&+-=*/|'
-    _calltip_keys = [ord('('), ]
-    _calltip_cancel = [ord(')'), wx.WXK_RETURN]
-
     def __init__(self, stc_buffer):
         """Initiliazes the completer
         @param stc_buffer: buffer that contains code
@@ -56,6 +50,13 @@ class Completer(completer.BaseCompleter):
         """
         completer.BaseCompleter.__init__(self, stc_buffer)
 
+        # Setup
+        self.SetAutoCompKeys([ord('.'), ])
+        self.SetAutoCompStops(' \'"\\`):')
+        self.SetAutoCompFillups('.,;([]}<>%^&+-=*/|')
+        self.SetCallTipKeys([ord('('), ])
+        self.SetCallTipCancel([ord(')'), wx.WXK_RETURN])
+
         # Needed for introspect to run
         try:
             sys.ps1
@@ -73,7 +74,9 @@ class Completer(completer.BaseCompleter):
 
         """
         if command is None or (len(command) and command[0].isdigit()):
-            return ''
+            if calltip:
+                return u""
+            return list()
 
         try:
             cmpl = PyCompleter()
@@ -82,7 +85,8 @@ class Completer(completer.BaseCompleter):
             # chance of getting the proper completions
             fname = self._buffer.GetFileName()
             if fname:
-                sys.path.insert(0, os.path.dirname(fname))
+                fpath = os.path.dirname(fname)
+                sys.path.insert(0, fpath)
 
             cmpl.evalsource(self._buffer.GetText(),
                             self._buffer.GetCurrentLine())
@@ -93,24 +97,36 @@ class Completer(completer.BaseCompleter):
             if calltip:
                 return cmpl.get_completions(command + '(', '', calltip)
             else:
-                # Get Autocompletion List
+                # Get Auto-completion List
                 complst = cmpl.get_completions(command)
-                sigs = [ sig['word'].rstrip('(.') for sig in complst ]
-                sigs.sort(lambda x, y: cmp(x.upper(), y.upper()))
+                sigs = list()
+                type = completer.TYPE_UNKNOWN
+                for sig in complst:
+                    word = sig['word'].rstrip(u'(.')
+                    if sig['type'] == "function":
+                        type = completer.TYPE_FUNCTION
+                    elif sig['type'] == "method":
+                        type = completer.TYPE_METHOD
+                    elif sig['type'] == "class":
+                        type = completer.TYPE_CLASS
+                    elif sig['type'] == "attribute":
+                        type = completer.TYPE_ATTRIBUTE
+                    elif sig['type'] == "property":
+                        type = completer.TYPE_PROPERTY
+                    
+                    sigs.append(completer.Symbol(word, type))
+
+#                sigs = [ sig['word'].rstrip('(.') for sig in complst ]
+                sigs.sort(lambda x, y: cmp(x.Name.upper(), y.Name.upper()))
                 return sigs
 
         except Exception, msg:
             self._log("[pycomp][err] _GetCompletionInfo: %s, %s" % \
                       (sys.exc_info()[0], sys.exc_info()[1]))
-            return ''
-
-    def GetAutoCompKeys(self):
-        """Returns the list of key codes for activating the
-        autocompletion.
-        @return: list of autocomp activation keys
-
-        """
-        return Completer._autocomp_keys
+            if calltip:
+                return u""
+            else:
+                return []
         
     def GetAutoCompList(self, command):
         """Returns the list of possible completions for a 
@@ -122,36 +138,37 @@ class Completer(completer.BaseCompleter):
         """
         return self._GetCompletionInfo(command)
 
-    def GetAutoCompStops(self):
-        """Returns a string of characters that should cancel
-        the autocompletion lookup.
-        @return: string of keys that will cancel autocomp/calltip actions
-
-        """
-        return Completer._autocomp_stop
-    
-    def GetAutoCompFillups(self):
-        return Completer._autocomp_fillup
-
     def GetCallTip(self, command):
-        """Returns the formated calltip string for the command.
+        """Returns the formatted calltip string for the command.
         If the namespace command is unset the locals namespace is used.
         @param command: command to get calltip for
-        @keyword namespace: namespace to do lookup in
 
         """
-        return self._GetCompletionInfo(command, calltip=True)
+        # get the relevant text
+        alltext = self._GetCompletionInfo(command, calltip=True)
+       
+        # split the text into natural paragraphs (a blank line separated)
+        paratext = alltext.split("\n\n")
+       
+        # add text by paragraph until text limit or all paragraphs
+        textlimit = 800
+        if len(paratext[0]) < textlimit:
+            numpara = len(paratext)
+            calltiptext = paratext[0]
+            ii = 1
+            while ii < numpara and \
+                  (len(calltiptext) + len(paratext[ii])) < textlimit:
+                calltiptext = calltiptext + "\n\n" + paratext[ii]
+                ii = ii + 1
 
-    def GetCallTipKeys(self):
-        """Returns the list of keys to activate a calltip on
-        @return: list of keys that can activate a calltip
-
-        """
-        return Completer._calltip_keys
-
-    def GetCallTipCancel(self):
-        """Get the list of key codes that should stop a calltip"""
-        return Completer._calltip_cancel
+            # if not all texts are added, add "[...]"
+            if ii < numpara:
+                calltiptext = calltiptext + "\n[...]"
+        # present the function signature only (first newline)
+        else:
+            calltiptext = alltext.split("\n")[0]
+           
+        return calltiptext
 
 #-----------------------------------------------------------------------------#
 # This code below is a modified and adapted version of the pythoncomplete 
@@ -269,14 +286,16 @@ class PyCompleter(object):
                 if ctip:
                     # Use introspect for calltips for now until some
                     # issues are sorted out with the main parser
-                    return introspect.getCallTip(_sanitize(stmt), 
-                                                 self.compldict)[2]
+                    tip = introspect.getCallTip(_sanitize(stmt), 
+                                                self.compldict)[2]
+                    if not isinstance(tip, basestring):
+                        tip = u""
+                    return tip
                 else:
                     result = eval(_sanitize(stmt[:-1]), self.compldict)
-
-                doc = max(getattr(result, '__doc__', ''), ' ')
-                return [{'word' : _cleanstr(self.get_arguments(result)), 
-                         'info' : _cleanstr(doc)}]
+                    doc = max(getattr(result, '__doc__', ''), ' ')
+                    return [{'word' : _cleanstr(self.get_arguments(result)), 
+                             'info' : _cleanstr(doc)}]
             elif ridx == -1:
                 match = stmt
                 compdict = self.compldict
@@ -288,6 +307,7 @@ class PyCompleter(object):
 
             dbg("[pycomp] completing: stmt:%s" % stmt)
             completions = []
+            isdict = isinstance(compdict, dict)
             for meth in compdict:
                 if meth == "_PyCmplNoType":
                     continue #this is internal
@@ -311,22 +331,40 @@ class PyCompleter(object):
                         else:
                             doc = ' '
 
+                        if isdict:
+                            typestr = str(compdict[inst])
+                        else:
+                            typestr = str(inst)
+
                         comp = {'word' : meth,
                                 'abbr' : meth,
-                                'info' : _cleanstr(str(doc))}
+                                'info' : _cleanstr(str(doc)),
+                                'type' : typestr}
 
-                        typestr = str(inst)
                         if "function" in typestr:
                             comp['word'] += '('
                             comp['abbr'] += '(' + _cleanstr(self.get_arguments(inst))
-                        elif "method" in typestr:
+                            comp['type'] = "function"
+                        elif "method" in typestr or "slot wrapper" in typestr:
                             comp['word'] += '('
                             comp['abbr'] += '(' + _cleanstr(self.get_arguments(inst))
+                            comp['type'] = "method"
                         elif "module" in typestr:
                             comp['word'] += '.'
+                            comp['type'] = "module"
                         elif "class" in typestr:
                             comp['word'] += '('
                             comp['abbr'] += '('
+                            comp['type'] = "class"
+                        elif "attribute" in typestr or \
+                             (not typestr.startswith('__') and \
+                              not typestr.startswith('<')):
+                            comp['type'] = "attribute"
+                        elif "property" in typestr: 
+                            comp['type'] = "property"
+#                        else:
+#                            print typestr, meth
+
                         completions.append(comp)
                 except Exception, msg:
                     dbg("[pycomp][err] inner completion: %s [stmt='%s']:" % (msg, stmt))
@@ -334,6 +372,8 @@ class PyCompleter(object):
             return completions
         except Exception, msg:
             dbg("[pycomp][err] get_completions: %s [stmt='%s']" % (msg, stmt))
+            if ctip:
+                return u""
             return []
 
 #-----------------------------------------------------------------------------#
@@ -865,7 +905,10 @@ class PyParser:
                         stmt = self._parseassignment()
                         dbg("[pycomp] parseassignment: %s = %s" % (name, stmt))
                         if stmt != None:
-                            self.scope.local("%s = %s" % (name, stmt))
+                            # XXX Safety Check don't allow assigments to 
+                            # item attributes unless the attribute is self
+                            if u'.' not in name or name.startswith(u'self'):
+                                self.scope.local("%s = %s" % (name, stmt))
                     freshscope = False
         except StopIteration: #thrown on EOF
             pass
