@@ -20,30 +20,39 @@ happen during run time.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: profiler.py 53693 2008-05-21 22:01:34Z CJP $"
-__revision__ = "$Revision: 53693 $"
+__svnid__ = "$Id: profiler.py 63791 2010-03-30 02:57:15Z CJP $"
+__revision__ = "$Revision: 63791 $"
 
 #--------------------------------------------------------------------------#
-# Dependancies
+# Imports
 import os
 import sys
 import cPickle
 import wx
-from ed_glob import CONFIG, PROG_NAME, VERSION
+
+# Editra Imports
+from ed_glob import CONFIG, PROG_NAME, VERSION, PRINT_BLACK_WHITE, EOL_MODE_LF
 import util
 import dev_tool
+import ed_msg
 
 _ = wx.GetTranslation
 #--------------------------------------------------------------------------#
 # Globals
 _DEFAULTS = {
-           'ALPHA'      : 255,              # Transparency level
+           'ALPHA'      : 255,              # Transparency level (0-255)
            'AALIASING'  : False,            # Use Anti-Aliasing if availble
            'APPSPLASH'  : True,             # Show splash at startup
+           'AUTOBACKUP' : False,            # Automatically backup files
+           'AUTOBACKUP_PATH' : '',          # Backup path
            'AUTO_COMP'  : True,             # Use Auto-comp if available
+           'AUTO_COMP_EX' : False,          # Use extended autocompletion
            'AUTO_INDENT': True,             # Use Auto Indent
+           'AUTO_TRIM_WS' : False,          # Trim whitespace on save
+           'AUTO_RELOAD' : False,           # Automatically reload files?
            'BRACKETHL'  : True,             # Use bracket highlighting
            'BSUNINDENT' : True,             # Backspace Unindents
+           'CTRLBAR'    : dict(),           # ControlBar layouts
            'CHECKMOD'   : True,             # Auto check file for file mod
            'CHECKUPDATE': True,             # Check for updates on start
            'CODE_FOLD'  : True,             # Use code folding
@@ -51,7 +60,8 @@ _DEFAULTS = {
            'DEFAULT'    : False,            # No longer used I believe
            'DEFAULT_VIEW' : 'Automatic',    # Default Perspective
            'EDGE'       : 80,               # Edge guide column
-           'EOL'        : 'Unix (\\n)',     # EOL mode
+           'ENCODING'   : None,             # Prefered text encoding
+           'EOL_MODE'   : EOL_MODE_LF,      # EOL mode 1 == LF, 2 == CRLF
            'FHIST'      : list(),           # List of history files
            'FHIST_LVL'  : 9,                # Filehistory length (9 is max)
            'FFILTER'    : 0,                # Last file filter used
@@ -60,33 +70,44 @@ _DEFAULTS = {
            'ICONS'      : 'Tango',          # Icon Theme
            'ICON_SZ'    : (24, 24),         # Toolbar Icon Size
            'INDENTWIDTH': 4,                # Default indent width
+           'ISBINARY'   : False,            # Is this instance a binary
            'KEY_PROFILE': None,             # Keybinding profile
            'LANG'       : 'Default',        # UI language
            'LASTCHECK'  : 0,                # Last time update check was done
+           #'LEXERMENU'  : [lang_name,]     # Created on an as needed basis
            'MAXIMIZED'  : False,            # Was window maximized on exit
            'MODE'       : 'CODE',           # Overall editor mode
            'MYPROFILE'  : 'default.ppb',    # Path to profile file
            'OPEN_NW'    : False,            # Open files in new windows
-           'PRINT_MODE' : 'BLACK/WHITE',    # Printer rendering mode
+           'PRINT_MODE' : PRINT_BLACK_WHITE,# Printer rendering mode
            'PROXY_SETTINGS' : dict(),       # Proxy Server Settings
            'REPORTER'   : True,             # Error Reporter is Active
            'SAVE_POS'   : True,             # Remember Carat positions
            'SAVE_SESSION' : False,          # Load previous session on startup
+           'SEARCH_LOC' : list(),           # Recent Search Locations
+           'SEARCH_FILTER' : '',            # Last used search filter
+           'SESSION_KEY' : '',              # Ipc Session Server Key
            'SET_WPOS'   : True,             # Remember window position
            'SET_WSIZE'  : True,             # Remember mainwindow size on exit
            'SHOW_EDGE'  : True,             # Show Edge Guide
            'SHOW_EOL'   : False,            # Show EOL markers
            'SHOW_LN'    : True,             # Show Line Numbers
            'SHOW_WS'    : False,            # Show whitespace markers
+           'SPELLCHECK' : dict(auto=False,
+                               dict='en_US',
+                               epath=None), # Spell checking preferences
            'STATBAR'    : True,             # Show Status Bar
            'SYNTAX'     : True,             # Use Syntax Highlighting
            'SYNTHEME'   : 'Default',        # Syntax Highlight color scheme
+           'TABICONS'   : True,             # Show Tab Icons
            'TABWIDTH'   : 8,                # Tab width
            'THEME'      : 'DEFAULT',        # For future use
            'TOOLBAR'    : True,             # Show Toolbar
            'USETABS'    : False,            # Use tabs instead of spaces
            'USE_PROXY'  : False,            # Use Proxy server settings?
            'VI_EMU'     : False,            # Use Vi emulation mode
+           'VI_NORMAL_DEFAULT' : False,     # Use Normal mode by default
+           'WARN_EOL'   : True,             # Warn about mixed eol characters
            'WRAP'       : False,            # Use Wordwrap
            'WSIZE'      : (700, 450)        # Mainwindow size
           #FONT1 created at runtime by ed_styles as primary font
@@ -133,7 +154,7 @@ class Profile(dict):
         @type item: string
 
         """
-        if self.has_key(item):
+        if item in self:
             del self[item]
         else:
             pass
@@ -147,7 +168,7 @@ class Profile(dict):
                           not in profile.
 
         """
-        if self.has_key(index):
+        if index in self:
             val = self.__getitem__(index)
         else:
             return default
@@ -209,6 +230,9 @@ class Profile(dict):
         else:
             self.__setitem__(index, _FromObject(val, fmt))
 
+        # Notify all clients with the configuration change message
+        ed_msg.PostMessage(ed_msg.EDMSG_PROFILE_CHANGE + (index,), val) 
+
     def Write(self, path):
         """Write the dataset of this profile as a pickle
         @param path: path to where to write the pickle
@@ -216,13 +240,16 @@ class Profile(dict):
 
         """
         try:
+            # Only write if given an absolute path
+            if not os.path.isabs(path):
+                return False
             self.Set('MYPROFILE', path)
             fhandle = open(path, 'wb')
             cPickle.dump(self.copy(), fhandle, cPickle.HIGHEST_PROTOCOL)
             fhandle.close()
             UpdateProfileLoader()
         except (IOError, cPickle.PickleError), msg:
-            dev_tool.DEBUGP("[profile][err] %s" % str(msg))
+            dev_tool.DEBUGP(u"[profile][err] %s" % msg)
             return False
         else:
             return True
@@ -239,13 +266,18 @@ class Profile(dict):
         """
         if update is None:
             for key, val in _DEFAULTS.iteritems():
-                if not self.has_key(key):
+                if key not in self:
                     self.Set(key, val)
         else:
             self.update(update)
 
     #---- End Public Members ----#
 
+#-----------------------------------------------------------------------------#
+# Singleton reference instance
+
+TheProfile = Profile()
+
 #-----------------------------------------------------------------------------#
 # Profile convenience functions
 def Profile_Del(item):
@@ -253,7 +285,7 @@ def Profile_Del(item):
     @param item: items key name
 
     """
-    Profile().DeleteItem(item)
+    TheProfile.DeleteItem(item)
 
 def Profile_Get(index, fmt=None, default=None):
     """Convenience for Profile().Get()
@@ -262,7 +294,7 @@ def Profile_Get(index, fmt=None, default=None):
     @keyword default: default value to return if not found
 
     """
-    return Profile().Get(index, fmt, default)
+    return TheProfile.Get(index, fmt, default)
 
 def Profile_Set(index, val, fmt=None):
     """Convenience for Profile().Set()
@@ -271,7 +303,7 @@ def Profile_Set(index, val, fmt=None):
     @keyword fmt: format to convert object from
 
     """
-    return Profile().Set(index, val, fmt)
+    return TheProfile.Set(index, val, fmt)
 
 def _FromObject(val, fmt):
     """Convert the given value to a to a profile compatible value
@@ -294,36 +326,33 @@ def _ToObject(index, val, fmt):
     @todo: exception handling,
 
     """
-    if not isinstance(fmt, basestring):
-        raise TypeError, "_ToObject expects a string for parameter 2"
-    else:
-        tmp = fmt.lower()
-        if tmp == u'font':
-            fnt = val.split(',')
-            rval = wx.FFont(int(fnt[1]), wx.DEFAULT, face=fnt[0])
-        elif tmp == u'bool':
-            if isinstance(val, bool):
-                rval = val
-            else:
-                rval = _DEFAULTS.get(index, False)
-        elif tmp == u'size_tuple':
-            if len(val) == 2 and \
-               isinstance(val[0], int) and isinstance(val[1], int):
-                rval = val
-            else:
-                rval = _DEFAULTS.get(index, wx.DefaultSize)
-        elif tmp == u'str':
-            rval = unicode(val)
-        elif tmp == u'int':
-            if isinstance(val, int):
-                rval = val
-            elif isinstance(val, basestring) and val.isdigit():
-                rval = int(val)
-            else:
-                rval = _DEFAULTS.get(index)
+    tmp = fmt.lower()
+    if tmp == u'font':
+        fnt = val.split(',')
+        rval = wx.FFont(int(fnt[1]), wx.DEFAULT, face=fnt[0])
+    elif tmp == u'bool':
+        if isinstance(val, bool):
+            rval = val
         else:
-            return val
-        return rval
+            rval = _DEFAULTS.get(index, False)
+    elif tmp == u'size_tuple':
+        if len(val) == 2 and \
+           isinstance(val[0], int) and isinstance(val[1], int):
+            rval = val
+        else:
+            rval = _DEFAULTS.get(index, wx.DefaultSize)
+    elif tmp == u'str':
+        rval = unicode(val)
+    elif tmp == u'int':
+        if isinstance(val, int):
+            rval = val
+        elif isinstance(val, basestring) and val.isdigit():
+            rval = int(val)
+        else:
+            rval = _DEFAULTS.get(index)
+    else:
+        return val
+    return rval
 
 #---- Begin Function Definitions ----#
 def AddFileHistoryToProfile(file_history):
@@ -340,13 +369,14 @@ def AddFileHistoryToProfile(file_history):
 
 def CalcVersionValue(ver_str="0.0.0"):
     """Calculates a version value from the provided dot-formated string
-    @keyword ver_str: Version string to calculate value of
 
     1) SPECIFICATION: Version value calculation AA.BBB.CCC
          - major values: < 1     (i.e 0.0.85 = 0.850)
          - minor values: 1 - 999 (i.e 0.1.85 = 1.850)
          - micro values: >= 1000 (i.e 1.1.85 = 1001.850)
 
+    @keyword ver_str: Version string to calculate value of
+
     """
     ver_str = ''.join([char for char in ver_str
                        if char.isdigit() or char == '.'])
@@ -368,8 +398,12 @@ def GetLoader():
            should be.
 
     """
-    loader = os.path.join(wx.GetHomeDir(), u"." + PROG_NAME,
-                          u"profiles", u".loader2")
+    cbase = CONFIG['CONFIG_BASE']
+    if cbase is None:
+        cbase = wx.StandardPaths_Get().GetUserDataDir()
+
+    loader = os.path.join(cbase, u"profiles", u".loader2")
+
     return loader
 
 def GetProfileStr():
@@ -407,7 +441,7 @@ def ProfileVersionStr():
 
     """
     loader = GetLoader()
-    reader = util.GetFileReader(loader)
+    reader = util.GetFileReader(loader, sys.getfilesystemencoding())
     if reader == -1:
         return "0.0.0"
 
@@ -430,6 +464,7 @@ def ProfileVersionStr():
 
 def UpdateProfileLoader():
     """Updates Loader File
+    @precondition: MYPROFILE has been set
     @postcondition: on disk profile loader is updated
     @return: 0 if no error, non zero for error condition
 
@@ -439,10 +474,18 @@ def UpdateProfileLoader():
         return 1
 
     prof_name = Profile_Get('MYPROFILE')
-    if not prof_name:
+    if not prof_name or not os.path.isabs(prof_name):
         prof_name = CONFIG['PROFILE_DIR'] + 'default.ppb'
 
-    prof_name = prof_name.encode(sys.getfilesystemencoding())
+    if not os.path.exists(prof_name):
+        prof_name = os.path.join(CONFIG['CONFIG_DIR'],
+                                 os.path.basename(prof_name))
+        Profile_Set('MYPROFILE', prof_name)
+
+    # Use just the relative profile name for local(portable) config paths
+    if CONFIG['ISLOCAL']:
+        prof_name = os.path.basename(prof_name)
+
     writer.write(prof_name)
     writer.write(u"\nVERSION\t" + VERSION)
     writer.close()
