@@ -12,15 +12,13 @@ This file contains various helper functions and utilities that the program uses.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: util.py 58724 2009-02-07 20:57:44Z CJP $"
-__revision__ = "$Revision: 58724 $"
+__svnid__ = "$Id: util.py 64250 2010-05-08 16:00:52Z CJP $"
+__revision__ = "$Revision: 64250 $"
 
 #--------------------------------------------------------------------------#
 # Imports
 import os
 import sys
-import stat
-import types
 import mimetypes
 import encodings
 import codecs
@@ -34,6 +32,7 @@ import ed_crypt
 import dev_tool
 import syntax.syntax as syntax
 import syntax.synglob as synglob
+import ebmlib
 
 _ = wx.GetTranslation
 #--------------------------------------------------------------------------#
@@ -50,11 +49,15 @@ class DropTargetFT(wx.PyDropTarget):
 
         """
         wx.PyDropTarget.__init__(self)
+
+        # Attributes
         self.window = window
         self._data = dict(data=None, fdata=None, tdata=None,
                           tcallb=textcallback, fcallb=filecallback)
         self._tmp = None
         self._lastp = None
+
+        # Setup
         self.InitObjects()
 
     def CreateDragString(self, txt):
@@ -134,8 +137,8 @@ class DropTargetFT(wx.PyDropTarget):
     def OnDragOver(self, x_cord, y_cord, drag_result):
         """Called when the cursor is moved during a drag action
         @return: result of drag over
-        @todo: For some reason the carrat postion changes which can be seen
-               by the brackets getting highlighted. However the actual carrat
+        @todo: For some reason the caret position changes which can be seen
+               by the brackets getting highlighted. However the actual caret
                is not moved.
 
         """
@@ -231,6 +234,43 @@ class DropTargetFT(wx.PyDropTarget):
 
 #---- End FileDropTarget ----#
 
+class EdClipboard(ebmlib.CycleCache):
+    """Local clipboard object
+    @todo: make into a singleton
+
+    """
+    def GetNext(self):
+        """Get the next item in the cache"""
+        # Initialize the clipboard if it hasn't been loaded yet and
+        # there is something in the system clipboard
+        if self.GetCurrentSize() == 0:
+            txt = GetClipboardText()
+            if txt is not None:
+                self.Put(txt)
+
+        return super(EdClipboard, self).GetNext()
+
+    def IsAtIndex(self, txt):
+        """Is the passed in phrase at the current cycle index in the
+        cache. Used to check if index should be reset or to continue in
+        the cycle.
+        @param txt: selected text
+
+        """
+        pre = self.PeekPrev()
+        next = self.PeekNext()
+        if txt in (pre, next):
+            return True
+        else:
+            return False
+
+    def Put(self, txt):
+        """Put some text in the clipboard"""
+        pre = self.PeekPrev()
+        next = self.PeekNext()
+        if len(txt) and txt not in (pre, next):
+            self.PutItem(txt)
+
 #---- Misc Common Function Library ----#
 # Used for holding the primary selection on mac/msw
 FAKE_CLIPBOARD = None
@@ -251,7 +291,8 @@ def GetClipboardText(primary=False):
 
     text_obj = wx.TextDataObject()
     rtxt = None
-    if wx.TheClipboard.Open():
+    
+    if wx.TheClipboard.IsOpened() or wx.TheClipboard.Open():
         if wx.TheClipboard.GetData(text_obj):
             rtxt = text_obj.GetText()
         wx.TheClipboard.Close()
@@ -279,7 +320,7 @@ def SetClipboardText(txt, primary=False):
 
     data_o = wx.TextDataObject()
     data_o.SetText(txt)
-    if wx.TheClipboard.Open():
+    if wx.TheClipboard.IsOpened() or wx.TheClipboard.Open():
         wx.TheClipboard.SetData(data_o)
         wx.TheClipboard.Close()
         if primary and wx.Platform == '__WXGTK__':
@@ -295,23 +336,12 @@ def FilterFiles(file_list):
 
     """
     good = list()
-    checker = FileTypeChecker()
+    checker = ebmlib.FileTypeChecker()
     for path in file_list:
         if not checker.IsBinary(path):
             good.append(path)
     return good
 
-def GetFileModTime(file_name):
-    """Returns the time that the given file was last modified on
-    @param file_name: path of file to get mtime of
-
-    """
-    try:
-        mod_time = os.path.getmtime(file_name)
-    except (OSError, EnvironmentError):
-        mod_time = 0
-    return mod_time
-
 def GetFileType(fname):
     """Get what the type of the file is as Editra sees it
     in a formatted string.
@@ -382,38 +412,6 @@ def GetFileWriter(file_name, enc='utf-8'):
         writer = file_h
     return writer
 
-def GetUniqueName(path, name):
-    """Make a file name that will be unique in case a file of the
-    same name already exists at that path.
-    @param path: Root path to folder of files destination
-    @param name: desired file name base
-    @return: string
-
-    """
-    tmpname = os.path.join(path, name)
-    if os.path.exists(tmpname):
-        if '.' not in name:
-            ext = ''
-            fbase = name
-        else:
-            ext = '.' + name.split('.')[-1]
-            fbase = name[:-1 * len(ext)]
-
-        inc = len([x for x in os.listdir(path) if x.startswith(fbase)])
-        tmpname = os.path.join(path, "%s-%d%s" % (fbase, inc, ext))
-        while os.path.exists(tmpname):
-            inc = inc + 1
-            tmpname = os.path.join(path, "%s-%d%s" % (fbase, inc, ext))
-
-    return tmpname
-
-def GetPathName(path):
-    """Gets the path minus filename
-    @param path: full path to get base of
-
-    """
-    return os.path.split(path)[0]
-
 def GetFileManagerCmd():
     """Get the file manager open command for the current os. Under linux
     it will check for xdg-open, nautilus, konqueror, and Thunar, it will then
@@ -435,71 +433,6 @@ def GetFileManagerCmd():
         else:
             return 'nautilus'
 
-def GetFileName(path):
-    """Gets last atom on end of string as filename
-    @param path: full path to get filename from
-
-    """
-    return os.path.split(path)[-1]
-
-def GetFileSize(path):
-    """Get the size of the file at a given path
-    @param path: Path to file
-    @return: long
-
-    """
-    try:
-        return os.stat(path)[stat.ST_SIZE]
-    except:
-        return 0
-
-def GetExtension(file_str):
-    """Gets last atom at end of string as extension if
-    no extension whole string is returned
-    @param file_str: path or file name to get extension from
-
-    """
-    return file_str.split('.')[-1]
-
-def MakeNewFile(path, name):
-    """Make a new file at the given path with the given name.
-    If the file already exists, the given name will be changed to
-    a unique name in the form of name + -NUMBER + .extension
-    @param path: path to directory to create file in
-    @param name: desired name of file
-    @return: Tuple of (success?, Path of new file OR Error message)
-
-    """
-    if not os.path.isdir(path):
-        path = os.path.dirname(path)
-    fname = GetUniqueName(path, name)
-
-    try:
-        open(fname, 'w').close()
-    except (IOError, OSError), msg:
-        return (False, str(msg))
-
-    return (True, fname)
-
-def MakeNewFolder(path, name):
-    """Make a new folder at the given path with the given name.
-    If the folder already exists, the given name will be changed to
-    a unique name in the form of name + -NUMBER.
-    @param path: path to create folder on
-    @param name: desired name for folder
-    @return: Tuple of (success?, new dirname OR Error message)
-
-    """
-    if not os.path.isdir(path):
-        path = os.path.dirname(path)
-    folder = GetUniqueName(path, name)
-    try:
-        os.mkdir(folder)
-    except (OSError, IOError), msg:
-        return (False, str(msg))
-
-    return (True, folder)
-
 def HasConfigDir(loc=u""):
     """ Checks if the user has a config directory and returns True
     if the config directory exists or False if it does not.
@@ -527,6 +460,20 @@ def MakeConfigDir(name):
     except (OSError, IOError):
         pass
 
+def RepairConfigState(path):
+    """Repair the state of profile path, updating and creating it
+    it does not exist.
+    @param path: path of profile
+
+    """
+    if os.path.isabs(path) and os.path.exists(path):
+        return path
+    else:
+        # Need to fix some stuff up
+        CreateConfigDir()
+        import profiler
+        return profiler.Profile_Get("MYPROFILE")
+
 def CreateConfigDir():
     """ Creates the user config directory its default sub
     directories and any of the default config files.
@@ -554,8 +501,9 @@ def CreateConfigDir():
             MakeConfigDir(cfg)
 
     import profiler
-    profiler.Profile().LoadDefaults()
+    profiler.TheProfile.LoadDefaults()
     profiler.Profile_Set("MYPROFILE", dest_file)
+    profiler.TheProfile.Write(dest_file)
     profiler.UpdateProfileLoader()
 
 def ResolvConfigDir(config_dir, sys_only=False):
@@ -584,6 +532,15 @@ def ResolvConfigDir(config_dir, sys_only=False):
         if os.path.exists(user_config):
             return user_config + os.sep
 
+    # Check if the system install path has already been resolved once before
+    if ed_glob.CONFIG['INSTALL_DIR'] != u"":
+        tmp = os.path.join(ed_glob.CONFIG['INSTALL_DIR'], config_dir)
+        tmp = os.path.normpath(tmp) + os.sep
+        if os.path.exists(tmp):
+            return tmp
+        else:
+            del tmp
+
     # The following lines are used only when Editra is being run as a
     # source package. If the found path does not exist then Editra is
     # running as as a built package.
@@ -592,14 +549,14 @@ def ResolvConfigDir(config_dir, sys_only=False):
         path = os.sep.join(path.split(os.sep)[:-2])
         path =  path + os.sep + config_dir + os.sep
         if os.path.exists(path):
-            if not isinstance(path, types.UnicodeType):
+            if not ebmlib.IsUnicode(path):
                 path = unicode(path, sys.getfilesystemencoding())
             return path
 
     # If we get here we need to do some platform dependant lookup
     # to find everything.
     path = sys.argv[0]
-    if not isinstance(path, types.UnicodeType):
+    if not ebmlib.IsUnicode(path):
         path = unicode(path, sys.getfilesystemencoding())
 
     # If it is a link get the real path
@@ -644,7 +601,7 @@ def ResolvConfigDir(config_dir, sys_only=False):
     path = os.path.normpath(pro_path) + os.sep
 
     # Make sure path is unicode
-    if not isinstance(path, types.UnicodeType):
+    if not ebmlib.IsUnicode(path):
         path = unicode(path, sys.getdefaultencoding())
 
     return path
@@ -758,45 +715,6 @@ def GetProxyOpener(proxy_set):
     return opener
 
 #---- GUI helper functions ----#
-def AdjustColour(color, percent, alpha=wx.ALPHA_OPAQUE):
-    """ Brighten/Darken input colour by percent and adjust alpha
-    channel if needed. Returns the modified color.
-    @param color: color object to adjust
-    @type color: wx.Color
-    @param percent: percent to adjust +(brighten) or -(darken)
-    @type percent: int
-    @keyword alpha: Value to adjust alpha channel to
-
-    """
-    radj, gadj, badj = [ int(val * (abs(percent) / 100.))
-                         for val in color.Get() ]
-
-    if percent < 0:
-        radj, gadj, badj = [ val * -1 for val in [radj, gadj, badj] ]
-    else:
-        radj, gadj, badj = [ val or percent for val in [radj, gadj, badj] ]
-
-    red = min(color.Red() + radj, 255)
-    green = min(color.Green() + gadj, 255)
-    blue = min(color.Blue() + badj, 255)
-    return wx.Colour(red, green, blue, alpha)
-
-def HexToRGB(hex_str):
-    """Returns a list of red/green/blue values from a
-    hex string.
-    @param hex_str: hex string to convert to rgb
-
-    """
-    hexval = hex_str
-    if hexval[0] == u"#":
-        hexval = hexval[1:]
-    ldiff = 6 - len(hexval)
-    hexval += ldiff * u"0"
-    # Convert hex values to integer
-    red = int(hexval[0:2], 16)
-    green = int(hexval[2:4], 16)
-    blue = int(hexval[4:], 16)
-    return [red, green, blue]
 
 def SetWindowIcon(window):
     """Sets the given windows icon to be the programs
@@ -816,59 +734,6 @@ def SetWindowIcon(window):
 
 #-----------------------------------------------------------------------------#
 
-class FileTypeChecker:
-    """File type checker and recognizer"""
-    TXTCHARS = ''.join(map(chr, [7,8,9,10,12,13,27] + range(0x20, 0x100)))
-    ALLBYTES = ''.join(map(chr, range(256)))
-
-    def __init__(self, preread=4096):
-        """Create the FileTypeChecker
-        @keyword preread: number of bytes to read for checking file type
-
-        """
-        # Attributes
-        self._preread = preread
-
-    def _GetHandle(self, fname):
-        """Get a file handle for reading
-        @param fname: filename
-        @return: file object or None
-
-        """
-        try:
-            handle = open(fname, 'rb')
-        except:
-            handle = None
-        return handle
-
-    def IsBinary(self, fname):
-        """Is the file made up of binary data
-        @param fname: filename to check
-        @return: bool
-
-        """
-        handle = self._GetHandle(fname)
-        if handle is not None:
-            bytes = handle.read(self._preread)
-            handle.close()
-            nontext = bytes.translate(FileTypeChecker.ALLBYTES,
-                                      FileTypeChecker.TXTCHARS)
-            return bool(nontext)
-        else:
-            return False
-
-    def IsReadableText(self, fname):
-        """Is the given path readable as text
-        @param fname: filename
-
-        """
-        f_ok = False
-        if os.access(fname, os.R_OK):
-            f_ok = not self.IsBinary(fname)
-        return f_ok
-
-#-----------------------------------------------------------------------------#
-
 class IntValidator(wx.PyValidator):
     """A Generic integer validator"""
     def __init__(self, min_=0, max_=0):
