@@ -2,7 +2,7 @@
 # Purpose:      base component classes
 # Author:       Roman Rolinsky <rolinsky@femagsoft.com>
 # Created:      31.05.2007
-# RCS-ID:       $Id: component.py 53803 2008-05-28 13:25:26Z ROL $
+# RCS-ID:       $Id: component.py 64107 2010-04-22 14:05:36Z ROL $
 
 """
 Component plugin classes.
@@ -103,6 +103,8 @@ class Component(object):
     renameDict = {}
     '''Dictionary of I{old_name}:I{new_name} for renaming some attributes
     in the Attribute Panel.'''
+    hasCode = True
+    '''True if component can generate code.'''
     
     def __init__(self, klass, groups, attributes, **kargs):
         '''
@@ -184,6 +186,8 @@ class Component(object):
             return 0
 
     def getTreeText(self, node):
+        if node.nodeType == node.COMMENT_NODE:
+            return node.data
         if node.tagName == 'object_ref':
             ref = node.getAttribute('ref')
             label = 'ref: %s' % ref
@@ -306,13 +310,13 @@ class Component(object):
                 # Style and exstyle are not in attributes and can be treated specially
                 if a == 'style':
                     styles = self.getAttribute(srcNode, a).split('|')
-                    allStyles = dstComp.styles + params.genericStyles
+                    allStyles = dstComp.styles + self.genericStyles
                     dstStyles = [s for s in styles if s.strip() in allStyles]
                     if dstStyles:
                         dstComp.addAttribute(dstNode, a, '|'.join(dstStyles))
                 elif a == 'exstyle':
                     styles = self.getAttribute(srcNode, a).split('|')
-                    allStyles = dstComp.exStyles + params.genericExStyles
+                    allStyles = dstComp.exStyles + self.genericExStyles
                     dstStyles = [s for s in styles if s.strip() in allStyles]
                     if dstStyles:
                         dstComp.addAttribute(dstNode, a, '|'.join(dstStyles))
@@ -320,6 +324,15 @@ class Component(object):
                     value = self.getAttribute(srcNode, a)
                     dstComp.addAttribute(dstNode, a, value)
 
+    def copyImplicitAttributes(self, srcNode, dstNode, dstComp):
+        '''Copy relevant implicit attribute nodes from srcNode to dstNode.'''
+        for n in srcNode.childNodes:
+            if n.nodeType == n.ELEMENT_NODE and not is_object(n):
+                a = n.tagName
+                if a in dstComp.implicitAttributes:
+                    value = self.getAttribute(srcNode, a)
+                    dstComp.addAttribute(dstNode, a, value)
+
 
 class SimpleComponent(Component):
     '''Component without window attributes and styles.'''
@@ -415,6 +428,7 @@ class RootComponent(Container):
     windowAttributes = []
     genericStyles = genericExStyles = []
     hasName = False
+    hasCode = False
 
 
 class SmartContainer(Container):
@@ -475,7 +489,6 @@ class SmartContainer(Container):
     def removeChild(self, parentNode, node):
         if self.requireImplicit(node):
             implicitNode = node.parentNode
-            #implicitNode.removeChild(node)
             return parentNode.removeChild(implicitNode)
         else:
             return parentNode.removeChild(node)
@@ -633,10 +646,11 @@ class _ComponentManager:
         self.panelNames = ['Windows', 'Panels', 'Controls', 'Sizers',  'Menus',
                            'Gizmos', 'Custom']
         self.panelImages = {}
-        self.handlers = []      # registered XmlHandlers
 
     def init(self):
         self.firstId = self.lastId = wx.NewId()
+        self.external = []      # external resources
+        self.handlers = []      # registered XmlHandlers
 
     def register(self, component):
         '''Register component object.'''
@@ -658,11 +672,18 @@ class _ComponentManager:
 
     def getNodeComp(self, node, defaultClass='unknown'):
         # For ref nodes without class name, need to find ref element
+        if node is Model.mainNode:
+            return self.rootComponent
+        elif node.nodeType == node.COMMENT_NODE:
+            return self.components['comment']
         cls = node.getAttribute('class')
         if node.tagName == 'object_ref':
             if not cls:
                 refNode = Model.findResource(node.getAttribute('ref'))
-                cls = refNode.getAttribute('class')
+                if refNode:
+                    cls = refNode.getAttribute('class')
+                else:
+                    cls = 'unknown'
         if defaultClass and cls not in self.components:
             cls = defaultClass
         return self.components[cls]
@@ -670,7 +691,7 @@ class _ComponentManager:
     def getMenuData(self, menu):
         return self.menus.get(menu, None)
 
-    def setMenu(self, component, menu, label, help, index=1000):
+    def setMenu(self, component, menu, label, help, index=999999):
         '''Set pulldown menu data.'''
         if menu not in self.menuNames: self.menuNames.append(menu)
         if menu not in self.menus: self.menus[menu] = []
@@ -725,8 +746,29 @@ class _ComponentManager:
                 except:
                     logger.exception('error adding XmlHandler "%s"', h)
                     wx.LogError('error adding XmlHandler "%s"' % h)
+
+    def addExternal(self, f):
+        '''Add an external resource file f to the list of preloaded
+        resources.'''
+        self.external.append(f)
+        Model.addExternal(f)
+
+    def preload(self, res):
+        '''Preload external resources.'''
+        for f in self.external:
+            TRACE('Loading external resources: %s', f)
+            res.Load(f)
         
 
 # Singleton object
 Manager = _ComponentManager()
 '''Singleton global object of L{_ComponentManager} class.'''
+
+c = SimpleComponent('comment', ['top_level', 'control'], ['comment'],
+                    specials={'comment': CommentAttribute},
+                    image=images.TreeComment.GetImage())
+c.hasName = False
+c.hasCode = False
+c.setParamClass('comment', params.ParamMultilineText)
+Manager.register(c)
+
